Type: Package
Package: statsExpressions
Title: Tidy Dataframes and Expressions with Statistical Details
Version: 2.1.1
Authors@R: 
    person("Indrajeet", "Patil", , "patilindrajeet.science@gmail.com", role = c("cre", "aut", "cph"),
           comment = c(ORCID = "0000-0003-1995-6531"))
Maintainer: Indrajeet Patil <patilindrajeet.science@gmail.com>
Description: Utilities for producing dataframes with rich details for the
    most common types of statistical approaches and tests: parametric,
    nonparametric, robust, and Bayesian t-test, one-way ANOVA, correlation
    analyses, contingency table analyses, and meta-analyses. The functions
    are pipe-friendly and provide a consistent syntax to work with tidy
    data. These dataframes additionally contain expressions with
    statistical details, and can be used in graphing packages. This
    package also forms the statistical processing backend for
    'ggstatsplot'. References: Patil (2021) <doi:10.21105/joss.03236>.
License: MIT + file LICENSE
URL: https://www.indrapatil.com/statsExpressions/,
        https://github.com/IndrajeetPatil/statsExpressions
BugReports: https://github.com/IndrajeetPatil/statsExpressions/issues
Depends: R (>= 4.5.0), stats
Imports: afex (>= 1.5-1), BayesFactor (>= 0.9.12-4.8), bayestestR (>=
        0.18.1), correlation (>= 0.8.8), datawizard (>= 1.3.1), dplyr
        (>= 1.2.1), effectsize (>= 1.0.3), glue (>= 1.8.1), insight (>=
        1.5.2), parameters (>= 0.29.2), performance (>= 0.17.1),
        PMCMRplus (>= 1.9.12), purrr (>= 1.2.2), rlang (>= 1.3.0),
        rstantools (>= 2.7.0), tidyr (>= 1.3.2), withr (>= 3.0.3), WRS2
        (>= 1.1-7)
Suggests: ggplot2, knitr, metaBMA, metafor, metaplus (>= 1.0-6),
        patrick, rmarkdown, survival, testthat (>= 3.3.2), utils
VignetteBuilder: knitr
Config/Needs/check: anthonynorth/roxyglobals
Config/Needs/coverage: RfastOfficial/Rfast
Config/Needs/website: RfastOfficial/Rfast
Config/roxygen2/version: 8.0.0
Config/roxyglobals/unique: TRUE
Config/testthat/edition: 3
Config/testthat/parallel: true
Encoding: UTF-8
Language: en-US
LazyData: true
NeedsCompilation: no
Packaged: 2026-08-24 09:02:37 UTC; runner
Author: Indrajeet Patil [cre, aut, cph] (ORCID:
    <https://orcid.org/0000-0003-1995-6531>)
Repository: CRAN
Date/Publication: 2026-08-24 10:50:02 UTC
Built: R 4.5.2; ; 2026-08-24 17:36:29 UTC; unix

Type: Package
Package: statsExpressions
Title: Tidy Dataframes and Expressions with Statistical Details
Version: 2.0.0
Authors@R: 
    person("Indrajeet", "Patil", , "patilindrajeet.science@gmail.com", role = c("cre", "aut", "cph"),
           comment = c(ORCID = "0000-0003-1995-6531"))
Maintainer: Indrajeet Patil <patilindrajeet.science@gmail.com>
Description: Utilities for producing dataframes with rich details for the
    most common types of statistical approaches and tests: parametric,
    nonparametric, robust, and Bayesian t-test, one-way ANOVA, correlation
    analyses, contingency table analyses, and meta-analyses. The functions
    are pipe-friendly and provide a consistent syntax to work with tidy
    data. These dataframes additionally contain expressions with
    statistical details, and can be used in graphing packages. This
    package also forms the statistical processing backend for
    'ggstatsplot'. References: Patil (2021) <doi:10.21105/joss.03236>.
License: MIT + file LICENSE
URL: https://www.indrapatil.com/statsExpressions/,
        https://github.com/IndrajeetPatil/statsExpressions
BugReports: https://github.com/IndrajeetPatil/statsExpressions/issues
Depends: R (>= 4.3.0), stats
Imports: afex (>= 1.5-1), BayesFactor (>= 0.9.12-4.8), bayestestR (>=
        0.17.0), correlation (>= 0.8.8), datawizard (>= 1.3.0), dplyr
        (>= 1.2.1), effectsize (>= 1.0.2), glue (>= 1.8.1), insight (>=
        1.5.0), parameters (>= 0.28.3), performance (>= 0.16.0),
        PMCMRplus (>= 1.9.12), purrr (>= 1.2.2), rlang (>= 1.2.0),
        rstantools (>= 2.6.0), tidyr (>= 1.3.2), withr (>= 3.0.2), WRS2
        (>= 1.1-7)
Suggests: ggplot2, knitr, metaBMA, metafor, metaplus (>= 1.0-6),
        patrick, rmarkdown, survival, testthat (>= 3.3.2), utils
VignetteBuilder: knitr
Config/Needs/check: anthonynorth/roxyglobals
Config/roxyglobals/unique: TRUE
Config/testthat/edition: 3
Config/testthat/parallel: true
Encoding: UTF-8
Language: en-US
LazyData: true
RoxygenNote: 7.3.3
NeedsCompilation: no
Packaged: 2026-04-22 21:32:04 UTC; runner
Author: Indrajeet Patil [cre, aut, cph] (ORCID:
    <https://orcid.org/0000-0003-1995-6531>)
Repository: CRAN
Date/Publication: 2026-04-23 12:50:02 UTC
Built: R 4.6.0; ; 2026-05-01 01:11:31 UTC; unix

# Generated by roxygen2: do not edit by hand

S3method(print,statsExpressions)
export(add_expression_col)
export(centrality_description)
export(contingency_table)
export(corr_test)
export(extract_stats_type)
export(long_to_wide_converter)
export(meta_analysis)
export(one_sample_test)
export(oneway_anova)
export(pairwise_comparisons)
export(pairwise_contingency_table)
export(stats_type_switch)
export(tidy_model_expressions)
export(tidy_model_parameters)
export(two_sample_test)
import(dplyr)
import(effectsize)
import(glue)
import(rlang)
importFrom(bayestestR,describe_posterior)
importFrom(insight,check_if_installed)
importFrom(insight,format_value)
importFrom(insight,standardize_names)
importFrom(parameters,model_parameters)
importFrom(purrr,map2)
importFrom(purrr,map_dbl)
importFrom(purrr,map_dfr)
importFrom(rstantools,bayes_R2)

<!-- README.md is generated from README.Rmd. Please edit that file -->

# `{statsExpressions}`: Tidy dataframes and expressions with statistical details

| Status | Usage | Miscellaneous |
|----|----|----|
| [![R build status](https://github.com/IndrajeetPatil/statsExpressions/workflows/R-CMD-check/badge.svg)](https://github.com/IndrajeetPatil/statsExpressions/actions) | [![Total downloads](https://cranlogs.r-pkg.org/badges/grand-total/statsExpressions?color=blue)](https://CRAN.R-project.org/package=statsExpressions) | [![Codecov](https://codecov.io/gh/IndrajeetPatil/statsExpressions/branch/main/graph/badge.svg)](https://app.codecov.io/gh/IndrajeetPatil/statsExpressions?branch=main) |
| [![lifecycle](https://img.shields.io/badge/lifecycle-maturing-blue.svg)](https://lifecycle.r-lib.org/articles/stages.html) | [![Daily downloads](https://cranlogs.r-pkg.org/badges/last-day/statsExpressions?color=blue)](https://CRAN.R-project.org/package=statsExpressions) | [![DOI](https://joss.theoj.org/papers/10.21105/joss.03236/status.svg)](https://doi.org/10.21105/joss.03236) |

# Introduction <img src="man/figures/logo.png" alt="statsExpressions package logo" align="right" width="240" />

The `{statsExpressions}` package has two key aims:

- to provide a consistent syntax to do statistical analysis with tidy
  data (in pipe-friendly manner),
- to provide statistical expressions (pre-formatted in-text statistical
  results) for plotting functions.

Statistical packages exhibit substantial diversity in terms of their
syntax and expected input type. This can make it difficult to switch
from one statistical approach to another. For example, some functions
expect vectors as inputs, while others expect dataframes. Depending on
whether it is a repeated measures design or not, different functions
might expect data to be in wide or long format. Some functions can
internally omit missing values, while other functions error in their
presence. Furthermore, if someone wishes to utilize the objects returned
by these packages downstream in their workflow, this is not
straightforward either because even functions from the same package can
return a list, a matrix, an array, a dataframe, etc., depending on the
function.

This is where `{statsExpressions}` comes in: It can be thought of as a
unified portal through which most of the functionality in these
underlying packages can be accessed, with a simpler interface and no
requirement to change data format.

This package forms the statistical processing backend for
[`ggstatsplot`](https://www.indrapatil.com/ggstatsplot/) package.

For more documentation, see the dedicated
[website](https://www.indrapatil.com/statsExpressions/).

# Installation

| Type        | Command                                       |
|:------------|:----------------------------------------------|
| Release     | `install.packages("statsExpressions")`        |
| Development | `pak::pak("IndrajeetPatil/statsExpressions")` |

On Linux, `{statsExpressions}` installation may require additional
system dependencies, which can be checked using:

``` r
pak::pkg_sysreqs("statsExpressions")
```

# Citation

The package can be cited as:

``` r
citation("statsExpressions")
To cite package 'statsExpressions' in publications use:

  Patil, I., (2021). statsExpressions: R Package for Tidy Dataframes
  and Expressions with Statistical Details. Journal of Open Source
  Software, 6(61), 3236, https://doi.org/10.21105/joss.03236

A BibTeX entry for LaTeX users is

  @Article{,
    doi = {10.21105/joss.03236},
    year = {2021},
    publisher = {{The Open Journal}},
    volume = {6},
    number = {61},
    pages = {3236},
    author = {Indrajeet Patil},
    title = {{statsExpressions: {R} Package for Tidy Dataframes and Expressions with Statistical Details}},
    journal = {{Journal of Open Source Software}},
  }
```

# General Workflow

<img src="man/figures/card.png" alt="Diagram showing the general workflow of the statsExpressions package" width="80%" />

# Summary of functionality

**Summary of available analyses**

| Test                       | Function                       |
|:---------------------------|:-------------------------------|
| one-sample *t*-test        | `one_sample_test()`            |
| two-sample *t*-test        | `two_sample_test()`            |
| one-way ANOVA              | `oneway_anova()`               |
| correlation analysis       | `corr_test()`                  |
| contingency table analysis | `contingency_table()`          |
| meta-analysis              | `meta_analysis()`              |
| pairwise comparisons       | `pairwise_comparisons()`       |
| pairwise contingency table | `pairwise_contingency_table()` |

**Summary of details available for analyses**

| Analysis                        | Hypothesis testing | Effect size estimation |
|:--------------------------------|:-------------------|:-----------------------|
| (one/two-sample) *t*-test       | ✅                 | ✅                     |
| one-way ANOVA                   | ✅                 | ✅                     |
| correlation                     | ✅                 | ✅                     |
| (one/two-way) contingency table | ✅                 | ✅                     |
| random-effects meta-analysis    | ✅                 | ✅                     |

**Summary of supported statistical approaches**

| Description | Parametric | Non-parametric | Robust | Bayesian |
|:---|:---|:---|:---|:---|
| Between group/condition comparisons | ✅ | ✅ | ✅ | ✅ |
| Within group/condition comparisons | ✅ | ✅ | ✅ | ✅ |
| Distribution of a numeric variable | ✅ | ✅ | ✅ | ✅ |
| Correlation between two variables | ✅ | ✅ | ✅ | ✅ |
| Association between categorical variables | ✅ | ✅ | ❌ | ✅ |
| Equal proportions for categorical variable levels | ✅ | ✅ | ❌ | ✅ |
| Random-effects meta-analysis | ✅ | ❌ | ✅ | ✅ |

# Tidy dataframes from statistical analysis

To illustrate the simplicity of this syntax, let’s say we want to run a
one-way ANOVA. If we first run a non-parametric ANOVA and then decide to
run a robust ANOVA instead, the syntax remains the same and the
statistical approach can be modified by changing a single argument:

``` r
mtcars |> oneway_anova(cyl, wt, type = "nonparametric")
#> # A tibble: 1 × 15
#>   parameter1 parameter2 statistic df.error   p.value
#>   <chr>      <chr>          <dbl>    <int>     <dbl>
#> 1 wt         cyl             22.8        2 0.0000112
#>   method                       effectsize      estimate conf.level conf.low
#>   <chr>                        <chr>              <dbl>      <dbl>    <dbl>
#> 1 Kruskal-Wallis rank sum test Epsilon2 (rank)    0.736       0.95    0.624
#>   conf.high conf.method          conf.iterations n.obs expression
#>       <dbl> <chr>                          <int> <int> <list>    
#> 1         1 percentile bootstrap             100    32 <language>

mtcars |> oneway_anova(cyl, wt, type = "robust")
#> # A tibble: 1 × 12
#>   statistic    df df.error p.value
#>       <dbl> <dbl>    <dbl>   <dbl>
#> 1      12.7     2     12.2 0.00102
#>   method                                           
#>   <chr>                                            
#> 1 A heteroscedastic one-way ANOVA for trimmed means
#>   effectsize                         estimate conf.level conf.low conf.high
#>   <chr>                                 <dbl>      <dbl>    <dbl>     <dbl>
#> 1 Explanatory measure of effect size     1.05       0.95    0.843      1.50
#>   n.obs expression
#>   <int> <list>    
#> 1    32 <language>
```

All possible output dataframes from functions are tabulated here:
<https://www.indrapatil.com/statsExpressions/articles/web_only/dataframe_outputs.html>

Needless to say this will also work with the `kable` function to
generate a table:

``` r
set.seed(123)

# one-sample robust t-test
# we will leave `expression` column out; it's not needed for using only the dataframe
mtcars |>
  one_sample_test(wt, test.value = 3, type = "robust") |>
  dplyr::select(-expression) |>
  knitr::kable()
```

| statistic | p.value | n.obs | method | effectsize | estimate | conf.level | conf.low | conf.high |
|---:|---:|---:|:---|:---|---:|---:|---:|---:|
| 1.179181 | 0.275 | 32 | Bootstrap-t method for one-sample test | Trimmed mean | 3.197 | 0.95 | 2.854246 | 3.539754 |

These functions are also compatible with other popular data manipulation
packages.

For example, let’s say we want to run a one-sample *t*-test for all
levels of a certain grouping variable. We can use `dplyr` to do so:

``` r
# for reproducibility
set.seed(123)
library(dplyr)

# grouped operation
# running one-sample test for all levels of grouping variable `cyl`
mtcars |>
  group_by(cyl) |>
  group_modify(~ one_sample_test(.x, wt, test.value = 3), .keep = TRUE) |>
  ungroup()
#> # A tibble: 3 × 16
#>     cyl    mu statistic df.error  p.value method            alternative
#>   <dbl> <dbl>     <dbl>    <dbl>    <dbl> <chr>             <chr>      
#> 1     4     3    -4.16        10 0.00195  One Sample t-test two.sided  
#> 2     6     3     0.870        6 0.418    One Sample t-test two.sided  
#> 3     8     3     4.92        13 0.000278 One Sample t-test two.sided  
#>   effectsize estimate conf.level conf.low conf.high conf.method
#>   <chr>         <dbl>      <dbl>    <dbl>     <dbl> <chr>      
#> 1 Hedges' g    -1.16        0.95   -1.88     -0.402 ncp        
#> 2 Hedges' g     0.286       0.95   -0.388     0.937 ncp        
#> 3 Hedges' g     1.24        0.95    0.544     1.91  ncp        
#>   conf.distribution n.obs expression
#>   <chr>             <int> <list>    
#> 1 t                    11 <language>
#> 2 t                     7 <language>
#> 3 t                    14 <language>
```

# Using expressions in custom plots

Note that *expression* here means **a pre-formatted in-text statistical
result**. In addition to other details contained in the dataframe, there
is also a column titled `expression`, which contains expression with
statistical details and can be displayed in a plot.

For **all** statistical test expressions, the default template attempt
to follow the gold standard for statistical reporting.

For example, here are results from Welch’s *t*-test:

<img src="man/figures/stats_reporting_format.png" alt="Example of statistical reporting format showing Welch's t-test results with test statistic, degrees of freedom, p-value, and effect size" align="center" />

Let’s load the needed library for visualization:

``` r
library(ggplot2)
```

## Expressions for centrality measure

**Note that when used in a geometric layer, the expression need to be
parsed.**

``` r
# displaying mean for each level of `cyl`
centrality_description(mtcars, cyl, wt) |>
  ggplot(aes(cyl, wt)) +
  geom_point() +
  geom_label(aes(label = expression), parse = TRUE)
```

<img src="man/figures/README-centrality-1.png" alt="Example ggplot showing centrality_description output: mean wt by cyl with labeled statistical expressions." width="100%" />

Here are a few examples for supported analyses.

## Expressions for one-way ANOVAs

The returned data frame will always have a column called `expression`.

Assuming there is only a single result you need to display in a plot, to
use it in a plot, you have two options:

- extract the expression from the list column
  (`results_data$expression[[1]]`) without parsing
- use the list column as is, in which case you will need to parse it
  (`parse(text = results_data$expression)`)

If you want to display more than one expression in a plot, you will
*have to* parse them.

### Between-subjects design

``` r
set.seed(123)
library(ggridges)

results_data <- oneway_anova(iris, Species, Sepal.Length, type = "robust")

# create a ridgeplot
ggplot(iris, aes(x = Sepal.Length, y = Species)) +
  geom_density_ridges() +
  labs(
    title = "A heteroscedastic one-way ANOVA for trimmed means",
    subtitle = results_data$expression[[1]]
  )
```

<img src="man/figures/README-anova_rob1-1.png" alt="Example ridge density plot for a heteroscedastic one-way ANOVA on Sepal.Length by Species" width="100%" />

### Within-subjects design

``` r
set.seed(123)
library(WRS2)
library(ggbeeswarm)

results_data <- oneway_anova(
  WineTasting,
  Wine,
  Taste,
  paired = TRUE,
  subject.id = Taster,
  type = "np"
)

ggplot2::ggplot(WineTasting, aes(Wine, Taste, color = Wine)) +
  geom_quasirandom() +
  labs(
    title = "Friedman's rank sum test",
    subtitle = parse(text = results_data$expression)
  )
```

<img src="man/figures/README-anova_parametric2-1.png" alt="Quasirandom dot plot of wine taste ratings by wine type with Friedman's rank sum test subtitle" width="100%" />

## Expressions for two-sample tests

### Between-subjects design

``` r
set.seed(123)

results_data <- two_sample_test(ToothGrowth, supp, len)

ggplot(ToothGrowth, aes(supp, len)) +
  geom_boxplot() +
  labs(
    title = "Two-Sample Welch's t-test",
    subtitle = parse(text = results_data$expression)
  )
```

<img src="man/figures/README-t_two-1.png" alt="Boxplot of ToothGrowth data with Two-Sample Welch's t-test expression in the subtitle" width="100%" />

### Within-subjects design

``` r
set.seed(123)
library(tidyr)
library(PairedData)
data(PrisonStress)

# get data in tidy format
df <- pivot_longer(PrisonStress, starts_with("PSS"), names_to = "PSS", values_to = "stress")

results_data <- two_sample_test(
  data = df,
  x = PSS,
  y = stress,
  paired = TRUE,
  subject.id = Subject,
  type = "np"
)

# plot
suppressWarnings(paired.plotProfiles(
  PrisonStress, "PSSbefore", "PSSafter",
  subjects = "Subject"
)) +
  labs(
    title = "Two-sample Wilcoxon paired test",
    subtitle = parse(text = results_data$expression)
  )
```

<img src="man/figures/README-t_two_paired1-1.png" alt="Example paired profiles plot for a two-sample Wilcoxon paired test" width="100%" />

## Expressions for one-sample tests

``` r
set.seed(123)

# dataframe with results
results_data <- one_sample_test(mtcars, wt, test.value = 3, type = "bayes")

# creating a histogram plot
ggplot(mtcars, aes(wt)) +
  geom_histogram(alpha = 0.5) +
  geom_vline(xintercept = mean(mtcars$wt), color = "red") +
  labs(subtitle = parse(text = results_data$expression))
```

<img src="man/figures/README-t_one-1.png" alt="Histogram of car weights with a vertical line at the mean and Bayesian one-sample t-test subtitle" width="100%" />

## Expressions for correlation analysis

Let’s look at another example where we want to run correlation analysis:

``` r
set.seed(123)

# dataframe with results
results_data <- corr_test(mtcars, mpg, wt, type = "nonparametric")

# create a scatter plot
ggplot(mtcars, aes(mpg, wt)) +
  geom_point() +
  geom_smooth(method = "lm", formula = y ~ x) +
  labs(
    title = "Spearman's rank correlation coefficient",
    subtitle = parse(text = results_data$expression)
  )
```

<img src="man/figures/README-corr-1.png" alt="Scatterplot of car fuel efficiency (mpg) versus weight (wt) with linear fit and Spearman correlation expression" width="100%" />

## Expressions for contingency table analysis

For categorical/nominal data - one-sample:

``` r
set.seed(123)

# dataframe with results
results_data <- contingency_table(
  as.data.frame(table(mpg$class)),
  Var1,
  counts = Freq,
  type = "bayes"
)

# create a pie chart
ggplot(as.data.frame(table(mpg$class)), aes(x = "", y = Freq, fill = factor(Var1))) +
  geom_bar(width = 1, stat = "identity") +
  theme(axis.line = element_blank()) +
  # cleaning up the chart and adding results from one-sample proportion test
  coord_polar(theta = "y", start = 0) +
  labs(
    fill = "Class",
    x = NULL,
    y = NULL,
    title = "Pie Chart of class (type of car)",
    caption = parse(text = results_data$expression)
  )
```

<img src="man/figures/README-gof-1.png" alt="Pie chart of car classes showing example output with statistical caption" width="100%" />

You can also use these function to get the expression in return without
having to display them in plots:

``` r
set.seed(123)

# Pearson's chi-squared test of independence
contingency_table(mtcars, am, vs)$expression[[1]]
#> list(chi["Pearson"]^2 * "(" * 1 * ")" == "0.91", italic(p) == 
#>     "0.34", widehat(italic("V"))["Cramer"] == "0.00", CI["95%"] ~ 
#>     "[" * "0.00", "0.49" * "]", italic("n")["obs"] == "32")
```

## Expressions for meta-analysis

``` r
set.seed(123)
library(metaviz)

# dataframe with results
results_data <- meta_analysis(dplyr::rename(mozart, estimate = d, std.error = se))

# meta-analysis forest plot with results random-effects meta-analysis
suppressWarnings(viz_forest(
  x = mozart[, c("d", "se")],
  study_labels = mozart[, "study_name"],
  xlab = "Cohen's d",
  variant = "thick",
  type = "cumulative"
)) +
  labs(
    title = "Meta-analysis of Pietschnig, Voracek, and Formann (2010) on the Mozart effect",
    subtitle = parse(text = results_data$expression)
  ) +
  theme(text = element_text(size = 12))
```

<img src="man/figures/README-metaanalysis-1.png" alt="Meta-analysis forest plot of the Mozart effect example, showing study estimates and the overall random-effects result." width="100%" />

# Customizing details to your liking

Sometimes you may not wish include so many details in the subtitle. In
that case, you can extract the expression and copy-paste only the part
you wish to include. For example, here only statistic and *p*-values are
included:

``` r
set.seed(123)

# extracting detailed expression
(res_expr <- oneway_anova(iris, Species, Sepal.Length, var.equal = TRUE)$expression[[1]])
#> list(italic("F")["Fisher"](2, 147) == "119.26", italic(p) == 
#>     "1.67e-31", widehat(omega["p"]^2) == "0.61", CI["95%"] ~ 
#>     "[" * "0.53", "1.00" * "]", italic("n")["obs"] == "150")

# adapting the details to your liking
ggplot(iris, aes(x = Species, y = Sepal.Length)) +
  geom_boxplot() +
  labs(subtitle = ggplot2::expr(paste(
    NULL, italic("F"), "(", "2", ",", "147", ") = ", "119.26", ", ",
    italic("p"), " = ", "1.67e-31"
  )))
```

<img src="man/figures/README-custom_expr-1.png" alt="Example ggplot boxplot of iris Sepal.Length by Species with a custom statistical expression subtitle" width="100%" />

# Summary of tests and effect sizes

Here a go-to summary about statistical test carried out and the returned
effect size for each function is provided. This should be useful if one
needs to find out more information about how an argument is resolved in
the underlying package or if one wishes to browse the source code. So,
for example, if you want to know more about how one-way
(between-subjects) ANOVA, you can run `?stats::oneway.test` in your R
console.

## `centrality_description`

| Type           | Measure      | Function used                         |
|:---------------|:-------------|:--------------------------------------|
| Parametric     | mean         | `datawizard::describe_distribution()` |
| Non-parametric | median       | `datawizard::describe_distribution()` |
| Robust         | trimmed mean | `datawizard::describe_distribution()` |
| Bayesian       | MAP          | `datawizard::describe_distribution()` |

## `oneway_anova`

#### between-subjects

**Hypothesis testing**

| Type | No. of groups | Test | Function used |
|:---|:---|:---|:---|
| Parametric | \> 2 | Fisher’s or Welch’s one-way ANOVA | `stats::oneway.test()` |
| Non-parametric | \> 2 | Kruskal-Wallis one-way ANOVA | `stats::kruskal.test()` |
| Robust | \> 2 | Heteroscedastic one-way ANOVA for trimmed means | `WRS2::t1way()` |
| Bayesian | \> 2 | Fisher’s ANOVA | `BayesFactor::anovaBF()` |

**Effect size estimation**

| Type | No. of groups | Effect size | CI available? | Function used |
|:---|:---|:---|:---|:---|
| Parametric | \> 2 | partial eta-squared, partial omega-squared | Yes | `effectsize::omega_squared()`, `effectsize::eta_squared()` |
| Non-parametric | \> 2 | rank epsilon squared | Yes | `effectsize::rank_epsilon_squared()` |
| Robust | \> 2 | Explanatory measure of effect size | Yes | `WRS2::t1way()` |
| Bayesian | \> 2 | Bayesian R-squared | Yes | `performance::r2_bayes()` |

#### within-subjects

**Data requirement**: Repeated measures tests assume a *complete* design
with exactly **one observation per subject per condition**. If your data
has multiple trials per cell, aggregate first (e.g., take the mean).
Verify with `table(data$subject, data$condition)` — every cell should
equal `1`.

**Hypothesis testing**

| Type | No. of groups | Test | Function used |
|:---|:---|:---|:---|
| Parametric | \> 2 | One-way repeated measures ANOVA | `afex::aov_ez()` |
| Non-parametric | \> 2 | Friedman rank sum test | `stats::friedman.test()` |
| Robust | \> 2 | Heteroscedastic one-way repeated measures ANOVA for trimmed means | `WRS2::rmanova()` |
| Bayesian | \> 2 | One-way repeated measures ANOVA | `BayesFactor::anovaBF()` |

**Effect size estimation**

| Type | No. of groups | Effect size | CI available? | Function used |
|:---|:---|:---|:---|:---|
| Parametric | \> 2 | partial eta-squared, partial omega-squared | Yes | `effectsize::omega_squared()`, `effectsize::eta_squared()` |
| Non-parametric | \> 2 | Kendall’s coefficient of concordance | Yes | `effectsize::kendalls_w()` |
| Robust | \> 2 | Algina-Keselman-Penfield robust standardized difference average | Yes | `WRS2::wmcpAKP()` |
| Bayesian | \> 2 | Bayesian R-squared | Yes | `performance::r2_bayes()` |

## `two_sample_test`

#### between-subjects

**Hypothesis testing**

| Type | No. of groups | Test | Function used |
|:---|:---|:---|:---|
| Parametric | 2 | Student’s or Welch’s *t*-test | `stats::t.test()` |
| Non-parametric | 2 | Mann-Whitney *U* test | `stats::wilcox.test()` |
| Robust | 2 | Yuen’s test for trimmed means | `WRS2::yuen()` |
| Bayesian | 2 | Student’s *t*-test | `BayesFactor::ttestBF()` |

**Effect size estimation**

| Type | No. of groups | Effect size | CI available? | Function used |
|:---|:---|:---|:---|:---|
| Parametric | 2 | Cohen’s *d*, Hedge’s *g* | Yes | `effectsize::cohens_d()`, `effectsize::hedges_g()` |
| Non-parametric | 2 | *r* (rank-biserial correlation) | Yes | `effectsize::rank_biserial()` |
| Robust | 2 | Algina-Keselman-Penfield robust standardized difference | Yes | `WRS2::akp.effect()` |
| Bayesian | 2 | difference | Yes | `bayestestR::describe_posterior()` |

#### within-subjects

**Data requirement**: Paired tests assume exactly **one observation per
subject per condition**. If your data has multiple trials per cell,
aggregate first (e.g., take the mean).

**Hypothesis testing**

| Type | No. of groups | Test | Function used |
|:---|:---|:---|:---|
| Parametric | 2 | Student’s *t*-test | `stats::t.test()` |
| Non-parametric | 2 | Wilcoxon signed-rank test | `stats::wilcox.test()` |
| Robust | 2 | Yuen’s test on trimmed means for dependent samples | `WRS2::yuend()` |
| Bayesian | 2 | Student’s *t*-test | `BayesFactor::ttestBF()` |

**Effect size estimation**

| Type | No. of groups | Effect size | CI available? | Function used |
|:---|:---|:---|:---|:---|
| Parametric | 2 | Cohen’s *d*, Hedge’s *g* | Yes | `effectsize::cohens_d()`, `effectsize::hedges_g()` |
| Non-parametric | 2 | *r* (rank-biserial correlation) | Yes | `effectsize::rank_biserial()` |
| Robust | 2 | Algina-Keselman-Penfield robust standardized difference | Yes | `WRS2::wmcpAKP()` |
| Bayesian | 2 | difference | Yes | `bayestestR::describe_posterior()` |

## `one_sample_test`

**Hypothesis testing**

| Type | Test | Function used |
|:---|:---|:---|
| Parametric | One-sample Student’s *t*-test | `stats::t.test()` |
| Non-parametric | One-sample Wilcoxon test | `stats::wilcox.test()` |
| Robust | Bootstrap-*t* method for one-sample test | `WRS2::trimcibt()` |
| Bayesian | One-sample Student’s *t*-test | `BayesFactor::ttestBF()` |

**Effect size estimation**

| Type | Effect size | CI available? | Function used |
|:---|:---|:---|:---|
| Parametric | Cohen’s *d*, Hedge’s *g* | Yes | `effectsize::cohens_d()`, `effectsize::hedges_g()` |
| Non-parametric | *r* (rank-biserial correlation) | Yes | `effectsize::rank_biserial()` |
| Robust | trimmed mean | Yes | `WRS2::trimcibt()` |
| Bayesian | difference | Yes | `bayestestR::describe_posterior()` |

## `corr_test`

**Hypothesis testing** and **Effect size estimation**

| Type | Test | CI available? | Function used |
|:---|:---|:---|:---|
| Parametric | Pearson’s correlation coefficient | Yes | `correlation::correlation()` |
| Non-parametric | Spearman’s rank correlation coefficient | Yes | `correlation::correlation()` |
| Robust | Winsorized Pearson’s correlation coefficient | Yes | `correlation::correlation()` |
| Bayesian | Bayesian Pearson’s correlation coefficient | Yes | `correlation::correlation()` |

## `contingency_table`

#### two-way table

**Hypothesis testing**

| Type | Design | Test | Function used |
|:---|:---|:---|:---|
| Parametric/Non-parametric | Unpaired | Pearson’s chi-squared test | `stats::chisq.test()` |
| Bayesian | Unpaired | Bayesian Pearson’s chi-squared test | `BayesFactor::contingencyTableBF()` |
| Parametric/Non-parametric | Paired | McNemar’s chi-squared test | `stats::mcnemar.test()` |
| Bayesian | Paired | No | No |

**Effect size estimation**

| Type | Design | Effect size | CI available? | Function used |
|:---|:---|:---|:---|:---|
| Parametric/Non-parametric | Unpaired | Cramer’s *V* | Yes | `effectsize::cramers_v()` |
| Bayesian | Unpaired | Cramer’s *V* | Yes | `effectsize::cramers_v()` |
| Parametric/Non-parametric | Paired | Cohen’s *g* | Yes | `effectsize::cohens_g()` |
| Bayesian | Paired | No | No | No |

#### one-way table

**Hypothesis testing**

| Type | Test | Function used |
|:---|:---|:---|
| Parametric/Non-parametric | Goodness of fit chi-squared test | `stats::chisq.test()` |
| Bayesian | Bayesian Goodness of fit chi-squared test | (custom) |

**Effect size estimation**

| Type | Effect size | CI available? | Function used |
|:---|:---|:---|:---|
| Parametric/Non-parametric | Pearson’s *C* | Yes | `effectsize::pearsons_c()` |
| Bayesian | No | No | No |

## `pairwise_contingency_table`

**Hypothesis testing**

| Test                | *p*-value adjustment? | Function used          |
|:--------------------|:----------------------|:-----------------------|
| Fisher’s exact test | Yes                   | `stats::fisher.test()` |

**Effect size estimation**

| Effect size  | CI available? | Function used             |
|:-------------|:--------------|:--------------------------|
| Cramer’s *V* | Yes           | `effectsize::cramers_v()` |

## `meta_analysis`

**Hypothesis testing** and **Effect size estimation**

| Type | Test | Effect size | CI available? | Function used |
|:---|:---|:---|:---|:---|
| Parametric | Meta-analysis via random-effects models | *beta* | Yes | `metafor::rma()` |
| Robust | Meta-analysis via robust random-effects models | *beta* | Yes | `metaplus::metaplus()` |
| Bayesian | Meta-analysis via Bayesian random-effects models | *beta* | Yes | `metaBMA::meta_random()` |

# Usage in `{ggstatsplot}`

Note that these functions were initially written to display results from
statistical tests on ready-made `{ggplot2}` plots implemented in
`{ggstatsplot}`.

For detailed documentation, see the package website:
<https://www.indrapatil.com/ggstatsplot/>

Here is an example from `{ggstatsplot}` of what the plots look like when
the expressions are displayed in the subtitle-

<img src="man/figures/ggstatsplot.png" alt="Example plot from ggstatsplot package showing statistical results in subtitle" align="center" />

# Acknowledgments

The hexsticker and the schematic illustration of general workflow were
generously designed by Sarah Otterstetter (Max Planck Institute for
Human Development, Berlin).

# Contributing

Bug reports, suggestions, questions, and (most of all) contributions are
welcome.

Please note that this project is released with a [Contributor Code of
Conduct](https://www.contributor-covenant.org/version/3/0/code_of_conduct/).
By participating in this project you agree to abide by its terms.

## -----------------------------------------------------------------------------
source("setup.R")

pkgs <- "ggplot2"

successfully_loaded <- purrr::map_lgl(pkgs, requireNamespace, quietly = TRUE)
can_evaluate <- all(successfully_loaded)

if (can_evaluate) {
  purrr::walk(pkgs, library, character.only = TRUE)
} else {
  knitr::opts_chunk$set(eval = FALSE)
}

## -----------------------------------------------------------------------------
citation("statsExpressions")

## -----------------------------------------------------------------------------
oneway_anova(mtcars, cyl, wt, type = "nonparametric")

oneway_anova(mtcars, cyl, wt, type = "robust")

## -----------------------------------------------------------------------------
# running one-sample proportion test for `vs` at all levels of `am`
mtcars |>
  group_by(am) |>
  group_modify(~ contingency_table(.x, vs), .keep = TRUE) |>
  ungroup()

## -----------------------------------------------------------------------------
pairwise_comparisons(
  data            = mtcars,
  x               = cyl,
  y               = wt,
  type            = "parametric",
  var.equal       = FALSE,
  p.adjust.method = "holm"
)

## -----------------------------------------------------------------------------
multi_test_results <- dplyr::bind_rows(
  two_sample_test(mtcars, am, wt, type = "parametric"),
  two_sample_test(mtcars, am, wt, type = "nonparametric"),
  two_sample_test(mtcars, am, wt, type = "robust")
) |>
  dplyr::mutate(p.value = stats::p.adjust(p.value, method = "holm"))

dplyr::select(multi_test_results, method, effectsize, estimate, p.value)

## -----------------------------------------------------------------------------
# suppose you have run your own statistical test
custom_stats <- cbind.data.frame(
  statistic  = 2.18,
  df         = 18,
  p.value    = 0.041,
  estimate   = 0.65,
  conf.level = 0.95,
  conf.low   = 0.03,
  conf.high  = 1.27,
  method     = "Student's t-test"
)

# generate a formatted expression
add_expression_col(
  data           = custom_stats,
  statistic.text = list(quote(italic("t"))),
  effsize.text   = list(quote(italic("d")["Cohen"])),
  n              = 20L,
  digits         = 2L,
  digits.df      = 0L
)$expression[[1]]

## -----------------------------------------------------------------------------
knitr::include_graphics("stats_reporting_format.png")

## -----------------------------------------------------------------------------
# needed libraries
library(ggplot2)

# Example 1: Performing a t-test on raw tidy data and extracting the formatted expression
# for direct use in a plot annotation
res_ttest <- two_sample_test(mtcars, am, wt, type = "parametric")

ggplot(mtcars, aes(as.factor(am), wt)) +
  geom_boxplot() +
  labs(
    x = "Transmission (0 = automatic, 1 = manual)",
    y = "Weight (1000 lbs)",
    title = "Vehicle Weight by Transmission Type",
    subtitle = res_ttest$expression[[1]] # Extract formatted p-value and effect size
  )

# Example 2: One-way ANOVA
res_anova <- oneway_anova(iris, Species, Sepal.Length, type = "nonparametric")

ggplot(iris, aes(x = Sepal.Length, y = Species)) +
  geom_boxplot() + # use 'expression' column to display results in the subtitle
  labs(
    x = "Penguin Species",
    y = "Body mass (in grams)",
    title = "Kruskal-Wallis Rank Sum Test",
    subtitle = res_anova$expression[[1]]
  )

# for reproducibility
set.seed(123)

# ----------------------- parametric -----------------------

one_sample_test(mtcars, wt, test.value = 3)

# biased (Cohen's d) effect size
one_sample_test(mtcars, wt, test.value = 3, effsize.type = "d")

# ----------------------- non-parametric -------------------

one_sample_test(mtcars, wt, test.value = 3, type = "nonparametric")

# ----------------------- robust ---------------------------

one_sample_test(mtcars, wt, test.value = 3, type = "robust")

# ----------------------- Bayesian -------------------------

one_sample_test(mtcars, wt, test.value = 3, type = "bayes")

#' \code{statsExpressions}
#'
#' @title statsExpressions: Tidy Dataframes and Expressions with Statistical Details
#'
#' @description
#'
#' ```{r child="man/rmd-fragments/statsExpressions-package.Rmd"}
#'
#' ```
#'
#' @docType package
#' @aliases statsExpressions statsExpressions-package
#' @name statsExpressions-package
#' @keywords internal
"_PACKAGE"


## statsExpressions namespace: start
##
#' @import rlang
#' @import dplyr
#' @import glue
#' @import effectsize
#'
#' @importFrom insight format_value check_if_installed standardize_names
#' @importFrom parameters model_parameters
#' @importFrom bayestestR describe_posterior
#' @importFrom purrr map2 map_dbl map_dfr
#' @importFrom rstantools bayes_R2
#'
## statsExpressions namespace: end
NULL

#' @title One-way analysis of variance (ANOVA)
#' @name oneway_anova
#'
#' @description
#' Parametric, non-parametric, robust, and Bayesian one-way ANOVA.
#'
#' @section One-way ANOVA:
#'
#' ```{r child="man/rmd-fragments/table_intro.Rmd"}
#' ```
#'
#' ```{r child="man/rmd-fragments/oneway_anova.Rmd"}
#' ```
#'
#' @returns
#'
#' ```{r child="man/rmd-fragments/return.Rmd"}
#' ```
#'
#' @inheritParams long_to_wide_converter
#' @inheritParams extract_stats_type
#' @param conf.level Scalar between `0` and `1` (default: `95%`
#' confidence/credible intervals, `0.95`). If `NULL`, no confidence intervals
#' will be computed.
#' @param effsize.type Type of effect size needed for *parametric* tests. The
#'   argument can be `"eta"` (partial eta-squared) or `"omega"` (partial
#'   omega-squared).
#' @param tr Trim level for the mean when carrying out `robust` tests. In case
#'   of an error, try reducing the value of `tr`, which is by default set to
#'   `0.2`. Lowering the value might help.
#' @param nboot Number of bootstrap samples for computing confidence interval
#'   for the effect size (Default: `100L`).
#' @param bf.prior A number between `0.5` and `2` (default `0.707`), the prior
#'   width to use in calculating Bayes factors and posterior estimates. In
#'   addition to numeric arguments, several named values are also recognized:
#'   `"medium"`, `"wide"`, and `"ultrawide"`, corresponding to *r* scale values
#'   of `1/2`, `sqrt(2)/2`, and `1`, respectively. In case of an ANOVA, this
#'   value corresponds to scale for fixed effects.
#' @inheritParams two_sample_test
#' @inheritParams add_expression_col
#' @param ... Additional arguments (currently ignored).
#' @inheritParams stats::oneway.test
#'
#' @autoglobal
#'
#' @examplesIf identical(Sys.getenv("NOT_CRAN"), "true")
#' # for reproducibility
#' set.seed(123)
#' library(statsExpressions)
#'
#' # ----------------------- parametric -------------------------------------
#'
#' # between-subjects
#' oneway_anova(
#'   data = mtcars,
#'   x    = cyl,
#'   y    = wt
#' )
#'
#' # biased (partial eta-squared) effect size
#' oneway_anova(
#'   data         = mtcars,
#'   x            = cyl,
#'   y            = wt,
#'   effsize.type = "eta"
#' )
#'
#' # within-subjects design
#' oneway_anova(
#'   data       = iris_long,
#'   x          = condition,
#'   y          = value,
#'   subject.id = id,
#'   paired     = TRUE
#' )
#'
#' # ----------------------- non-parametric ----------------------------------
#'
#' # between-subjects
#' oneway_anova(
#'   data = mtcars,
#'   x    = cyl,
#'   y    = wt,
#'   type = "np"
#' )
#'
#' # within-subjects design
#' oneway_anova(
#'   data       = iris_long,
#'   x          = condition,
#'   y          = value,
#'   subject.id = id,
#'   paired     = TRUE,
#'   type       = "np"
#' )
#'
#' # ----------------------- robust -------------------------------------
#'
#' # between-subjects
#' oneway_anova(
#'   data = mtcars,
#'   x    = cyl,
#'   y    = wt,
#'   type = "r"
#' )
#'
#' # within-subjects design
#' oneway_anova(
#'   data       = iris_long,
#'   x          = condition,
#'   y          = value,
#'   subject.id = id,
#'   paired     = TRUE,
#'   type       = "r"
#' )
#'
#' @examplesIf identical(Sys.getenv("NOT_CRAN"), "true") && requireNamespace("rstantools")
#'
#' # ----------------------- Bayesian -------------------------------------
#'
#' # between-subjects
#' oneway_anova(
#'   data = mtcars,
#'   x    = cyl,
#'   y    = wt,
#'   type = "bayes"
#' )
#'
#' # within-subjects design
#' oneway_anova(
#'   data       = iris_long,
#'   x          = condition,
#'   y          = value,
#'   subject.id = id,
#'   paired     = TRUE,
#'   type       = "bayes"
#' )
#'
#' @template citation
#'
#' @export
oneway_anova <- function(
  data,
  x,
  y,
  subject.id = NULL,
  type = "parametric",
  paired = FALSE,
  digits = 2L,
  conf.level = 0.95,
  effsize.type = "omega",
  var.equal = FALSE,
  bf.prior = 0.707,
  tr = 0.2,
  nboot = 100L,
  ...
) {
  # data -------------------------------------------

  type <- extract_stats_type(type)
  x <- ensym(x)
  y <- ensym(y)

  data <- long_to_wide_converter(
    data,
    x = {{ x }},
    y = {{ y }},
    subject.id = {{ subject.id }},
    paired = paired,
    spread = FALSE
  ) |>
    mutate(.rowid = as.factor(.rowid))

  #  parametric ---------------------------------------

  if (type == "parametric") {
    digits.df <- ifelse(paired, digits, 0L)
    digits.df.error <- ifelse(!paired && var.equal, 0L, digits)

    .f.es <- switch(
      match.arg(effsize.type, c("omega", "eta", "unbiased", "biased")),
      omega = ,
      unbiased = effectsize::omega_squared,
      eta = ,
      biased = effectsize::eta_squared
    )

    if (paired) {
      mod <- afex::aov_ez(
        id = ".rowid",
        dv = as_string(y),
        data = data,
        within = as_string(x),
        include_aov = TRUE
      )
    }

    if (!paired) {
      mod <- stats::oneway.test(new_formula(y, x), data, var.equal = var.equal)
    }

    effect_df <- exec(.f.es, model = mod, ci = conf.level, verbose = FALSE) |>
      tidy_model_effectsize()

    stats_df <- bind_cols(
      tidy_model_parameters(mod),
      effect_df
    )
  }

  # non-parametric ------------------------------------

  if (type == "nonparametric") {
    digits.df <- 0L
    digits.df.error <- 0L

    # styler: off
    if (paired) {
      .f <- stats::friedman.test
      .f.es <- effectsize::kendalls_w
      .f.args <- list(
        formula = new_formula(
          enexpr(y),
          expr(!!enexpr(x) | .rowid)
        )
      )
      .f.es.args <- list(
        x = new_formula(
          enexpr(y),
          expr(!!enexpr(x) | .rowid)
        )
      )
    }

    if (!paired) {
      .f <- stats::kruskal.test
      .f.es <- effectsize::rank_epsilon_squared
      .f.args <- list(formula = new_formula(y, x))
      .f.es.args <- list(x = new_formula(y, x))
    }
    # styler: on

    stats_df <- tidy_model_parameters(exec(.f, !!!.f.args, data = data))

    ez_df <- exec(
      .fn = .f.es,
      data = data,
      ci = conf.level,
      iterations = nboot,
      verbose = FALSE,
      !!!.f.es.args
    ) |>
      tidy_model_effectsize()

    stats_df <- bind_cols(stats_df, ez_df)
  }

  # robust ---------------------------------------

  if (type == "robust") {
    digits.df <- ifelse(paired, digits, 0L)
    digits.df.error <- digits

    if (paired) {
      mod <- WRS2::rmanova(
        y = data[[as_name(y)]],
        groups = data[[as_name(x)]],
        blocks = data[[".rowid"]],
        tr = tr
      )
    }

    if (!paired) {
      mod <- WRS2::t1way(
        formula = new_formula(y, x),
        data = data,
        tr = tr,
        alpha = 1.0 - conf.level,
        nboot = nboot
      )
    }

    stats_df <- tidy_model_parameters(mod)

    if (paired) {
      ez_df <- long_to_wide_converter(data, {{ x }}, {{ y }}) |>
        WRS2::wmcpAKP(select(-.rowid), tr = tr, nboot = nboot) |>
        tidy_model_parameters()

      stats_df <- bind_cols(stats_df, ez_df)
    }
  }

  # Bayesian ---------------------------------------

  if (type == "bayes") {
    if (!paired) {
      .f.args <- list(formula = new_formula(y, x), rscaleFixed = bf.prior)
    }
    if (paired) {
      .f.args <- list(
        formula = new_formula(enexpr(y), expr(!!enexpr(x) + .rowid)),
        rscaleFixed = bf.prior,
        whichRandom = ".rowid",
        rscaleRandom = 1.0
      )
    }

    stats_df <- exec(
      BayesFactor::anovaBF,
      data = as.data.frame(data),
      progress = FALSE,
      !!!.f.args
    ) |>
      tidy_model_parameters(ci = conf.level)
  }

  # expression ---------------------------------------

  add_expression_col(
    data = stats_df,
    n = ifelse(paired, length(unique(data$.rowid)), nrow(data)),
    paired = paired,
    digits = digits,
    digits.df = digits.df,
    digits.df.error = digits.df.error
  )
}

test_that(desc = "expr_anova_robust works - between-subjects", code = {
  # between-subjects -------------------------------------------------------

  set.seed(123)
  df1 <- oneway_anova(
    type = "robust",
    data = mtcars,
    x = cyl,
    y = wt,
    paired = FALSE,
    digits = 5L,
    tr = 0.00025,
    nboot = 2
  )

  set.seed(123)
  df2 <- suppressWarnings(oneway_anova(
    type = "robust",
    data = filter(msleep, vore != "insecti"),
    x = vore,
    y = sleep_total,
    paired = FALSE,
    digits = 4L,
    nboot = 15,
    conf.level = 0.99
  ))

  set.seed(123)
  expect_snapshot(select(df1, -expression))
  expect_snapshot(df1[["expression"]])

  set.seed(123)
  expect_snapshot(select(df2, -expression))
  expect_snapshot(df2[["expression"]])
})

test_that(desc = "expr_anova_robust works - within-subjects", code = {
  # within-subjects -------------------------------------------------------

  set.seed(123)
  df1 <- oneway_anova(
    type = "robust",
    data = bugs_long,
    x = condition,
    y = desire,
    digits = 4L,
    paired = TRUE
  )

  set.seed(123)
  expect_snapshot(select(df1, -expression))
  expect_snapshot(df1[["expression"]])

  # edge case with few cases

  dat <- dplyr::tibble(
    cases = c(1, 1, 2, 2, 3, 3, 4, 4),
    groups = c("b", "a", "b", "a", "b", "a", "b", "a"),
    values = c(2, 5, 3, 4, 4, 6, 5, 8)
  )

  set.seed(123)
  df2 <- oneway_anova(
    data = dat,
    x = groups,
    y = values,
    type = "r",
    conf.level = 0.99,
    paired = TRUE
  )

  set.seed(123)
  expect_snapshot(select(df2, -expression))
  expect_snapshot(df2[["expression"]])
})

skip_if_not_installed("boot")

# between-subjects ----------------------------------------------

test_that(desc = "between-subjects", code = {
  # without NA
  set.seed(123)
  df1 <- oneway_anova(
    type = "np",
    data = sample_frac(movies_long, 0.1),
    x = genre,
    y = length,
    paired = FALSE
  )

  set.seed(123)
  expect_snapshot(select(df1, -expression))
  expect_snapshot(df1[["expression"]])

  # with NA
  set.seed(123)
  df2 <- suppressWarnings(oneway_anova(
    type = "np",
    data = msleep,
    x = vore,
    y = sleep_total,
    paired = FALSE,
    conf.level = 0.99
  ))

  set.seed(123)
  expect_snapshot(select(df2, -expression))
  expect_snapshot(df2[["expression"]])
})

# within-subjects ----------------------------------------------

test_that(desc = "within-subjects", code = {
  #  with NAs
  set.seed(123)
  df1 <- oneway_anova(
    type = "np",
    data = bugs_long,
    x = condition,
    y = desire,
    paired = TRUE,
    conf.level = 0.99
  )

  set.seed(123)
  expect_snapshot(select(df1, -expression))
  expect_snapshot(df1[["expression"]])

  # without NAs
  set.seed(123)
  df2 <- oneway_anova(
    type = "np",
    data = iris_long,
    x = condition,
    y = value,
    paired = TRUE,
    conf.level = 0.90
  )

  set.seed(123)
  expect_snapshot(select(df2, -expression))
  expect_snapshot(df2[["expression"]])
})

test_that(desc = "works with subject id", code = {
  set.seed(123)
  expr1 <- oneway_anova(
    type = "np",
    data = data_with_subid,
    x = condition,
    y = score,
    subject.id = id,
    paired = TRUE
  )

  set.seed(123)
  expr2 <- oneway_anova(
    type = "np",
    data = arrange(data_with_subid, id),
    x = condition,
    y = score,
    paired = TRUE
  )

  expect_identical(expr1, expr2)
})

test_that(desc = "parametric anova subtitles work (without NAs)", code = {
  set.seed(123)
  df <- oneway_anova(
    data = mtcars,
    x = cyl,
    y = wt,
    effsize.type = "eta",
    digits = 5L,
    var.equal = FALSE
  )

  set.seed(123)
  expect_snapshot(select(df, -expression))
  expect_snapshot(df[["expression"]])

  set.seed(123)
  df1 <- oneway_anova(
    data = mtcars,
    x = cyl,
    y = wt,
    effsize.type = "eta",
    digits = 5L,
    var.equal = TRUE
  )

  set.seed(123)
  expect_snapshot(select(df1, -expression))
  expect_snapshot(df1[["expression"]])
})

test_that(desc = "parametric anova subtitles with partial omega-squared", code = {
  set.seed(123)
  df1 <- oneway_anova(
    data = msleep,
    x = vore,
    y = brainwt,
    effsize.type = "unbiased",
    digits = 4L
  )

  set.seed(123)
  expect_snapshot(select(df1, -expression))
  expect_snapshot(df1[["expression"]])
})

test_that(desc = "paired parametric anova subtitles work (without NAs)", code = {
  set.seed(123)
  df1 <- oneway_anova(
    data = iris_long,
    x = condition,
    y = value,
    paired = TRUE,
    digits = 3L,
    var.equal = FALSE, # shouldn't make a difference
    conf.level = 0.99
  )

  set.seed(123)
  expect_snapshot(select(df1, -expression))
  expect_snapshot(df1[["expression"]])
})


test_that(desc = "works with subject id", code = {
  df <- data_with_subid

  set.seed(123)
  expr1 <- oneway_anova(
    data = df,
    x = condition,
    y = score,
    subject.id = id,
    paired = TRUE
  )

  set.seed(123)
  expr2 <- oneway_anova(
    data = arrange(df, id),
    x = condition,
    y = score,
    paired = TRUE
  )

  expect_identical(expr1, expr2)
})

# don't test data frames because the values vary across platforms, even with the
# same seed; for the same reason, don't change number of digits

# between-subjects ------------------------------

skip_if_not_installed("rstantools")

test_that(desc = "bayesian (between-subjects - anova)", code = {
  # with NA
  set.seed(123)
  df1 <- suppressWarnings(oneway_anova(
    type = "bayes",
    data = msleep,
    x = vore,
    y = brainwt
  ))

  expect_snapshot(dim(df1))
  expect_snapshot(df1[["expression"]][[1]])

  # without NA
  set.seed(123)
  df2 <- suppressWarnings(oneway_anova(
    type = "bayes",
    data = iris,
    x = Species,
    y = Sepal.Length
  ))

  expect_snapshot(dim(df2))
  expect_snapshot(df2[["expression"]][[1]])
})

# within-subjects ------------------------------

test_that(desc = "bayesian (within-subjects - anova)", code = {
  set.seed(123)
  df1 <- oneway_anova(
    type = "bayes",
    data = WRS2::WineTasting,
    x = Wine,
    y = Taste,
    paired = TRUE,
    bf.prior = 0.88
  )

  expect_snapshot(dim(df1))
  expect_snapshot(df1[["expression"]][[1]])

  # data with NA
  set.seed(123)
  df2 <- oneway_anova(
    type = "bayes",
    data = bugs_long,
    x = condition,
    y = desire,
    paired = TRUE
  )

  expect_snapshot(dim(df2))
  expect_snapshot(df2[["expression"]][[1]])

  # with subject.id ---------------------------------

  set.seed(123)
  expr1 <- oneway_anova(
    type = "bayes",
    data = data_with_subid,
    x = condition,
    y = score,
    subject.id = id,
    paired = TRUE
  )

  set.seed(123)
  expr2 <- oneway_anova(
    type = "bayes",
    data = arrange(data_with_subid, id),
    x = condition,
    y = score,
    paired = TRUE
  )

  expect_equal(expr2, expr1, ignore_attr = TRUE)
})

# test Bayesian ANOVA helper behavior --------

test_that(desc = "Bayesian ANOVA with if_all() filtering and row replication", code = {
  # Test between-subjects design
  # This ensures the if_all(matches("effect")) filtering behaves correctly
  # when effect/component columns are absent (they appear in the within-subjects case)
  set.seed(123)
  df_between <- suppressWarnings(oneway_anova(
    type = "bayes",
    data = iris,
    x = Species,
    y = Sepal.Length
  ))

  # Verify structure is correct after filtering and binding
  expect_true(all(
    c("estimate", "conf.low", "conf.high") %in% colnames(df_between)
  ))
  expect_snapshot(colnames(df_between))
  expect_snapshot(nrow(df_between))

  # Test within-subjects design
  # This tests both if_all filters and the row replication logic
  set.seed(123)
  df_within <- suppressWarnings(oneway_anova(
    type = "bayes",
    data = WRS2::WineTasting,
    x = Wine,
    y = Taste,
    paired = TRUE
  ))

  # Should have same columns and proper row count
  expect_true(all(
    c("estimate", "conf.low", "conf.high") %in% colnames(df_within)
  ))
  expect_snapshot(colnames(df_within))
  expect_snapshot(nrow(df_within))
})

# test tidy_model_parameters with Bayesian ANOVA --------

test_that(desc = "tidy_model_parameters handles Bayesian ANOVA correctly", code = {
  # Test between-subjects design (no component column)
  set.seed(123)
  model_between <- BayesFactor::anovaBF(Sepal.Length ~ Species, data = iris)

  # Call tidy_model_parameters directly
  result_between <- tidy_model_parameters(model_between)

  # Verify expected columns exist
  expect_true("estimate" %in% colnames(result_between))
  expect_true("conf.low" %in% colnames(result_between))
  expect_true("conf.high" %in% colnames(result_between))
  expect_true("method" %in% colnames(result_between))
  expect_identical(
    result_between$method[[1]],
    "Bayes factors for linear models"
  )

  # Verify that the row replication worked - should have same number of rows as original
  expect_gt(nrow(result_between), 0L)

  # Verify if_all behavior: when component column doesn't exist (between-subjects), keeps all rows
  expect_snapshot(dim(result_between))
})

#' @title Correlation analyses
#' @name corr_test
#'
#' @description
#' Parametric, non-parametric, robust, and Bayesian correlation test.
#'
#' @section Correlation analyses:
#'
#' ```{r child="man/rmd-fragments/table_intro.Rmd"}
#' ```
#'
#' ```{r child="man/rmd-fragments/corr_test.Rmd"}
#' ```
#'
#' @returns
#'
#' ```{r child="man/rmd-fragments/return.Rmd"}
#' ```
#'
#' @param x The column in `data` containing the explanatory variable to be
#'   plotted on the `x`-axis.
#' @param y The column in `data` containing the response (outcome) variable to
#'   be plotted on the `y`-axis.
#' @inheritParams oneway_anova
#'
#' @autoglobal
#'
#' @example man/examples/examples-corr-test.R
#'
#' @template citation
#'
#' @export
corr_test <- function(
  data,
  x,
  y,
  type = "parametric",
  digits = 2L,
  conf.level = 0.95,
  tr = 0.2,
  bf.prior = 0.707,
  ...
) {
  type <- extract_stats_type(type)

  data <- select(ungroup(data), {{ x }}, {{ y }}) |>
    filter(!if_any(everything(), is.na))

  stats_df <- correlation::correlation(
    data = data,
    method = ifelse(type == "nonparametric", "spearman", "pearson"),
    ci = conf.level,
    bayesian = type == "bayes",
    bayesian_prior = bf.prior,
    winsorize = ifelse(type == "robust", tr, FALSE)
  ) |>
    standardize_names(style = "broom") |>
    dplyr::mutate(conf.method = ifelse(type == "bayes", "HDI", "normal"))

  add_expression_col(stats_df, paired = TRUE, digits = digits)
}

# parametric --------------------------------------------------------------

test_that(desc = "corr_test works - parametric", code = {
  # with NA
  set.seed(123)
  df1 <- corr_test(
    data = msleep,
    x = brainwt,
    y = sleep_rem,
    type = "parametric",
    digits = 3L,
    conf.level = 0.90
  )

  set.seed(123)
  expect_snapshot(select(df1, -expression))
  expect_snapshot(df1[["expression"]])

  # without NA
  set.seed(123)
  df2 <- corr_test(
    data = mtcars,
    x = wt,
    y = mpg,
    type = "p",
    digits = 3L
  )

  set.seed(123)
  expect_snapshot(select(df2, -expression))
  expect_snapshot(df2[["expression"]])
})

# robust ----------------------------------------------------------------

test_that(desc = "corr_test works - robust", code = {
  # with NA
  set.seed(123)
  df1 <- corr_test(
    data = msleep,
    x = brainwt,
    y = sleep_total,
    type = "r",
    digits = 4L,
    conf.level = 0.50
  )

  set.seed(123)
  expect_snapshot(select(df1, -expression))
  expect_snapshot(df1[["expression"]])

  # without NA
  set.seed(123)
  df2 <- corr_test(
    data = mtcars,
    x = wt,
    y = mpg,
    type = "r"
  )

  set.seed(123)
  expect_snapshot(select(df2, -expression))
  expect_snapshot(df2[["expression"]])
})

# nonparametric ----------------------------------------------------------

test_that(desc = "corr_test works - nonparametric", code = {
  # with NA
  set.seed(123)
  df1 <- corr_test(
    data = msleep,
    x = brainwt,
    y = sleep_total,
    type = "np",
    digits = 4L,
    conf.level = 0.50
  )

  set.seed(123)
  expect_snapshot(select(df1, -expression))
  expect_snapshot(df1[["expression"]])

  # without NA
  set.seed(123)
  df2 <- corr_test(
    data = mtcars,
    x = wt,
    y = mpg,
    type = "np",
    digits = 4L
  )

  set.seed(123)
  expect_snapshot(select(df2, -expression))
  expect_snapshot(df2[["expression"]])
})

# bayesian --------------------------------------

test_that(desc = "corr_test works - Bayesian", code = {
  # with NA
  set.seed(123)
  df1 <- corr_test(
    type = "bayes",
    data = msleep,
    y = brainwt,
    x = sleep_rem,
    bf.prior = 0.8,
    conf.level = 0.99
  )

  expect_equal(df1$bf10, 0.614, tolerance = 0.001)
  expect_snapshot(df1[["expression"]])

  # without NA
  set.seed(123)
  df2 <- corr_test(
    data = mtcars,
    x = wt,
    y = mpg,
    type = "bayes"
  )

  expect_snapshot(df2[["expression"]])
})

#' @name tidy_model_parameters
#' @title Convert `{parameters}` package output to `{tidyverse}` conventions
#'
#' @inheritParams parameters::model_parameters
#'
#' @autoglobal
#'
#' @examples
#' model <- lm(mpg ~ wt + cyl, data = mtcars)
#' tidy_model_parameters(model)
#'
#' @template citation
#'
#' @export
tidy_model_parameters <- function(model, ...) {
  params <- model_parameters(model, verbose = FALSE, ...)
  stats_df <- params |>
    mutate(conf.method = attr(params, "ci_method")) |>
    select(-matches("Difference")) |>
    standardize_names(style = "broom") |>
    rename_all(\(x) gsub("cramers.|omega2.|eta2.", "", x)) |>
    rename_with(recode, bayes.factor = "bf10") |>
    tidyr::fill(matches("^prior|^bf"), .direction = "updown") |>
    mutate(across(matches("bf10"), \(x) log(x), .names = "log_e_{.col}"))

  if (!"estimate" %in% colnames(stats_df)) {
    stats_df <- select(stats_df, -matches("^conf"))
  }

  # Bayesian ANOVA designs -----------------------------------

  if (
    "method" %in%
      names(stats_df) &&
      stats_df$method[[1]] == "Bayes factors for linear models"
  ) {
    # for within-subjects design, retain only conditional component
    df_r2 <- performance::r2_bayes(
      model,
      average = TRUE,
      verbose = FALSE,
      ci = stats_df$conf.level[[1]]
    ) |>
      as_tibble() |>
      standardize_names(style = "broom") |>
      rename(estimate = r.squared) |>
      filter(if_all(matches("component"), ~ (.x == "conditional")))

    # remove estimates and CIs and use R2 data frame instead
    stats_df <- stats_df |>
      select(-matches("^est|^conf|^comp")) |>
      filter(if_all(matches("effect"), ~ (.x == "fixed")))

    # replicate df_r2 to match stats_df rows for bind_cols
    df_r2 <- df_r2[rep(1L, nrow(stats_df)), ]

    stats_df <- bind_cols(stats_df, df_r2)
  }

  as_tibble(stats_df)
}


#' @name tidy_model_effectsize
#' @title Convert `{effectsize}` package output to `{tidyverse}` conventions
#'
#' @param data A data frame returned by `{effectsize}` functions.
#' @param ... Currently ignored.
#'
#' @autoglobal
#'
#' @examples
#' df <- effectsize::cohens_d(sleep$extra, sleep$group)
#' tidy_model_effectsize(df)
#' @noRd
tidy_model_effectsize <- function(data, ...) {
  data |>
    mutate(
      effectsize = stats::na.omit(effectsize::get_effectsize_label(colnames(
        data
      )))
    ) |>
    standardize_names(style = "broom") |>
    select(-contains("term")) |>
    bind_cols(rename_with(as_tibble(attr(data, "ci_method")), \(x) {
      paste0("conf.", x)
    }))
}

test_that("tidy_model_expressions works - t", {
  set.seed(123)
  mod_t <- lm(wt ~ mpg, data = mtcars)

  set.seed(123)
  df_t <- suppressWarnings(tidy_model_expressions(
    tidy_model_parameters(mod_t),
    statistic = "t"
  ))

  expect_snapshot(select(df_t, -expression))
  expect_snapshot(df_t[["expression"]])

  # with NA df.error
  set.seed(123)
  df_t_na <- suppressWarnings(tidy_model_expressions(
    mutate(tidy_model_parameters(mod_t), df.error = NA_real_),
    statistic = "t"
  ))

  expect_snapshot(df_t_na[["expression"]])

  # with infinity as error
  set.seed(123)
  df_t_inf <- suppressWarnings(tidy_model_expressions(
    mutate(tidy_model_parameters(mod_t), df.error = Inf),
    statistic = "t"
  ))

  expect_snapshot(df_t_inf[["expression"]])
})

test_that("tidy_model_expressions works - chi2", {
  skip_if_not_installed("survival")
  withr::local_package("survival")

  mod_chi <- survival::coxph(
    formula = Surv(time, status) ~ age + sex + frailty(inst),
    data = lung
  )

  set.seed(123)
  df_chi <- suppressWarnings(tidy_model_expressions(
    tidy_model_parameters(mod_chi),
    statistic = "chi"
  ))

  expect_snapshot(select(df_chi, -expression))
  expect_snapshot(df_chi[["expression"]])

  df_chi$estimate[1] <- NA
  df_chi <- dplyr::select(df_chi, -expression)
  df_chi2 <- suppressWarnings(tidy_model_expressions(df_chi, statistic = "chi"))
  expect_null(df_chi2[["expression"]][[1]])
})

test_that("tidy_model_expressions works - z", {
  df <- as.data.frame(Titanic)

  mod_z <- stats::glm(
    formula = Survived ~ Sex + Age,
    data = df,
    weights = df$Freq,
    family = stats::binomial(link = "logit")
  )

  set.seed(123)
  df_z <- suppressWarnings(tidy_model_expressions(
    tidy_model_parameters(mod_z),
    statistic = "z"
  ))

  expect_snapshot(select(df_z, -expression))
  expect_snapshot(df_z[["expression"]])
})


test_that("tidy_model_expressions works - F", {
  set.seed(123)
  mod_f <- aov(yield ~ N * P + Error(block), npk)

  set.seed(123)
  df1 <- tidy_model_expressions(
    tidy_model_parameters(
      mod_f,
      es_type = "omega",
      table_wide = TRUE
    ),
    statistic = "f"
  )

  expect_snapshot(select(df1, -expression))
  expect_snapshot(df1[["expression"]])

  set.seed(123)
  df2 <- tidy_model_expressions(
    tidy_model_parameters(
      mod_f,
      es_type = "eta",
      table_wide = TRUE
    ),
    statistic = "f",
    effsize.type = "eta"
  )

  expect_snapshot(select(df2, -expression))
  expect_snapshot(df2[["expression"]])
})

#' @title Expressions with statistics for tidy regression data frames
#' @name tidy_model_expressions
#'
#' @param ... Currently ignored.
#' @param data A tidy data frame from regression model object (see
#'   [`statsExpressions::tidy_model_parameters()`]).
#' @param statistic Which statistic is to be displayed (either `"t"` or `"f"`or
#'   `"z"` or `"chi"`) in the expression.
#' @inheritParams oneway_anova
#'
#' @details
#' When any of the necessary numeric column values (`estimate`, `statistic`,
#' `p.value`) are missing, for these rows, a `NULL` is returned instead of an
#' expression with empty strings.
#'
#' @autoglobal
#'
#' @examplesIf identical(Sys.getenv("NOT_CRAN"), "true")
#' # setup
#' set.seed(123)
#' library(statsExpressions)
#'
#' # extract a tidy data frame
#' df <- tidy_model_parameters(lm(wt ~ am * cyl, mtcars))
#'
#' # create a column containing expression; the expression will depend on `statistic`
#' tidy_model_expressions(df, statistic = "t")
#' tidy_model_expressions(df, statistic = "z")
#' tidy_model_expressions(df, statistic = "chi")
#'
#' # f-statistic (requires a data frame with `df`, `df.error`, and effect-size columns)
#' df_f <- tidy_model_parameters(
#'   aov(wt ~ cyl, mtcars),
#'   es_type = "omega",
#'   table_wide = TRUE
#' )
#' tidy_model_expressions(df_f, statistic = "f")
#' df_f_eta <- tidy_model_parameters(
#'   aov(wt ~ cyl, mtcars),
#'   es_type = "eta",
#'   table_wide = TRUE
#' )
#' tidy_model_expressions(df_f_eta, statistic = "f", effsize.type = "eta")
#'
#' @template citation
#'
#' @export
tidy_model_expressions <- function(
  data,
  statistic = NULL,
  digits = 2L,
  effsize.type = "omega",
  ...
) {
  # standardize the statistic naming
  statistic <- substring(tolower(statistic), 1L, 1L)

  # if any of the necessary numeric columns are missing, there shouldn't be an
  # expression corresponding to that row; convert the necessary columns to
  # character type for expression
  df_expr <- data |>
    filter(if_all(
      .cols = matches("estimate|statistic|std.error|p.value"),
      .fns = Negate(is.na)
    )) |>
    .data_to_char(digits)

  stat_type <- statistic

  es.text <- if (stat_type == "f") {
    switch(
      effsize.type,
      eta = list(quote(widehat(italic(eta)[p]^2))),
      list(quote(widehat(italic(omega)[p]^2)))
    )
  } else {
    list(quote(widehat(italic(beta))))
  }

  # nolint start: line_length_linter.
  stat_part <- switch(
    stat_type,
    t = "italic(t)('{df.error}')=='{statistic}'",
    z = "italic(z)=='{statistic}'",
    c = "italic(chi)^2*('{df.error}')=='{statistic}'",
    f = "italic(F)('{df}', '{df.error}')=='{statistic}'"
  )
  expr_template <- paste0(
    "list({es.text}=='{estimate}', ",
    stat_part,
    ", italic(p)=='{p.value}')"
  )

  df_expr <- df_expr |>
    mutate(
      expression = if (stat_type == "t") {
        case_when(
          df.error %in% c("NA", "Inf") ~ glue(
            "list({es.text}=='{estimate}', italic(t)=='{statistic}', italic(p)=='{p.value}')"
          ),
          .default = glue(expr_template)
        )
      } else {
        glue(expr_template)
      }
    )
  # nolint end

  # Replace `NA` with `NULL` to show nothing instead of an empty string ("")
  left_join(data, select(df_expr, term, expression), by = "term") |>
    .glue_to_expression()
}


#' @keywords internal
#' @noRd
.glue_to_expression <- function(data) {
  data |>
    rowwise() |>
    mutate(expression = list(parse_expr(expression))) |>
    ungroup() |> # convert from `expression` to `language`
    mutate(
      expression = case_when(
        is.na(unlist(expression)) ~ list(NULL),
        .default = unlist(expression)
      )
    ) |>
    .add_package_class()
}

#' @keywords internal
#' @noRd
.add_package_class <- function(data) {
  data <- as_tibble(data)
  class(data) <- c("statsExpressions", class(data))
  data
}

#' @title Data frame and expression for distribution properties
#' @name centrality_description
#'
#' @details
#'
#' This function describes a distribution for `y` variable for each level of the
#' grouping variable in `x` by a set of indices (e.g., measures of centrality,
#' dispersion, range, skewness, kurtosis, etc.). It additionally returns an
#' expression containing a specified centrality measure. The function internally
#' relies on [`datawizard::describe_distribution()`] function.
#'
#' @description
#' Parametric, non-parametric, robust, and Bayesian measures of centrality.
#'
#' @section Centrality measures:
#'
#' ```{r child="man/rmd-fragments/table_intro.Rmd"}
#' ```
#'
#' ```{r child="man/rmd-fragments/centrality_description.Rmd"}
#' ```
#'
#' @param x The grouping (or independent) variable in `data`.
#' @inheritParams oneway_anova
#' @param ... Currently ignored.
#'
#' @autoglobal
#'
#' @example man/examples/examples-centrality-description.R
#'
#' @template citation
#'
#' @export
centrality_description <- function(
  data,
  x,
  y,
  type = "parametric",
  conf.level = 0.95,
  tr = 0.2,
  digits = 2L,
  ...
) {
  # styler: off
  centrality <- recode_values(
    extract_stats_type(type),
    "parametric" ~ "mean",
    "nonparametric" ~ "median",
    "robust" ~ "trimmed",
    "bayes" ~ "MAP"
  )
  # styler: on

  select(data, {{ x }}, {{ y }}) |>
    filter(!if_any(everything(), is.na)) |>
    group_by({{ x }}) |>
    group_modify(
      .f = ~ standardize_names(
        data = datawizard::describe_distribution(
          x = pull(., {{ y }}),
          centrality = centrality,
          threshold = tr,
          verbose = FALSE,
          ci = conf.level
        ),
        style = "broom"
      )
    ) |>
    rename_all(~ gsub(".mean|.median|.trimmed|.map", "", .x)) |>
    ungroup() |>
    mutate(
      expression = glue(
        "list(widehat(mu)[{centrality}]=='{format_value(estimate, digits)}')"
      ),
      n.expression = paste0({{ x }}, "\n(n = ", .prettyNum(n.obs), ")")
    ) |>
    arrange({{ x }}) |>
    select({{ x }}, !!as.character(ensym(y)) := estimate, everything()) |>
    .glue_to_expression()
}

test_that(desc = "centrality description works as expected - no missing data", code = {
  set.seed(123)
  df <- purrr::pmap_dfr(
    .l = list(
      data = list(mtcars),
      x = alist(am),
      y = alist(wt),
      type = list("p", "np", "r", "b"),
      digits = 3L,
      conf.level = list(0.89, 0.99, 0.90, 0.50)
    ),
    .f = centrality_description
  )

  set.seed(123)
  expect_snapshot(select(df, -expression))
  expect_snapshot(df[["expression"]])
})

test_that(desc = "centrality description works as expected - missing data", code = {
  # some MAP estimates are different on macOS compared to windows and linux
  skip_on_os(c("windows", "linux"))

  set.seed(123)
  df_na <- purrr::pmap_dfr(
    .l = list(
      data = list(bugs_long),
      x = alist(gender),
      y = alist(desire),
      type = list("p", "np", "r", "b"),
      digits = 3L,
      conf.level = list(0.89, 0.99, 0.90, 0.50)
    ),
    .f = centrality_description
  )

  set.seed(123)
  expect_snapshot(select(df_na, -expression))
  expect_snapshot(df_na[["expression"]])
})


test_that(desc = "centrality description works when variable is named `variable`", code = {
  df_var <- dplyr::rename(mtcars, variable = cyl)

  set.seed(123)
  res <- suppressWarnings(centrality_description(df_var, variable, wt))

  set.seed(123)
  expect_snapshot(select(res, -expression))
  expect_snapshot(res[["expression"]])
})

#' @title Template for expressions with statistical details
#' @name add_expression_col
#'
#' @description
#'
#' Creates an expression from a data frame containing statistical details.
#' Ideally, this data frame would come from having run `tidy_model_parameters()`
#' on your model object.
#'
#' This function is currently **not** stable and should not be used outside of
#' this package context.
#'
#' @param data A data frame containing details from the statistical analysis
#'   and should contain some or all of the the following columns:
#' - *statistic*: the numeric value of a statistic.
#' - *df.error*: the numeric value of a parameter being modeled (often degrees
#' of freedom for the test); irrelevant. if there are no degrees of freedom.
#' - *df*: relevant if the statistic in question has two degrees of freedom.
#' - *p.value*: the two-sided *p*-value associated with observed statistic.
#' - *method*: method describing the test carried out.
#' - *effectsize*: name of the effect size (if not present, same as `method`).
#' - *estimate*: estimated value of the effect size.
#' - *conf.level*: width for the confidence intervals.
#' - *conf.low*: lower bound for effect size estimate.
#' - *conf.high*: upper bound for effect size estimate.
#' - *bf10*: Bayes Factor value (if `bayesian = TRUE`).
#' @param statistic.text A character that specifies the relevant test statistic.
#'   For example, for tests with *t*-statistic, `statistic.text = "t"`.
#' @param effsize.text A character that specifies the relevant effect size or
#'   posterior estimate.
#' @param digits,digits.df,digits.df.error Number of decimal places to display
#'   for the parameters (default: `0L`).
#' @param n An integer specifying the sample size used for the test.
#' @param n.text A character that specifies the design, which will determine
#'   what the `n` stands for. It defaults to `quote(italic("n")["pairs"])` if
#'   `paired = TRUE`, and to `quote(italic("n")["obs"])` if `paired = FALSE`. If
#'   you wish to customize this further, you will need to provide object of
#'   `language` type.
#' @param effsize.text A character that specifies the relevant effect size.
#' @param prior.type The type of prior.
#' @param ... Currently ignored.
#' @inheritParams oneway_anova
#' @inheritParams long_to_wide_converter
#'
#' @autoglobal
#'
#' @examples
#' set.seed(123)
#'
#' # creating a data frame with stats results
#' stats_df <- cbind.data.frame(
#'   statistic  = 5.494,
#'   df         = 29.234,
#'   p.value    = 0.00001,
#'   estimate   = -1.980,
#'   conf.level = 0.95,
#'   conf.low   = -2.873,
#'   conf.high  = -1.088,
#'   method     = "Student's t-test"
#' )
#'
#' # expression for *t*-statistic with Cohen's *d* as effect size
#' # note that the plotmath expressions need to be quoted
#' add_expression_col(
#'   data           = stats_df,
#'   statistic.text = list(quote(italic("t"))),
#'   effsize.text   = list(quote(italic("d"))),
#'   n              = 32L,
#'   n.text         = list(quote(italic("n")["no.obs"])),
#'   digits         = 3L,
#'   digits.df      = 3L
#' )
#'
#' @template citation
#'
#' @export
add_expression_col <- function(
  data,
  paired = FALSE,
  statistic.text = NULL,
  effsize.text = NULL,
  prior.type = NULL,
  n = NULL,
  n.text = ifelse(
    paired,
    list(quote(italic("n")["pairs"])),
    list(quote(italic("n")["obs"]))
  ),
  digits = 2L,
  digits.df = 0L,
  digits.df.error = digits.df,
  ...
) {
  if (!"n.obs" %in% colnames(data)) {
    data <- mutate(data, n.obs = n)
  }
  if (!"effectsize" %in% colnames(data)) {
    data <- mutate(data, effectsize = method)
  }
  data <- rename_with(data, recode, bayes.factor = "bf10")

  bayesian <- any("bf10" == colnames(data))
  no.parameters <- sum("df.error" %in% names(data) + "df" %in% names(data))

  # special case for Bayesian contingency table analysis
  if (bayesian && grepl("contingency", data$method[[1L]], fixed = TRUE)) {
    data <- mutate(data, effectsize = "Cramers_v")
  }

  # dealing with exactly 0 p-values
  if ("p.value" %in% colnames(data)) {
    data <- data |>
      mutate(p.value = if_else(p.value == 0, .Machine$double.xmin, p.value))
  }

  df_expr <- data |> # convert needed columns to character type
    .data_to_char(digits, digits.df, digits.df.error) |>
    mutate(
      statistic.text = statistic.text %||%
        extract_statistic_text(tolower(method)),
      es.text = effsize.text %||% extract_estimate_type(tolower(effectsize)),
      prior.distribution = prior_switch(tolower(method)),
      n.obs = .prettyNum(n.obs)
    )

  # Bayesian analysis ------------------------------

  if (bayesian) {
    df_expr <- df_expr |>
      mutate(
        expression = glue(
          "list(
            log[e]*(BF['01'])=='{format_value(-log(bf10), digits)}',
            {es.text}^'posterior'=='{estimate}',
            CI['{conf.level}']^{conf.method}~'['*'{conf.low}', '{conf.high}'*']',
            {prior.distribution}=='{prior.scale}')"
        )
      )
  }

  # 0 degrees of freedom --------------------

  if (!bayesian && no.parameters == 0L) {
    df_expr <- df_expr |>
      mutate(
        expression = glue(
          "list(
            {statistic.text}=='{statistic}', italic(p)=='{p.value}',
            {es.text}=='{estimate}', CI['{conf.level}']~'['*'{conf.low}', '{conf.high}'*']',
            {n.text}=='{n.obs}')"
        )
      )
  }

  # 1 degree of freedom --------------------

  if (!bayesian && no.parameters == 1L) {
    if ("df" %in% colnames(df_expr)) {
      df_expr <- mutate(df_expr, df.error = df)
    } # for chi-squared statistic

    df_expr <- df_expr |>
      mutate(
        expression = glue(
          "list(
            {statistic.text}*'('*{df.error}*')'=='{statistic}', italic(p)=='{p.value}',
            {es.text}=='{estimate}', CI['{conf.level}']~'['*'{conf.low}', '{conf.high}'*']',
            {n.text}=='{n.obs}')"
        )
      )
  }

  # 2 degrees of freedom -----------------

  if (!bayesian && no.parameters == 2L) {
    df_expr <- df_expr |>
      mutate(
        expression = glue(
          "list(
            {statistic.text}({df}, {df.error})=='{statistic}', italic(p)=='{p.value}',
            {es.text}=='{estimate}', CI['{conf.level}']~'['*'{conf.low}', '{conf.high}'*']',
            {n.text}=='{n.obs}')"
        )
      )
  }

  # convert `expression` to `language`
  df_expr <- .glue_to_expression(df_expr)

  data |>
    relocate(matches("^effectsize$"), .before = matches("^estimate$")) |>
    mutate(expression = df_expr$expression) |>
    .add_package_class()
}


# utilities -----------------

#' Helper function to convert certain numeric columns to character type
#' @noRd
.data_to_char <- function(
  data,
  digits = 2L,
  digits.df = 0L,
  digits.df.error = 0L
) {
  data |>
    mutate(
      across(
        .cols = matches("^est|^sta|p.value|.scale$|.low$|.high$|^log"),
        .fns = \(x) .to_char(x, digits)
      ),
      across(.cols = matches("^df$"), .fns = \(x) .to_char(x, digits.df)),
      across(.cols = matches("^df.error$"), .fns = \(x) {
        .to_char(x, digits.df.error)
      }),
      across(.cols = matches("^conf.level$"), .fns = \(x) paste0(x * 100L, "%"))
    )
}

#' @note `decimal.mark` is pinned to `"."` to avoid a clash with `big.mark`
#'   when users set `options(OutDec = ",")`.
#' @noRd
.prettyNum <- function(x) {
  format_value(x, digits = 0, big_mark = ",", decimal_point = ".")
}

#' @note `decimal_point` is pinned to `"."` because plotmath parses `,` as a
#'   list separator, so expressions must use `.` regardless of `options(OutDec)`.
#' @noRd
.to_char <- function(x, digits = 2L) {
  format_value(x, digits, missing = "NA", decimal_point = ".")
}

#' @title Two-sample tests
#' @name two_sample_test
#'
#' @description
#' Parametric, non-parametric, robust, and Bayesian two-sample tests.
#'
#' @inheritParams long_to_wide_converter
#' @inheritParams extract_stats_type
#' @inheritParams one_sample_test
#' @inheritParams oneway_anova
#' @inheritParams stats::t.test
#' @inheritParams add_expression_col
#'
#' @section Two-sample tests:
#'
#' ```{r child="man/rmd-fragments/table_intro.Rmd"}
#' ```
#'
#' ```{r child="man/rmd-fragments/two_sample_test.Rmd"}
#' ```
#'
#' @returns
#'
#' ```{r child="man/rmd-fragments/return.Rmd"}
#' ```
#'
#' @autoglobal
#'
#' @examplesIf identical(Sys.getenv("NOT_CRAN"), "true")
#' # ----------------------- within-subjects -------------------------------------
#'
#' # data
#' df <- dplyr::filter(bugs_long, condition %in% c("LDLF", "LDHF"))
#'
#' # for reproducibility
#' set.seed(123)
#'
#' # ----------------------- parametric ---------------------------------------
#'
#' two_sample_test(
#'   df,
#'   condition,
#'   desire,
#'   subject.id = subject,
#'   paired = TRUE,
#'   type = "parametric"
#' )
#'
#' # ----------------------- non-parametric -----------------------------------
#'
#' two_sample_test(
#'   df,
#'   condition,
#'   desire,
#'   subject.id = subject,
#'   paired = TRUE,
#'   type = "nonparametric"
#' )
#'
#' # ----------------------- robust --------------------------------------------
#'
#' two_sample_test(
#'   df,
#'   condition,
#'   desire,
#'   subject.id = subject,
#'   paired = TRUE,
#'   type = "robust"
#' )
#'
#' # ----------------------- Bayesian ---------------------------------------
#'
#' two_sample_test(
#'   df,
#'   condition,
#'   desire,
#'   subject.id = subject,
#'   paired = TRUE,
#'   type = "bayes"
#' )
#'
#' # ----------------------- between-subjects -------------------------------------
#'
#' # for reproducibility
#' set.seed(123)
#'
#' # ----------------------- parametric ---------------------------------------
#'
#' # unequal variance
#' two_sample_test(ToothGrowth, supp, len, type = "parametric")
#'
#' # equal variance
#' two_sample_test(ToothGrowth, supp, len, type = "parametric", var.equal = TRUE)
#'
#' # biased (Cohen's d) effect size
#' two_sample_test(ToothGrowth, supp, len, type = "parametric", effsize.type = "d")
#'
#' # ----------------------- non-parametric -----------------------------------
#'
#' two_sample_test(ToothGrowth, supp, len, type = "nonparametric")
#'
#' # ----------------------- robust --------------------------------------------
#'
#' two_sample_test(ToothGrowth, supp, len, type = "robust")
#'
#' # ----------------------- Bayesian ---------------------------------------
#'
#' two_sample_test(ToothGrowth, supp, len, type = "bayes")
#'
#' @template citation
#'
#' @export
two_sample_test <- function(
  data,
  x,
  y,
  subject.id = NULL,
  type = "parametric",
  paired = FALSE,
  alternative = "two.sided",
  digits = 2L,
  conf.level = 0.95,
  effsize.type = "g",
  var.equal = FALSE,
  bf.prior = 0.707,
  tr = 0.2,
  nboot = 100L,
  exact = FALSE,
  ...
) {
  # data -------------------------------------------

  type <- extract_stats_type(type)
  x <- ensym(x)
  y <- ensym(y)

  data <- long_to_wide_converter(
    data,
    x = {{ x }},
    y = {{ y }},
    subject.id = {{ subject.id }},
    paired = paired,
    spread = ifelse(type %in% c("bayes", "robust"), paired, TRUE)
  )

  # parametric ---------------------------------------

  if (type == "parametric") {
    digits.df <- ifelse(paired || var.equal, 0L, digits)
    .f <- stats::t.test
    .f.es <- switch(
      match.arg(effsize.type, c("g", "d", "unbiased", "biased")),
      g = ,
      unbiased = effectsize::hedges_g,
      d = ,
      biased = effectsize::cohens_d
    )
  }

  # non-parametric ------------------------------------

  if (type == "nonparametric") {
    .f <- stats::wilcox.test
    .f.es <- effectsize::rank_biserial
  }

  if (type %in% c("parametric", "nonparametric")) {
    .f.args <- list(
      x = data[[2L]],
      y = data[[3L]],
      paired = paired,
      alternative = alternative
    )
    stats_df <- exec(.f, !!!.f.args, var.equal = var.equal, exact = exact) |>
      tidy_model_parameters()
    ez_df <- exec(
      .f.es,
      !!!.f.args,
      pooled_sd = FALSE,
      ci = conf.level,
      verbose = FALSE
    ) |>
      tidy_model_effectsize()
  }

  # robust ---------------------------------------

  if (type == "robust") {
    digits.df <- ifelse(paired, 0L, digits)

    # styler: off
    if (!paired) {
      .f <- WRS2::yuen
      .f.es <- WRS2::akp.effect
    }
    if (paired) {
      .f <- WRS2::yuend
      .f.es <- WRS2::dep.effect
    }

    .f.args <- list(
      formula = new_formula(y, x),
      data = data,
      x = data[[2L]],
      y = data[[3L]]
    )
    .f.es.args <- list(
      EQVAR = FALSE,
      nboot = nboot,
      alpha = 1.0 - conf.level,
      tr = tr
    )

    ez_df <- tidy_model_parameters(
      exec(.f.es, !!!.f.args, !!!.f.es.args),
      keep = "AKP"
    )
    stats_df <- tidy_model_parameters(exec(.f, !!!.f.args, !!!.f.es.args))
    # styler: on
  }

  if (type != "bayes") {
    stats_df <- bind_cols(
      select(stats_df, -matches("^est|^eff|conf|^ci")),
      select(ez_df, -matches("term"))
    )
  }

  # Bayesian ---------------------------------------

  if (type == "bayes") {
    # styler: off
    if (!paired) {
      .f.args <- list(
        formula = new_formula(y, x),
        data = as.data.frame(data),
        paired = paired
      )
    }
    if (paired) {
      .f.args <- list(x = data[[2L]], y = data[[3L]], paired = paired)
    }
    # styler: on

    stats_df <- exec(BayesFactor::ttestBF, rscale = bf.prior, !!!.f.args) |>
      tidy_model_parameters(ci = conf.level)
  }

  # expression ---------------------------------------

  add_expression_col(
    data = if (type == "bayes") {
      stats_df
    } else {
      .standardize_two_sample_terms(stats_df, as_name(x), as_name(y))
    },
    paired = paired,
    n = ifelse(paired, length(unique(data$.rowid)), nrow(data)),
    digits = digits,
    digits.df = digits.df
  )
}

#' @noRd
.standardize_two_sample_terms <- function(data, x_name, y_name) {
  data |>
    mutate(
      across(matches("^parameter1$|^term$"), \(x) y_name),
      across(matches("^parameter2$|^group$"), \(x) x_name)
    )
}

test_that(desc = "parametric t-test works (between-subjects without NAs)", code = {
  set.seed(123)
  df1 <- suppressWarnings(
    two_sample_test(
      ToothGrowth,
      x = supp,
      y = len,
      effsize.type = "d",
      var.equal = TRUE,
      conf.level = 0.99,
      digits = 5
    )
  )

  set.seed(123)
  expect_snapshot(select(df1, -expression))
  expect_snapshot(df1[["expression"]])
})

test_that(desc = "parametric t-test works (between-subjects with NAs)", code = {
  set.seed(123)
  df1 <- suppressWarnings(
    two_sample_test(
      ToothGrowth,
      x = supp,
      y = len,
      effsize.type = "g",
      var.equal = FALSE,
      conf.level = 0.90,
      digits = 3
    )
  )

  set.seed(123)
  expect_snapshot(select(df1, -expression))
  expect_snapshot(df1[["expression"]])
})

test_that(desc = "parametric t-test works (within-subjects without NAs)", code = {
  set.seed(123)
  df1 <- suppressWarnings(two_sample_test(
    data = filter(iris_long, condition %in% c("Sepal.Length", "Sepal.Width")),
    x = condition,
    y = value,
    paired = TRUE,
    effsize.type = "g",
    digits = 4L,
    conf.level = 0.50
  ))

  set.seed(123)
  expect_snapshot(select(df1, -expression))
  expect_snapshot(df1[["expression"]])
})


test_that(desc = "parametric t-test works (within-subjects with NAs)", code = {
  set.seed(123)
  df1 <- two_sample_test(
    data = filter(bugs_long, condition %in% c("HDHF", "HDLF")),
    x = condition,
    y = desire,
    paired = TRUE,
    effsize.type = "d",
    digits = 3
  )

  set.seed(123)
  expect_snapshot(select(df1, -expression))
  expect_snapshot(df1[["expression"]])
})

test_that(desc = "works with subject id", code = {
  df <- filter(data_with_subid, condition %in% c(1, 5))

  set.seed(123)
  expr1 <- two_sample_test(
    data = df,
    x = condition,
    y = score,
    subject.id = id,
    paired = TRUE
  )

  set.seed(123)
  expr2 <- two_sample_test(
    data = arrange(df, id),
    x = condition,
    y = score,
    paired = TRUE
  )

  expect_identical(expr1, expr2)
})

# within-subjects ------------------------------------------------------------

test_that(desc = "t_robust - within-subjects - without NAs", code = {
  set.seed(123)
  df1 <- two_sample_test(
    type = "r",
    data = filter(
      iris_long,
      condition %in% c("Sepal.Length", "Sepal.Width")
    ),
    x = condition,
    y = value,
    paired = TRUE,
    digits = 4L
  )

  set.seed(123)
  expect_snapshot(select(df1, -expression))
  expect_snapshot(df1[["expression"]])
})

test_that(desc = "t_robust - within-subjects - with NAs", code = {
  set.seed(123)
  df1 <- two_sample_test(
    type = "r",
    data = filter(bugs_long, condition %in% c("HDHF", "HDLF")),
    x = condition,
    y = desire,
    paired = TRUE,
    digits = 3L
  )

  set.seed(123)
  expect_snapshot(select(df1, -expression))
  expect_snapshot(df1[["expression"]])
})


test_that(desc = "t_robust - between-subjects - without NAs", code = {
  # between-subjects ------------------------------------------------------

  set.seed(123)
  df1 <- two_sample_test(
    type = "r",
    data = mtcars,
    x = am,
    y = wt,
    paired = FALSE,
    conf.level = 0.99,
    digits = 3
  )

  set.seed(123)
  expect_snapshot(select(df1, -expression))
  expect_snapshot(df1[["expression"]])
})

test_that(desc = "t_robust - between-subjects - with NAs", code = {
  set.seed(123)
  df1 <- two_sample_test(
    type = "r",
    data = filter(msleep, vore %in% c("carni", "herbi")),
    x = vore,
    y = brainwt,
    paired = FALSE,
    conf.level = 0.90,
    digits = 4L
  )

  set.seed(123)
  expect_snapshot(select(df1, -expression))
  expect_snapshot(df1[["expression"]])
})

test_that(desc = "works with subject id", code = {
  df <- filter(data_with_subid, condition %in% c(1, 5))

  set.seed(123)
  expr1 <- two_sample_test(
    type = "r",
    data = df,
    x = condition,
    y = score,
    subject.id = id,
    paired = TRUE
  )

  set.seed(123)
  expr2 <- two_sample_test(
    type = "r",
    data = arrange(df, id),
    x = condition,
    y = score,
    paired = TRUE
  )

  expect_identical(expr1, expr2)
})

test_that(desc = "t_nonparametric works - between-subjects design", code = {
  # between-subjects design -----------------------------------------------

  set.seed(123)
  df <- two_sample_test(
    type = "np",
    data = mtcars,
    x = am,
    y = wt,
    digits = 3L,
    conf.level = 0.90
  )

  set.seed(123)
  expect_snapshot(select(df, -expression))
  expect_snapshot(df[["expression"]])
})

test_that(desc = "nonparametric works - within-subjects design", code = {
  # within-subjects design -----------------------------------------------

  set.seed(123)
  df <- suppressWarnings(two_sample_test(
    data = filter(bugs_long, condition %in% c("HDHF", "HDLF")),
    x = condition,
    y = desire,
    type = "np",
    digits = 5L,
    conf.level = 0.99,
    paired = TRUE
  ))

  set.seed(123)
  expect_snapshot(select(df, -expression))
  expect_snapshot(df[["expression"]])
})

test_that(desc = "works with subject id", code = {
  df <- filter(data_with_subid, condition %in% c(1, 5))

  set.seed(123)
  expr1 <- two_sample_test(
    type = "np",
    data = df,
    x = condition,
    y = score,
    subject.id = id,
    paired = TRUE
  )

  set.seed(123)
  expr2 <- two_sample_test(
    type = "np",
    data = arrange(df, id),
    x = condition,
    y = score,
    paired = TRUE
  )

  expect_identical(expr1, expr2)
})

test_that(desc = "bayesian (independent samples t-test)", code = {
  set.seed(123)
  df <- two_sample_test(
    type = "bayes",
    data = ToothGrowth,
    x = supp,
    y = len,
    paired = FALSE,
    conf.level = 0.99
  )

  expect_snapshot(df[["expression"]])
})

test_that(desc = "bayesian (paired t-test)", code = {
  dat_tidy <- dplyr::filter(bugs_long, condition %in% c("HDLF", "HDHF"))

  set.seed(123)
  df_results <- two_sample_test(
    type = "bayes",
    data = dat_tidy,
    x = "condition",
    y = desire,
    paired = TRUE,
    bf.prior = 0.8
  )

  expect_equal(df_results$bf10[[1]], 40.36079, tolerance = 0.001)

  set.seed(123)
  df <- two_sample_test(
    type = "bayes",
    data = dat_tidy,
    x = "condition",
    y = desire,
    paired = TRUE,
    bf.prior = 0.8
  )

  expect_snapshot(df[["expression"]])
})

test_that(desc = "works with subject id", code = {
  df <- filter(data_with_subid, condition %in% c(1, 5))

  set.seed(123)
  expr1 <- two_sample_test(
    type = "bayes",
    data = df,
    x = condition,
    y = score,
    subject.id = id,
    paired = TRUE
  )

  set.seed(123)
  expr2 <- two_sample_test(
    type = "bayes",
    data = arrange(df, id),
    x = condition,
    y = score,
    paired = TRUE
  )

  expect_identical(expr1, expr2)
})

knitr::opts_chunk$set(
  collapse = TRUE,
  comment = "#>",
  warning = FALSE,
  message = FALSE,
  out.width = "100%",
  dpi = 300
)

# needed libraries
library(dplyr)
library(statsExpressions)

options(lifecycle_verbosity = "warning")

# for reproducibility
set.seed(123)

#' @name extract_stats_type
#' @title Switch the type of statistics.
#'
#' @description
#'
#' Relevant mostly for `{ggstatsplot}` and `{statsExpressions}` packages, where
#' different statistical approaches are supported via this argument: parametric,
#' non-parametric, robust, and Bayesian. This switch function converts strings
#' entered by users to a common pattern for convenience.
#'
#' @param type A character specifying the type of statistical approach:
#'   - `"parametric"`
#'   - `"nonparametric"`
#'   - `"robust"`
#'   - `"bayes"`
#'
#' You can specify just the initial letter.
#'
#' @autoglobal
#'
#' @examples
#' extract_stats_type("p")
#' extract_stats_type("bf")
#' @export
# styler: off
extract_stats_type <- function(type) {
  case_when(
    grepl("^n", type) ~ "nonparametric",
    grepl("^r", type) ~ "robust",
    grepl("^b", type) ~ "bayes",
    TRUE ~ "parametric"
  )
}

#' @rdname extract_stats_type
#' @export
stats_type_switch <- extract_stats_type

#' @noRd
extract_estimate_type <- function(x) {
  case_when(
    .grepl("pearson's c", x) ~ list(quote(widehat(italic("C"))["Pearson"])),
    .grepl("cohen's d", x) ~ list(quote(widehat(italic("d"))["Cohen"])),
    .grepl("hedges' g", x) ~ list(quote(widehat(italic("g"))["Hedges"])),
    .grepl("biserial", x) ~ list(quote(
      widehat(italic("r"))["biserial"]^"rank"
    )),
    .grepl("cramer", x) ~ list(quote(widehat(italic("V"))["Cramer"])),
    .grepl("cohen's g", x) ~ list(quote(widehat(italic("g"))["Cohen"])),
    .grepl("r-squared", x) ~ list(quote(widehat(italic(R^"2"))["Bayesian"])),
    .grepl("spearman", x) ~ list(quote(widehat(rho)["Spearman"])),
    grepl("^bayesian pearson", x) ~ list(quote(widehat(rho)["Pearson"])),
    grepl("posterior|t-", x) ~ list(quote(widehat(delta)["difference"])),
    grepl("difference$", x) ~ list(quote(widehat(delta)["R"]^"AKP")),
    grepl("average$", x) ~ list(quote(widehat(delta)["R-avg"]^"AKP")),
    grepl("^eta2", x) ~ list(quote(widehat(eta["p"]^2))),
    grepl("^omega2", x) ~ list(quote(widehat(omega["p"]^2))),
    grepl("^trimmed", x) ~ list(quote(widehat(mu)["trimmed"])),
    grepl("^epsilon2", x) ~ list(quote(widehat(epsilon)["ordinal"]^2)),
    grepl("^explanatory", x) ~ list(quote(widehat(xi))),
    grepl("^meta", x) ~ list(quote(widehat(beta)["summary"]^"meta")),
    grepl("^pearson", x) ~ list(quote(widehat(italic("r"))["Pearson"])),
    grepl("^winsor", x) ~ list(quote(widehat(italic("r"))["Winsorized"])),
    grepl("^kendall", x) ~ list(quote(widehat(italic("W"))["Kendall"])),
    TRUE ~ list(NULL)
  )
}

#' @noRd
extract_statistic_text <- function(x) {
  case_when(
    grepl("^welch", x) ~ list(quote(italic("t")["Welch"])),
    grepl("afex| of means$", x) ~ list(quote(italic("F")["Fisher"])),
    grepl("^boot", x) ~ list(quote(italic("t")["bootstrapped"])),
    grepl("^spearman", x) ~ list(quote(italic("S"))),
    grepl("t-test$|correlation$", x) ~ list(quote(italic("t")["Student"])),
    .grepl("wilcoxon rank", x) ~ list(quote(italic("W")["Mann-Whitney"])),
    .grepl("wilcoxon signed", x) ~ list(quote(italic("V")["Wilcoxon"])),
    .grepl("variances", x) ~ list(quote(italic("F")["Welch"])),
    .grepl("yuen", x) ~ list(quote(italic("t")["Yuen"])),
    .grepl("heteroscedastic", x) ~ list(quote(italic("F")["trimmed-means"])),
    .grepl("meta", x) ~ list(quote(italic("z"))),
    .grepl("friedman", x) ~ list(quote(chi["Friedman"]^2)),
    .grepl("kruskal", x) ~ list(quote(chi["Kruskal-Wallis"]^2)),
    .grepl("probabilities", x) ~ list(quote(chi["gof"]^2)),
    .grepl("pearson's chi", x) ~ list(quote(chi["Pearson"]^2)),
    .grepl("mcnemar's chi", x) ~ list(quote(chi["McNemar"]^2)),
    TRUE ~ list(NULL)
  )
}

#' @noRd
prior_switch <- function(x) {
  case_when(
    .grepl("contingency", x) ~ list(quote(italic("a")["Gunel-Dickey"])),
    .grepl("correlation", x) ~ list(quote(italic("r")["beta"]^"JZS")),
    TRUE ~ list(quote(italic("r")["Cauchy"]^"JZS"))
  )
}

#' @note Don't curry using `purrr::partial()` because it causes `"Found a .Internal call"` warning.
#' @noRd
.grepl <- function(pattern, x) grepl(pattern, x, fixed = TRUE)

# styler: on

test_that(desc = "switch for stats type works", code = {
  expect_identical(extract_stats_type("p"), "parametric")
  expect_identical(extract_stats_type("pearson"), "parametric")
  expect_identical(extract_stats_type("non-parametric"), "nonparametric")
  expect_identical(extract_stats_type("np"), "nonparametric")
  expect_identical(extract_stats_type("r"), "robust")
  expect_identical(extract_stats_type("bf"), "bayes")
  expect_identical(extract_stats_type("xxx"), "parametric")
})

#' @title Convert long/tidy data frame to wide format
#' @name long_to_wide_converter
#'
#' @description
#'
#' This conversion is helpful mostly for repeated measures design, where
#' removing `NA`s by participant can be a bit tedious.
#'
#' @param data A data frame (or a tibble) from which variables specified are to
#'   be taken. Other data types (e.g., matrix,table, array, etc.) will **not**
#'   be accepted. Additionally, grouped data frames from `{dplyr}` should be
#'   ungrouped before they are entered as `data`.
#' @param x The grouping (or independent) variable from `data`. In case of a
#'   repeated measures or within-subjects design, if `subject.id` argument is
#'   not available or not explicitly specified, the function assumes that the
#'   data has already been sorted by such an id by the user and creates an
#'   internal identifier. So if your data is **not** sorted, the results *can*
#'   be inaccurate when there are more than two levels in `x` and there are
#'   `NA`s present. The data is expected to be sorted by user in
#'   subject-1, subject-2, ..., pattern.
#' @param y The response (or outcome or dependent) variable from `data`.
#' @param subject.id Relevant in case of a repeated measures or within-subjects
#'   design (`paired = TRUE`, i.e.), it specifies the subject or repeated
#'   measures identifier. **Important**: Note that if this argument is `NULL`
#'   (which is the default), the function assumes that the data has already been
#'   sorted by such an id by the user and creates an internal identifier. So if
#'   your data is **not** sorted and you leave this argument unspecified, the
#'   results *can* be inaccurate when there are more than two levels in `x` and
#'   there are `NA`s present.
#' @param paired Logical that decides whether the experimental design is
#'   repeated measures/within-subjects or between-subjects. The default is
#'   `FALSE`.
#' @param spread Logical that decides whether the data frame needs to be
#'   converted from long/tidy to wide (default: `TRUE`).
#' @param ... Currently ignored.
#'
#' @returns A data frame with `NA`s removed while respecting the
#'   between-or-within-subjects nature of the dataset.
#'
#' @autoglobal
#'
#' @examples
#' # for reproducibility
#' library(statsExpressions)
#' set.seed(123)
#'
#' # repeated measures design
#' long_to_wide_converter(
#'   bugs_long,
#'   condition,
#'   desire,
#'   subject.id = subject,
#'   paired = TRUE
#' )
#'
#' # independent measures design
#' long_to_wide_converter(mtcars, cyl, wt, paired = FALSE)
#'
#' @template citation
#'
#' @export
long_to_wide_converter <- function(
  data,
  x,
  y,
  subject.id = NULL,
  paired = TRUE,
  spread = TRUE,
  ...
) {
  data <- data |>
    select({{ x }}, {{ y }}, .rowid = {{ subject.id }}) |>
    mutate({{ x }} := droplevels(as.factor({{ x }}))) |>
    arrange({{ x }})

  if (!".rowid" %in% names(data)) {
    if (paired) {
      data <- group_by(data, {{ x }})
    }
    data <- mutate(data, .rowid = row_number())
  }

  data <- data |>
    ungroup() |>
    filter(!anyNA(pick({{ x }}, {{ y }})), .by = .rowid)

  # convert to wide?
  if (spread) {
    data <- tidyr::pivot_wider(
      data,
      names_from = {{ x }},
      values_from = {{ y }}
    )
  }

  as_tibble(relocate(data, .rowid) |> arrange(.rowid))
}

withr::local_options(list(tibble.width = Inf))

test_that(desc = "long_to_wide_converter works - spread true", code = {
  skip_if(
    grepl("Under development", R.version$status, fixed = TRUE),
    "Skipping on R-devel due to summary() format changes"
  )

  # data without NAs ------------------------------

  # within-subjects
  set.seed(123)
  df1 <- long_to_wide_converter(
    data = iris_long,
    x = condition,
    y = value
  )

  # between-subjects
  set.seed(123)
  df2 <- long_to_wide_converter(
    data = mtcars,
    x = am,
    y = wt,
    paired = FALSE
  )

  # data with NAs ------------------------------

  # within-subjects
  set.seed(123)
  df3 <- long_to_wide_converter(
    data = bugs_long,
    x = condition,
    y = desire,
    paired = TRUE
  )

  # between-subjects
  set.seed(123)
  df4 <- long_to_wide_converter(
    data = msleep,
    x = vore,
    y = brainwt,
    paired = FALSE
  )

  # checking datasets
  set.seed(123)
  expect_snapshot(purrr::walk(list(df1, df2, df3, df4), dplyr::glimpse))
  expect_snapshot(purrr::map(list(df1, df2, df3, df4), summary))
})


test_that(desc = "long_to_wide_converter works - spread false", code = {
  # ----------------------- data without NAs ------------------------------

  # within-subjects
  set.seed(123)
  df1 <- long_to_wide_converter(
    data = iris_long,
    x = condition,
    y = value,
    spread = FALSE
  )

  # between-subjects
  set.seed(123)
  df2 <- long_to_wide_converter(
    data = mtcars,
    x = am,
    y = wt,
    paired = FALSE,
    spread = FALSE
  )

  # -------------------------- data with NAs ------------------------------

  # within-subjects
  set.seed(123)
  df3 <- long_to_wide_converter(
    data = bugs_long,
    x = condition,
    y = desire,
    paired = TRUE,
    spread = FALSE
  )

  # between-subjects
  set.seed(123)
  df4 <- long_to_wide_converter(
    data = msleep,
    x = vore,
    y = brainwt,
    paired = FALSE,
    spread = FALSE
  )

  set.seed(123)
  expect_snapshot(purrr::walk(list(df1, df2, df3, df4), dplyr::glimpse))
  expect_snapshot(purrr::map(list(df1, df2, df3, df4), summary))
})

# with .rowid - without NA ---------------------------------------------

test_that(desc = "with .rowid - without NA", code = {
  df_original <- structure(
    list(
      score = c(90, 90, 72.5, 45),
      condition = structure(
        c(1L, 2L, 2L, 1L),
        .Label = c("4", "5"),
        class = "factor"
      ),
      id = c(1L, 2L, 1L, 2L)
    ),
    row.names = c(NA, -4L),
    class = c("tbl_df", "tbl", "data.frame")
  )

  df_arranged <- arrange(df_original, id)

  expect_identical(
    long_to_wide_converter(df_arranged, condition, score),
    long_to_wide_converter(df_original, condition, score, id)
  )

  expect_identical(
    arrange(
      long_to_wide_converter(df_arranged, condition, score, spread = FALSE),
      .rowid
    ),
    arrange(
      long_to_wide_converter(df_original, condition, score, id, spread = FALSE),
      .rowid
    )
  )
})


# with .rowid - with NA ---------------------------------------------

test_that(desc = "with .rowid - with NA", code = {
  df_original <- bugs_long
  df_arranged <- arrange(bugs_long, subject)

  expect_identical(
    select(long_to_wide_converter(df_arranged, condition, desire), -.rowid),
    select(
      long_to_wide_converter(df_original, condition, desire, subject),
      -.rowid
    )
  )

  expect_identical(
    select(
      long_to_wide_converter(df_arranged, condition, desire, spread = FALSE),
      -.rowid
    ),
    select(
      long_to_wide_converter(
        df_original,
        condition,
        desire,
        subject,
        spread = FALSE
      ),
      -.rowid
    )
  )
})


# NA in subject.id should not drop rows with complete x/y ----------------

test_that("NA in subject.id does not drop rows with complete measurements", {
  df <- dplyr::tibble(
    id = c(1L, 1L, NA_integer_, NA_integer_),
    group = c("a", "b", "a", "b"),
    value = c(10, 20, 30, 40)
  )

  result <- long_to_wide_converter(
    df,
    x = group,
    y = value,
    subject.id = id,
    paired = TRUE,
    spread = FALSE
  )

  expect_identical(nrow(result), 4L)
})

#' @title Random-effects meta-analysis
#' @name meta_analysis
#'
#' @description
#' Parametric, non-parametric, robust, and Bayesian random-effects meta-analysis.
#'
#' @param data A data frame. It **must** contain columns named `estimate` (effect
#'   sizes or outcomes)  and `std.error` (corresponding standard errors). These
#'   two columns will be used:
#'   - as `yi`  and `sei` arguments in [`metafor::rma()`] (for **parametric** test)
#'   - as `yi`  and `sei` arguments in [`metaplus::metaplus()`] (for **robust** test)
#'   - as `y` and `SE` arguments in [`metaBMA::meta_random()`] (for **Bayesian** test)
#' @inheritParams one_sample_test
#' @inheritParams metaplus::metaplus
#' @inheritParams oneway_anova
#' @param ... Additional arguments passed to the respective meta-analysis
#'   function.
#'
#' @section Random-effects meta-analysis:
#'
#' ```{r child="man/rmd-fragments/table_intro.Rmd"}
#' ```
#'
#' ```{r child="man/rmd-fragments/corr_test.Rmd"}
#' ```
#'
#' @returns
#'
#' ```{r child="man/rmd-fragments/return.Rmd"}
#' ```
#'
#' @note
#'
#' **Important**: The function assumes that you have already downloaded the
#' needed package (`{metafor}`, `{metaplus}`, or `{metaBMA}`) for meta-analysis.
#' If they are not available, you will be asked to install them.
#'
#' @autoglobal
#'
#' @examplesIf identical(Sys.getenv("NOT_CRAN"), "true") && requireNamespace("metaplus", quietly = TRUE)
#' set.seed(123)
#' library(statsExpressions)
#'
#' # let's use `mag` dataset from `{metaplus}`
#' data(mag, package = "metaplus")
#' dat <- dplyr::rename(mag, estimate = yi, std.error = sei)
#'
#' # ----------------------- parametric ----------------------------------------
#'
#' @examplesIf identical(Sys.getenv("NOT_CRAN"), "true") && requireNamespace("metaplus") && requireNamespace("metafor")
#'
#' meta_analysis(dat)
#'
#' @examplesIf identical(Sys.getenv("NOT_CRAN"), "true") && requireNamespace("metaplus")
#'
#' # ----------------------- robust --------------------------------------------
#'
#' meta_analysis(dat, type = "random", random = "normal")
#'
#' @examplesIf identical(Sys.getenv("NOT_CRAN"), "true") && requireNamespace("metaplus") && requireNamespace("metaBMA")
#'
#' # ----------------------- Bayesian ------------------------------------------
#'
#' meta_analysis(dat, type = "bayes")
#'
#' @template citation
#'
#' @export
meta_analysis <- function(
  data,
  type = "parametric",
  random = "mixture",
  digits = 2L,
  conf.level = 0.95,
  ...
) {
  type <- extract_stats_type(type)

  # nolint start: line_length_linter.
  .meta_args <- switch(
    type,
    parametric = list(
      .ns = "metafor",
      .fn = "rma",
      .f.args = list(yi = quote(estimate), sei = quote(std.error), ...)
    ),
    robust = list(
      .ns = "metaplus",
      .fn = "metaplus",
      .f.args = list(
        yi = quote(estimate),
        sei = quote(std.error),
        random = random,
        ...
      )
    ),
    bayes = list(
      .ns = "metaBMA",
      .fn = "meta_random",
      .f.args = list(y = quote(estimate), SE = quote(std.error), ...)
    )
  )
  .ns <- .meta_args$.ns
  .fn <- .meta_args$.fn
  .f.args <- .meta_args$.f.args
  # nolint end

  check_if_installed(.ns)

  stats_df <- eval(call2(.fn = .fn, .ns = .ns, data = data, !!!.f.args)) |>
    tidy_model_parameters(include_studies = FALSE, ci = conf.level)

  if (type != "bayes") {
    stats_df <- mutate(stats_df, effectsize = "meta-analytic summary estimate")
  }
  if (type == "bayes") {
    stats_df <- mutate(
      stats_df,
      effectsize = "meta-analytic posterior estimate"
    )
  }

  add_expression_col(
    stats_df,
    n = nrow(data),
    n.text = list(quote(italic("n")["effects"])),
    digits = digits
  )
}

test_that(desc = "meta_analysis works - robust", code = {
  skip_if_not_installed("metaplus")

  set.seed(123)
  df <- meta_analysis(data_meta, type = "robust", random = "normal")

  set.seed(123)
  expect_snapshot(select(df, -expression))
  expect_snapshot(df[["expression"]])
})

test_that(desc = "meta_analysis works - bayesian", code = {
  skip_if_not_installed("metaBMA")

  set.seed(123)
  df <- meta_analysis(
    type = "bayes",
    data = data_meta,
    digits = 3L,
    iter = 1000L,
    summarize = "integrate"
  )

  expect_type(df, "list")

  expect_snapshot(dplyr::select(df, -expression))
  expect_snapshot(df[["expression"]])
})

test_that(desc = "meta_analysis works - parametric", code = {
  skip_if_not_installed("metafor")

  set.seed(123)
  df <- meta_analysis(data_meta)

  set.seed(123)
  expect_snapshot(select(df, -expression))
  expect_snapshot(df[["expression"]])

  expect_snapshot(meta_analysis(mtcars), error = TRUE)
})

#' @title Contingency table analyses
#' @name contingency_table
#'
#' @description
#' Parametric and Bayesian one-way and two-way contingency table analyses.
#'
#' @section Contingency table analyses:
#'
#' ```{r child="man/rmd-fragments/table_intro.Rmd"}
#' ```
#'
#' ```{r child="man/rmd-fragments/contingency_table.Rmd"}
#' ```
#'
#' @returns
#'
#' ```{r child="man/rmd-fragments/return.Rmd"}
#' ```
#'
#' @param x The variable to use as the **rows** in the contingency table.
#' @param y The variable to use as the **columns** in the contingency table.
#'   Default is `NULL`. If `NULL`, one-sample proportion test (a goodness of fit
#'   test) will be run for the `x` variable.
#' @param counts The variable in data containing counts, or `NULL` if each row
#'   represents a single observation.
#' @param paired Logical indicating whether data came from a within-subjects or
#'   repeated measures design study (Default: `FALSE`).
#' @param sampling.plan Character describing the sampling plan. Possible options:
#'   - `"indepMulti"` (independent multinomial; default)
#'   - `"poisson"`
#'   - `"jointMulti"` (joint multinomial)
#'   - `"hypergeom"` (hypergeometric).
#'   For more, see [`BayesFactor::contingencyTableBF()`].
#' @param fixed.margin For the independent multinomial sampling plan, which
#'   margin is fixed (`"rows"` or `"cols"`). Defaults to `"rows"`.
#' @param prior.concentration Specifies the prior concentration parameter, set
#'   to `1` by default. It indexes the expected deviation from the null
#'   hypothesis under the alternative, and corresponds to Gunel and Dickey's
#'   (1974) `"a"` parameter.
#' @param ratio A vector of proportions: the expected proportions for the
#'   proportion test (should sum to `1`). Default is `NULL`, which means the null
#'   is equal theoretical proportions across the levels of the nominal variable.
#'   E.g., `ratio = c(0.5, 0.5)` for two levels,
#'   `ratio = c(0.25, 0.25, 0.25, 0.25)` for four levels, etc.
#' @param ... Additional arguments (currently ignored).
#' @inheritParams stats::chisq.test
#' @inheritParams oneway_anova
#' @inheritParams parameters::model_parameters.htest
#'
#' @autoglobal
#'
#' @examplesIf identical(Sys.getenv("NOT_CRAN"), "true")
#' #### -------------------- association test ------------------------ ####
#'
#' # ------------------------ frequentist ---------------------------------
#'
#' # unpaired
#'
#' set.seed(123)
#' contingency_table(
#'   data = mtcars,
#'   x = am,
#'   y = vs,
#'   paired = FALSE
#' )
#'
#' # paired
#'
#' paired_data <- dplyr::tibble(
#'   response_before = structure(
#'     c(1L, 2L, 1L, 2L),
#'     levels = c("no", "yes"),
#'     class = "factor"
#'   ),
#'   response_after = structure(
#'     c(1L, 1L, 2L, 2L),
#'     levels = c("no", "yes"),
#'     class = "factor"
#'   ),
#'   Freq = c(65L, 25L, 5L, 5L)
#' )
#'
#' set.seed(123)
#' contingency_table(
#'   data = paired_data,
#'   x = response_before,
#'   y = response_after,
#'   paired = TRUE,
#'   counts = Freq
#' )
#'
#' # ------------------------ Bayesian -------------------------------------
#'
#' # unpaired
#'
#' set.seed(123)
#' contingency_table(
#'   data = mtcars,
#'   x = am,
#'   y = vs,
#'   paired = FALSE,
#'   type = "bayes"
#' )
#'
#' # paired
#'
#' set.seed(123)
#' contingency_table(
#'   data = paired_data,
#'   x = response_before,
#'   y = response_after,
#'   paired = TRUE,
#'   counts = Freq,
#'   type = "bayes"
#' )
#'
#' #### -------------------- goodness-of-fit test -------------------- ####
#'
#' # ------------------------ frequentist ---------------------------------
#'
#' set.seed(123)
#' contingency_table(
#'   data = as.data.frame(HairEyeColor),
#'   x = Eye,
#'   counts = Freq
#' )
#'
#' # ------------------------ Bayesian -------------------------------------
#'
#' set.seed(123)
#' contingency_table(
#'   data = as.data.frame(HairEyeColor),
#'   x = Eye,
#'   counts = Freq,
#'   ratio = c(0.2, 0.2, 0.3, 0.3),
#'   type = "bayes"
#' )
#'
#' @export
contingency_table <- function(
  data,
  x,
  y = NULL,
  paired = FALSE,
  type = "parametric",
  counts = NULL,
  ratio = NULL,
  alternative = "two.sided",
  digits = 2L,
  conf.level = 0.95,
  sampling.plan = "indepMulti",
  fixed.margin = "rows",
  prior.concentration = 1.0,
  ...
) {
  # data -------------------------------------------

  type <- extract_stats_type(type)
  test <- ifelse(quo_is_null(enquo(y)), "1way", "2way")

  data <- data |>
    select({{ x }}, {{ y }}, .counts = {{ counts }}) |>
    filter(!if_any(everything(), is.na))

  # untable the data frame based on the counts for each observation (if present)
  if (".counts" %in% names(data)) {
    data <- tidyr::uncount(data, weights = .counts)
  }

  xtab <- table(data)
  ratio <- ratio %||% rep(1 / length(xtab), length(xtab))

  # non-Bayesian ---------------------------------------

  if (type != "bayes" && test == "2way") {
    if (paired) {
      .f <- stats::mcnemar.test
      .f.es <- effectsize::cohens_g
    }
    if (!paired) {
      .f <- stats::chisq.test
      .f.es <- effectsize::cramers_v
    }
    .f.args <- list(x = xtab, correct = FALSE)
  }

  if (type != "bayes" && test == "1way") {
    .f <- stats::chisq.test
    .f.es <- effectsize::pearsons_c
    .f.args <- list(x = xtab, p = ratio, correct = FALSE)
  }

  if (type != "bayes") {
    stats_df <- bind_cols(
      tidy_model_parameters(exec(.f, !!!.f.args)),
      tidy_model_effectsize(exec(
        .f.es,
        !!!.f.args,
        ci = conf.level,
        alternative = alternative
      ))
    )
  }

  # Bayesian ---------------------------------------

  if (type == "bayes" && test == "2way") {
    stats_df <- BayesFactor::contingencyTableBF(
      xtab,
      sampleType = sampling.plan,
      fixedMargin = fixed.margin,
      priorConcentration = prior.concentration
    ) |>
      tidy_model_parameters(
        ci = conf.level,
        es_type = "cramers_v",
        alternative = alternative
      )
  }

  if (type == "bayes" && test == "1way") {
    return(.one_way_bayesian_table(xtab, prior.concentration, ratio, digits))
  }

  add_expression_col(stats_df, paired = paired, n = nrow(data), digits = digits)
}


.one_way_bayesian_table <- function(xtab, prior.concentration, ratio, digits) {
  # nocov start
  # a one-cell table is a degenerate case for this computation
  if (length(as.vector(xtab)) == 1L) {
    return(NULL)
  }
  # nocov end

  p1s <- rdirichlet(n = 100000L, alpha = prior.concentration * ratio)
  pr_h1 <- map_dbl(
    1:100000L,
    ~ stats::dmultinom(as.matrix(xtab), prob = p1s[.x, ], log = TRUE)
  )

  # BF = (log) prob of data under alternative - (log) prob of data under null
  # computing Bayes Factor and formatting the results
  tibble(
    bf10 = exp(
      BayesFactor::logMeanExpLogs(pr_h1) -
        stats::dmultinom(as.matrix(xtab), NULL, ratio, TRUE)
    ),
    prior.scale = prior.concentration,
    method = "Bayesian one-way contingency table analysis"
  ) |>
    mutate(
      expression = glue(
        "list(
            log[e]*(BF['01'])=='{format_value(-log(bf10), digits)}',
            {prior_switch(method)}=='{format_value(prior.scale, digits)}')"
      )
    ) |>
    .glue_to_expression()
}

#' @title estimate log prob of data under null with Monte Carlo
#' @note `rdirichlet()` function from `{MCMCpack}`
#' @noRd
rdirichlet <- function(n, alpha) {
  l <- length(alpha)
  x <- matrix(stats::rgamma(l * n, alpha), ncol = l, byrow = TRUE)
  x / as.vector(x %*% rep(1, l))
}

test_that(desc = "contingency_table works", code = {
  # contingency tab - without NAs ---------------------------------

  set.seed(123)
  df1 <- suppressWarnings(contingency_table(
    data = mtcars,
    x = am,
    y = cyl,
    digits = 5L,
    conf.level = 0.99
  ))

  set.seed(123)
  expect_snapshot(select(df1, -expression))
  expect_snapshot(df1[["expression"]])

  set.seed(123)
  df2 <- contingency_table(
    data = as.data.frame(Titanic),
    x = Sex,
    y = Survived,
    counts = Freq
  )

  set.seed(123)
  expect_snapshot(select(df2, -expression))
  expect_snapshot(df2[["expression"]])

  # contingency tab - with NAs --------------------------------------

  # introduce NAs
  set.seed(123)
  df3 <- suppressWarnings(contingency_table(
    data = msleep,
    x = vore,
    y = conservation,
    conf.level = 0.990
  ))

  set.seed(123)
  expect_snapshot(select(df3, -expression))
  expect_snapshot(df3[["expression"]])
})

test_that(desc = "paired contingency_table works ", code = {
  # paired data - without NAs and counts data ----------------------------

  paired_data <- dplyr::tibble(
    response_before = structure(
      c(1L, 2L, 1L, 2L),
      levels = c("no", "yes"),
      class = "factor"
    ),
    response_after = structure(
      c(1L, 1L, 2L, 2L),
      levels = c("no", "yes"),
      class = "factor"
    ),
    Freq = c(65L, 25L, 5L, 5L)
  )

  set.seed(123)
  df1 <- suppressWarnings(
    contingency_table(
      data = paired_data,
      x = response_before,
      y = response_after,
      paired = TRUE,
      counts = Freq,
      digits = 5
    )
  )

  set.seed(123)
  expect_snapshot(select(df1, -expression))
  expect_snapshot(df1[["expression"]])

  # paired data with NAs  ---------------------------------------------

  paired_data <- tidyr::uncount(paired_data, weights = Freq)

  # deliberately introduce NAs
  set.seed(123)
  paired_data[1, 1] <- NA
  paired_data[12, 1] <- NA
  paired_data[22, 1] <- NA
  paired_data[24, 1] <- NA
  paired_data[65, 1] <- NA

  set.seed(123)
  df2 <- suppressWarnings(
    contingency_table(
      data = paired_data,
      x = response_before,
      y = response_after,
      paired = TRUE,
      alternative = "greater",
      digits = 3L,
      conf.level = 0.90
    )
  )

  set.seed(123)
  expect_snapshot(select(df2, -expression))
  expect_snapshot(df2[["expression"]])
})

test_that(desc = "Goodness of Fit contingency_table works without counts", code = {
  # one-sample test (without NAs) -------------------------------------

  set.seed(123)
  df1 <- suppressWarnings(contingency_table(
    data = mtcars,
    x = am,
    conf.level = 0.99,
    digits = 5
  ))

  set.seed(123)
  expect_snapshot(select(df1, -expression))
  expect_snapshot(df1[["expression"]])

  set.seed(123)
  df2 <- contingency_table(
    data = as.data.frame(Titanic),
    x = Sex,
    counts = Freq,
    alternative = "greater"
  )

  set.seed(123)
  expect_snapshot(select(df2, -expression))
  expect_snapshot(df2[["expression"]])

  # one-sample test (with NAs) -------------------------------------

  set.seed(123)
  df3 <- contingency_table(
    data = msleep,
    x = vore,
    ratio = c(0.2, 0.2, 0.3, 0.3)
  )

  set.seed(123)
  expect_snapshot(select(df3, -expression))
  expect_snapshot(df3[["expression"]])

  # edge case
  expect_null(contingency_table(data.frame(x = "x"), x, type = "bayes"))
})

test_that(desc = "bayesian (proportion test)", code = {
  # bayesian (proportion test) --------------------------------------

  set.seed(123)
  df1 <- contingency_table(
    data = mtcars,
    x = am,
    type = "bayes"
  )

  expect_snapshot(select(df1, -expression))
  expect_snapshot(df1[["expression"]])

  set.seed(123)
  df2 <- contingency_table(
    type = "bayes",
    data = mtcars,
    x = cyl,
    prior.concentration = 10
  )

  expect_snapshot(select(df2, -expression))
  expect_snapshot(df2[["expression"]])
})

test_that(desc = "bayesian (contingency tab)", code = {
  # without NAs
  set.seed(123)
  df1 <- contingency_table(
    type = "bayes",
    data = mtcars,
    x = am,
    y = cyl
  )

  expect_snapshot(df1[["expression"]])

  # with NAs
  set.seed(123)
  df2 <- contingency_table(
    type = "bayes",
    data = msleep,
    x = vore,
    y = conservation
  )

  expect_snapshot(df2[["expression"]])
})

# `options(OutDec)` invariance (#146) -------------------------------------
#
# Regardless of the user's decimal-mark locale, the plotmath expression must
# carry `.` as the decimal mark (plotmath parses `,` as a list separator, so
# `,` would break it) and no `big.mark`/`decimal.mark` clash warning should
# be emitted.

patrick::with_parameters_test_that(
  "contingency_table() expression is invariant to `options(OutDec)`: ",
  {
    withr::local_options(list(OutDec = dec))

    set.seed(123)
    df <- suppressWarnings(contingency_table(
      data = mtcars,
      x = am,
      y = cyl,
      digits = 5L,
      conf.level = 0.99
    ))

    expect_snapshot(df[["expression"]])
  },
  .cases = dplyr::tibble(dec = c(".", ","))
)

test_that(desc = "print doesn't change global options and returns object invisibly", code = {
  withr::local_options(list(tibble.width = 5))

  old_option <- getOption("tibble.width")
  old_tbl <- contingency_table(mtcars, am)

  capture.output({
    new_tbl <- print(old_tbl)
  })
  new_option <- getOption("tibble.width")

  expect_identical(new_option, old_option)
  expect_identical(new_tbl, old_tbl)
})

#' @title Multiple pairwise comparison for one-way design
#' @name pairwise_comparisons
#'
#' @description
#'
#' Calculate parametric, non-parametric, robust, and Bayes Factor pairwise
#' comparisons between group levels with corrections for multiple testing.
#'
#' @inheritParams long_to_wide_converter
#' @inheritParams extract_stats_type
#' @inheritParams oneway_anova
#' @inheritParams two_sample_test
#' @param p.adjust.method Adjustment method for *p*-values for multiple
#'   comparisons. Possible methods are: `"holm"` (default), `"hochberg"`,
#'   `"hommel"`, `"bonferroni"`, `"BH"`, `"BY"`, `"fdr"`, `"none"`.
#' @param ... Additional arguments passed to other methods.
#' @inheritParams stats::t.test
#' @inheritParams WRS2::rmmcp
#'
#' @section Pairwise comparison tests:
#'
#' ```{r child="man/rmd-fragments/table_intro.Rmd"}
#' ```
#'
#' ```{r child="man/rmd-fragments/pairwise_comparisons.Rmd"}
#' ```
#'
#' @returns
#'
#' ```{r child="man/rmd-fragments/return.Rmd"}
#' ```
#'
#' @references For more, see:
#' <https://www.indrapatil.com/ggstatsplot/articles/web_only/pairwise.html>
#'
#' @autoglobal
#'
#' @examplesIf identical(Sys.getenv("NOT_CRAN"), "true")
#' # for reproducibility
#' set.seed(123)
#' library(statsExpressions)
#'
#' #------------------- between-subjects design ----------------------------
#'
#' # parametric
#' # if `var.equal = TRUE`, then Student's t-test will be run
#' pairwise_comparisons(
#'   data            = mtcars,
#'   x               = cyl,
#'   y               = wt,
#'   type            = "parametric",
#'   var.equal       = TRUE,
#'   paired          = FALSE,
#'   p.adjust.method = "none"
#' )
#'
#' # if `var.equal = FALSE`, then Games-Howell test will be run
#' pairwise_comparisons(
#'   data            = mtcars,
#'   x               = cyl,
#'   y               = wt,
#'   type            = "parametric",
#'   var.equal       = FALSE,
#'   paired          = FALSE,
#'   p.adjust.method = "bonferroni"
#' )
#'
#' # non-parametric (Dunn test)
#' pairwise_comparisons(
#'   data            = mtcars,
#'   x               = cyl,
#'   y               = wt,
#'   type            = "nonparametric",
#'   paired          = FALSE,
#'   p.adjust.method = "none"
#' )
#'
#' # robust (Yuen's trimmed means *t*-test)
#' pairwise_comparisons(
#'   data            = mtcars,
#'   x               = cyl,
#'   y               = wt,
#'   type            = "robust",
#'   paired          = FALSE,
#'   p.adjust.method = "fdr"
#' )
#'
#' # Bayes Factor (Student's *t*-test)
#' pairwise_comparisons(
#'   data   = mtcars,
#'   x      = cyl,
#'   y      = wt,
#'   type   = "bayes",
#'   paired = FALSE
#' )
#'
#' #------------------- within-subjects design ----------------------------
#'
#' # parametric (Student's *t*-test)
#' pairwise_comparisons(
#'   data            = bugs_long,
#'   x               = condition,
#'   y               = desire,
#'   subject.id      = subject,
#'   type            = "parametric",
#'   paired          = TRUE,
#'   p.adjust.method = "BH"
#' )
#'
#' # non-parametric (Durbin-Conover test)
#' pairwise_comparisons(
#'   data            = bugs_long,
#'   x               = condition,
#'   y               = desire,
#'   subject.id      = subject,
#'   type            = "nonparametric",
#'   paired          = TRUE,
#'   p.adjust.method = "BY"
#' )
#'
#' # robust (Yuen's trimmed means t-test)
#' pairwise_comparisons(
#'   data            = bugs_long,
#'   x               = condition,
#'   y               = desire,
#'   subject.id      = subject,
#'   type            = "robust",
#'   paired          = TRUE,
#'   p.adjust.method = "hommel"
#' )
#'
#' # Bayes Factor (Student's *t*-test)
#' pairwise_comparisons(
#'   data       = bugs_long,
#'   x          = condition,
#'   y          = desire,
#'   subject.id = subject,
#'   type       = "bayes",
#'   paired     = TRUE
#' )
#'
#' @template citation
#'
#' @export
pairwise_comparisons <- function(
  data,
  x,
  y,
  subject.id = NULL,
  type = "parametric",
  paired = FALSE,
  var.equal = FALSE,
  tr = 0.2,
  bf.prior = 0.707,
  p.adjust.method = "holm",
  digits = 2L,
  exact = FALSE,
  ...
) {
  # data -------------------------------------------

  type <- extract_stats_type(type)
  x <- ensym(x)
  y <- ensym(y)

  data <- long_to_wide_converter(
    data,
    x = {{ x }},
    y = {{ y }},
    subject.id = {{ subject.id }},
    paired = paired,
    spread = FALSE
  )

  # a few functions expect these as vectors
  x_vec <- pull(data, {{ x }})
  y_vec <- pull(data, {{ y }})
  g_vec <- pull(data, .rowid)
  .f.args <- list(paired = paired, p.adjust.method = "none", exact = exact, ...)

  # parametric ---------------------------------

  if (type %in% c("parametric", "bayes")) {
    # styler: off
    if (var.equal || paired) {
      .f <- stats::pairwise.t.test
      test <- "Student's t"
    }
    if (!(var.equal || paired)) {
      .f <- PMCMRplus::gamesHowellTest
      test <- "Games-Howell"
    }
    # styler: on
  }

  # nonparametric ----------------------------

  if (type == "nonparametric") {
    # styler: off
    if (!paired) {
      .f <- PMCMRplus::kwAllPairsDunnTest
      test <- "Dunn"
    }
    if (paired) {
      .f <- PMCMRplus::durbinAllPairsTest
      test <- "Durbin-Conover"
    }
    # styler: on

    # `exec` fails otherwise for `pairwise.t.test` because `y` is passed to `t.test`
    .f.args <- utils::modifyList(.f.args, list(y = y_vec))
  }

  if (type != "robust") {
    df_pair <- suppressWarnings(exec(
      .f,
      # Dunn, Games-Howell, Student's t-test
      x = y_vec,
      g = x_vec,
      # Durbin-Conover test
      groups = x_vec,
      blocks = g_vec,
      # common
      !!!.f.args
    )) |>
      tidy_model_parameters() |>
      select(-matches("^parameter1$|^parameter2$")) |>
      rename(group2 = group1, group1 = group2)
  }

  # robust ----------------------------------

  if (type == "robust") {
    if (!paired) {
      .ns <- "WRS2"
      .fn <- "lincon"
      .f.args <- list(formula = new_formula(y, x), data = data, method = "none")
    }

    if (paired) {
      .ns <- "WRS2"
      .fn <- "rmmcp"
      .f.args <- list(
        y = quote(y_vec),
        groups = quote(x_vec),
        blocks = quote(g_vec)
      )
    }

    df_pair <- eval(call2(.ns = .ns, .fn = .fn, tr = tr, !!!.f.args)) |>
      tidy_model_parameters()
    test <- "Yuen's trimmed means"
  }

  # Bayesian --------------------------------

  if (type == "bayes") {
    df_tidy <- map_dfr(
      # creating a list of data frames with subsections of data
      .x = map2(
        .x = as.character(df_pair$group1),
        .y = as.character(df_pair$group2),
        .f = function(a, b) droplevels(filter(data, {{ x }} %in% c(a, b)))
      ),
      .f = ~ two_sample_test(
        data = .x,
        x = {{ x }},
        y = {{ y }},
        paired = paired,
        bf.prior = bf.prior,
        type = "bayes"
      )
    ) |>
      filter(term == "Difference") |>
      mutate(
        expression = glue(
          "list(log[e]*(BF['01'])=='{format_value(-log(bf10), digits)}')"
        ),
        test = "Student's t"
      )

    df_pair <- bind_cols(select(df_pair, group1, group2), df_tidy)
  }

  # expression formatting ----------------------------------

  df_pair <- df_pair |>
    mutate(across(where(is.factor), \(x) as.character(x))) |>
    arrange(group1, group2) |>
    select(group1, group2, everything())

  if (type != "bayes") {
    df_pair <- df_pair |>
      .pairwise_p_adjust_expr(p.adjust.method, digits, test) |>
      mutate(p.value = p.value.adj) |>
      select(-p.value.adj)
  }

  select(df_pair, everything(), -matches("p.adjustment|^method$")) |>
    .glue_to_expression()
}

#' @noRd
.pairwise_p_adjust_expr <- function(data, p.adjust.method, digits, test) {
  data |>
    mutate(
      p.value.adj = stats::p.adjust(p = p.value, method = p.adjust.method),
      p.adjust.method = p_adjust_text(p.adjust.method),
      test = test,
      expression = case_when(
        p.adjust.method == "None" ~ glue(
          "list(italic(p)[unadj.]=='{format_value(p.value.adj, digits)}')"
        ),
        .default = glue(
          "list(italic(p)['{p.adjust.method}'-adj.]=='{format_value(p.value.adj, digits)}')"
        )
      )
    )
}

#' @noRd
p_adjust_text <- function(p.adjust.method) {
  case_when(
    grepl("^n|^bo|^h", p.adjust.method) ~ paste0(
      toupper(substr(p.adjust.method, 1L, 1L)),
      substr(p.adjust.method, 2L, nchar(p.adjust.method))
    ),
    grepl("^BH|^f", p.adjust.method) ~ "FDR",
    grepl("^BY", p.adjust.method) ~ "BY",
    .default = "Holm"
  )
}

# between-subjects design --------------------------------------------------

test_that(desc = "`pairwise_comparisons()` works for between-subjects design", code = {
  # student's t
  set.seed(123)
  df1 <- pairwise_comparisons(
    data = msleep,
    x = vore,
    y = brainwt,
    type = "p",
    var.equal = TRUE,
    paired = FALSE,
    p.adjust.method = "bonferroni"
  )

  expect_snapshot(df1)
  expect_snapshot(df1[["expression"]])

  # games-howell
  df_msleep <- msleep

  # adding empty factor level (shouldn't change results)
  df_msleep <- df_msleep |> dplyr::mutate(vore = as.factor(vore))

  df_msleep$vore <- factor(
    df_msleep$vore,
    levels = c(levels(df_msleep$vore), "Random")
  )

  set.seed(123)
  df2 <- pairwise_comparisons(
    data = df_msleep,
    x = vore,
    y = brainwt,
    type = "p",
    var.equal = FALSE,
    paired = FALSE,
    p.adjust.method = "bonferroni"
  )

  expect_snapshot(df2)
  expect_snapshot(df2[["expression"]])

  # Dunn test
  set.seed(123)
  df3 <- pairwise_comparisons(
    data = msleep,
    x = vore,
    y = brainwt,
    type = "np",
    paired = FALSE,
    p.adjust.method = "none"
  )

  expect_snapshot(df3)
  expect_snapshot(df3[["expression"]])

  # robust t test
  set.seed(123)
  df4 <- pairwise_comparisons(
    data = msleep,
    x = vore,
    y = brainwt,
    type = "r",
    paired = FALSE,
    p.adjust.method = "fdr"
  )

  expect_snapshot(df4)
  expect_snapshot(df4[["expression"]])

  # checking the edge case where factor level names contain `-`
  set.seed(123)
  df5 <- pairwise_comparisons(
    data = movies_long,
    x = mpaa,
    y = rating,
    var.equal = TRUE
  )

  expect_snapshot(df5)
  expect_snapshot(df5[["expression"]])

  # bayes test
  set.seed(123)
  df6 <- pairwise_comparisons(
    data = df_msleep,
    x = vore,
    y = brainwt
  )

  expect_snapshot(df6)
  expect_snapshot(df6[["expression"]])
})

# dropped levels --------------------------------------------------

test_that(desc = "dropped levels are not included", code = {
  # drop levels
  msleep2 <- dplyr::filter(.data = msleep, vore %in% c("carni", "omni"))

  # check those levels are not included
  set.seed(123)
  df1 <- pairwise_comparisons(
    data = msleep2,
    x = vore,
    y = brainwt,
    p.adjust.method = "none"
  )

  expect_snapshot(df1)
  expect_snapshot(df1[["expression"]])

  set.seed(123)
  df2 <- pairwise_comparisons(
    data = msleep,
    x = vore,
    y = brainwt,
    p.adjust.method = "none"
  ) |>
    dplyr::filter(group2 == "omni", group1 == "carni")

  expect_equal(df1$statistic, df2$statistic, tolerance = 0.01)
})

# data without NAs --------------------------------------------------

test_that(desc = "data without NAs", code = {
  set.seed(123)
  df <- pairwise_comparisons(
    data = iris,
    x = Species,
    y = Sepal.Length,
    type = "p",
    p.adjust.method = "fdr",
    var.equal = TRUE
  )

  expect_snapshot(df)
  expect_snapshot(df[["expression"]])
})


# within-subjects design - NAs --------------------------------------------

test_that(desc = "`pairwise_comparisons()` works for within-subjects design - NAs", code = {
  # student's t test
  set.seed(123)
  df1 <- pairwise_comparisons(
    data = bugs_long,
    x = condition,
    y = desire,
    type = "p",
    digits = 3L,
    paired = TRUE,
    p.adjust.method = "bonferroni"
  )

  expect_snapshot(df1)
  expect_snapshot(df1[["expression"]])

  # Durbin-Conover test
  set.seed(123)
  df2 <- pairwise_comparisons(
    data = bugs_long,
    x = condition,
    y = desire,
    type = "np",
    digits = 3L,
    paired = TRUE,
    p.adjust.method = "BY"
  )

  expect_snapshot(df2)
  expect_snapshot(df2[["expression"]])

  # robust t test
  set.seed(123)
  df3 <- pairwise_comparisons(
    data = bugs_long,
    x = condition,
    y = desire,
    type = "r",
    digits = 3L,
    paired = TRUE,
    p.adjust.method = "hommel"
  )

  expect_snapshot(df3)
  expect_snapshot(df3[["expression"]])

  # Bayesian
  set.seed(123)
  df4 <- pairwise_comparisons(
    data = bugs_long,
    x = condition,
    y = desire,
    type = "bf",
    paired = TRUE
  )

  expect_snapshot(df4)
  expect_snapshot(df4[["expression"]])
})


# within-subjects design - no NAs -----------------------------------------

test_that(desc = "`pairwise_comparisons()` works for within-subjects design - without NAs", code = {
  # student's t test
  set.seed(123)
  df1 <- pairwise_comparisons(
    data = WRS2::WineTasting,
    x = Wine,
    y = Taste,
    type = "p",
    digits = 3L,
    paired = TRUE,
    p.adjust.method = "none"
  )

  expect_snapshot(df1)
  expect_snapshot(df1[["expression"]])

  # Durbin-Conover test
  set.seed(123)
  df2 <- pairwise_comparisons(
    data = WRS2::WineTasting,
    x = Wine,
    y = Taste,
    type = "np",
    digits = 3L,
    paired = TRUE,
    p.adjust.method = "none"
  )

  expect_snapshot(df2)
  expect_snapshot(df2[["expression"]])

  # robust t test
  set.seed(123)
  df3 <- pairwise_comparisons(
    data = WRS2::WineTasting,
    x = Wine,
    y = Taste,
    type = "r",
    digits = 3L,
    paired = TRUE,
    p.adjust.method = "none"
  )

  expect_snapshot(df3)
  expect_snapshot(df3[["expression"]])

  set.seed(123)
  df4 <- pairwise_comparisons(
    data = WRS2::WineTasting,
    x = Wine,
    y = Taste,
    type = "bf",
    paired = TRUE
  )

  expect_snapshot(df4)
  expect_snapshot(df4[["expression"]])
})

test_that(desc = "works with subject id", code = {
  set.seed(123)
  df1 <- purrr::pmap_dfr(
    .f = pairwise_comparisons,
    .l = list(
      data = list(WRS2::WineTasting),
      x = list("Wine"),
      y = list("Taste"),
      type = list("p", "np", "r", "bf"),
      digits = 3L,
      subject.id = list("Taster"),
      paired = TRUE
    )
  )

  set.seed(123)
  df2 <- purrr::pmap_dfr(
    .f = pairwise_comparisons,
    .l = list(
      data = list(dplyr::arrange(WRS2::WineTasting, Taster)),
      x = list("Wine"),
      y = list("Taste"),
      type = list("p", "np", "r", "bf"),
      digits = 3L,
      paired = TRUE
    )
  )

  # columns should be same no matter the test
  expect_equal(
    dplyr::select(df1, -expression),
    dplyr::select(df2, -expression),
    ignore_attr = TRUE
  )
  expect_equal(
    dplyr::select(df1, expression),
    dplyr::select(df2, expression),
    ignore_attr = TRUE
  )
})

# additional arguments are passed ---------------------------------------

test_that(desc = "additional arguments are passed to underlying methods", code = {
  set.seed(123)
  df1 <- pairwise_comparisons(
    data = bugs_long,
    x = condition,
    y = desire,
    paired = TRUE,
    p.adjust.method = "none",
    alternative = "less"
  )

  expect_snapshot(df1)
  expect_snapshot(df1[["expression"]])

  set.seed(123)
  df2 <- pairwise_comparisons(
    data = bugs_long,
    x = condition,
    y = desire,
    paired = TRUE,
    p.adjust.method = "none",
    alternative = "greater"
  )

  expect_snapshot(df2)
  expect_snapshot(df2[["expression"]])

  set.seed(123)
  df3 <- pairwise_comparisons(
    data = mtcars,
    x = cyl,
    y = wt,
    var.equal = TRUE,
    p.adjust.method = "none",
    alternative = "less"
  )

  expect_snapshot(df3)
  expect_snapshot(df3[["expression"]])

  set.seed(123)
  df4 <- pairwise_comparisons(
    data = mtcars,
    x = cyl,
    y = wt,
    var.equal = TRUE,
    p.adjust.method = "none",
    alternative = "greater"
  )

  expect_snapshot(df4)
  expect_snapshot(df4[["expression"]])
})

#' @title Movie information and user ratings from IMDB.
#' @name movies_long
#' @details Modified dataset from `{ggplot2movies}` package.
#'
#' @format A data frame with 1,579 rows and 8 variables
#'
#'   - title.  Title of the movie.
#'   - year.  Year of release.
#'   - budget.  Total budget (if known) in US dollars
#'   - length.  Length in minutes.
#'   - rating.  Average IMDB user rating.
#'   - votes.  Number of IMDB users who rated this movie.
#'   - mpaa.  MPAA rating.
#'   - genre. Different genres of movies (action, animation, comedy, drama,
#'     documentary, romance, short).
#'
#' @source <https://CRAN.R-project.org/package=ggplot2movies>
#'
#' @examples
#' dim(movies_long)
#' head(movies_long)
#' dplyr::glimpse(movies_long)
"movies_long"


#' @title Edgar Anderson's Iris Data in long format.
#' @name iris_long
#' @details This famous (Fisher's or Anderson's) iris data set gives the
#'   measurements in centimeters of the variables sepal length and width and
#'   petal length and width, respectively, for 50 flowers from each of 3 species
#'   of iris. The species are Iris setosa, versicolor, and virginica.
#'
#' This is a modified dataset from `{datasets}` package.
#'
#' @format A data frame with 600 rows and 5 variables
#'
#'   - id. Dummy identity number for each flower (150 flowers in total).
#'   - Species.	The species are *Iris setosa*, *versicolor*, and
#'     *virginica*.
#'   - condition. Factor giving a detailed description of the attribute
#'     (Four levels: `"Petal.Length"`, `"Petal.Width"`,  `"Sepal.Length"`,
#'     `"Sepal.Width"`).
#'   - attribute.	What attribute is being measured (`"Sepal"` or `"Pepal"`).
#'   - measure.	What aspect of the attribute is being measured (`"Length"`
#'     or `"Width"`).
#'   - value.	Value of the measurement.
#'
#' @examples
#' dim(iris_long)
#' head(iris_long)
#' dplyr::glimpse(iris_long)
"iris_long"

#' @title Tidy version of the "Bugs" dataset.
#' @name bugs_long
#' @details This data set, "Bugs", provides the extent to which men and women
#'   want to kill arthropods that vary in freighteningness (low, high) and
#'   disgustingness (low, high). Each participant rates their attitudes towards
#'   all anthropods. Subset of the data reported by Ryan et al. (2013).
#'
#' @format A data frame with 372 rows and 6 variables
#'
#'   - subject. Dummy identity number for each participant.
#'   - gender. Participant's gender (Female, Male).
#'   - region. Region of the world the participant was from.
#'   - education. Level of education.
#'   - condition. Condition of the experiment the participant gave rating
#'     for (**LDLF**: low freighteningness and low disgustingness; **LFHD**: low
#'     freighteningness and high disgustingness; **HFHD**: high freighteningness
#'     and low disgustingness; **HFHD**: high freighteningness and high
#'     disgustingness).
#'   - desire. The desire to kill an arthropod was indicated on a scale from
#'     0 to 10.
#'
#' @references
#'
#' Ryan, R. S., Wilde, M., & Crist, S. (2013). Compared to a small, supervised
#' lab experiment, a large, unsupervised web-based experiment on a previously
#' unknown effect has benefits that outweigh its potential costs. *Computers in
#' Human Behavior*, *29*(4), 1295-1301.
#'
#' @examples
#' dim(bugs_long)
#' head(bugs_long)
#' dplyr::glimpse(bugs_long)
"bugs_long"

testthat::set_state_inspector(function() {
  list(
    attached = search(),
    connections = nrow(showConnections()),
    cwd = getwd(),
    envvars = Sys.getenv(),
    libpaths = .libPaths(),
    locale = Sys.getlocale(),
    options = .Options,
    packages = .packages(all.available = TRUE),
    NULL
  )
})

# for reproducibility
set.seed(123)

# ----------------------- parametric -----------------------

centrality_description(iris, Species, Sepal.Length, type = "parametric")

# ----------------------- non-parametric -------------------

centrality_description(mtcars, am, wt, type = "nonparametric")

# ----------------------- robust ---------------------------

centrality_description(ToothGrowth, supp, len, type = "robust")

# ----------------------- Bayesian -------------------------

centrality_description(sleep, group, extra, type = "bayes")

# Generated by roxyglobals: do not edit by hand

utils::globalVariables(c(
  # <contingency_table>
  # <pairwise_contingency_table>
  ".counts",
  # <long_to_wide_converter>
  # <oneway_anova>
  # <pairwise_comparisons>
  ".rowid",
  # <add_expression_col>
  "df",
  # <centrality_description>
  "estimate",
  # <pairwise_comparisons>
  # <pairwise_contingency_table>
  "group1",
  # <pairwise_comparisons>
  # <pairwise_contingency_table>
  "group2",
  # <add_expression_col>
  "method",
  # <add_expression_col>
  # <centrality_description>
  "n.obs",
  # <add_expression_col>
  # <pairwise_contingency_table>
  "p.value",
  # <pairwise_comparisons>
  # <pairwise_contingency_table>
  "p.value.adj",
  # <tidy_model_parameters>
  "r.squared",
  # <pairwise_comparisons>
  # <tidy_model_expressions>
  "term",
  NULL
))

#' @title Pairwise contingency table analyses
#' @name pairwise_contingency_table
#'
#' @description
#'
#' Pairwise Fisher's exact tests as post hoc tests for contingency table
#' analyses, with effect sizes (Cramer's *V*) and *p*-value adjustment for
#' multiple comparisons.
#'
#' @inheritParams contingency_table
#' @inheritParams pairwise_comparisons
#'
#' @section Pairwise contingency table tests:
#'
#' ```{r child="man/rmd-fragments/table_intro.Rmd"}
#' ```
#'
#' ```{r child="man/rmd-fragments/pairwise_contingency_table.Rmd"}
#' ```
#'
#' @returns
#'
#' ```{r child="man/rmd-fragments/return.Rmd"}
#' ```
#'
#' @autoglobal
#'
#' @examplesIf identical(Sys.getenv("NOT_CRAN"), "true")
#' # for reproducibility
#' set.seed(123)
#' library(statsExpressions)
#'
#' # pairwise Fisher's exact tests with Holm adjustment
#' pairwise_contingency_table(
#'   data = mtcars,
#'   x = cyl,
#'   y = am,
#'   p.adjust.method = "holm"
#' )
#'
#' # with counts data and Bonferroni adjustment
#' pairwise_contingency_table(
#'   data = as.data.frame(Titanic),
#'   x = Class,
#'   y = Survived,
#'   counts = Freq,
#'   p.adjust.method = "bonferroni"
#' )
#'
#' # no p-value adjustment
#' pairwise_contingency_table(
#'   data = mtcars,
#'   x = cyl,
#'   y = am,
#'   p.adjust.method = "none"
#' )
#'
#' @template citation
#'
#' @export
pairwise_contingency_table <- function(
  data,
  x,
  y,
  counts = NULL,
  p.adjust.method = "holm",
  digits = 2L,
  conf.level = 0.95,
  alternative = "two.sided",
  ...
) {
  # data -------------------------------------------

  x <- ensym(x)
  y <- ensym(y)

  data <- data |>
    select({{ x }}, {{ y }}, .counts = {{ counts }}) |>
    filter(!if_any(everything(), is.na))

  if (".counts" %in% names(data)) {
    data <- tidyr::uncount(data, weights = .counts)
  }

  data <- mutate(data, {{ x }} := droplevels(as.factor({{ x }})))

  # pairwise comparisons -------------------------------------------

  x_levels <- levels(pull(data, {{ x }}))
  pair_list <- utils::combn(x_levels, 2L, simplify = FALSE)

  df_pair <- map_dfr(pair_list, function(pair) {
    data_sub <- filter(data, {{ x }} %in% pair) |>
      mutate(across(where(is.factor), droplevels))

    xtab <- table(data_sub)

    fisher_result <- stats::fisher.test(xtab, alternative = alternative, ...)
    es_result <- effectsize::cramers_v(
      xtab,
      ci = conf.level,
      alternative = alternative
    )

    bind_cols(
      tibble(
        group1 = pair[[1L]],
        group2 = pair[[2L]],
        p.value = fisher_result$p.value
      ),
      tidy_model_effectsize(es_result)
    )
  })

  # p-value adjustment and expression -------------------------------------------

  df_pair <- df_pair |>
    arrange(group1, group2) |>
    .pairwise_p_adjust_expr(p.adjust.method, digits, "Fisher's exact test")

  select(
    df_pair,
    group1,
    group2,
    p.value,
    p.value.adj,
    everything(),
    -matches("^method$")
  ) |>
    .glue_to_expression()
}

# basic usage --------------------------------------------------

test_that("pairwise_contingency_table works - basic", {
  set.seed(123)
  df1 <- pairwise_contingency_table(
    data = mtcars,
    x = cyl,
    y = am,
    p.adjust.method = "bonferroni"
  )

  expect_snapshot(select(df1, -expression))
  expect_snapshot(df1[["expression"]])

  # correct number of pairs (3 levels -> 3 pairs)
  expect_identical(nrow(df1), 3L)

  # both raw and adjusted p-values present
  expect_true(all(c("p.value", "p.value.adj") %in% names(df1)))

  # adjusted should be >= raw
  expect_true(all(df1$p.value.adj >= df1$p.value))
})

# counts data --------------------------------------------------

test_that("pairwise_contingency_table works - with counts", {
  set.seed(123)
  df1 <- pairwise_contingency_table(
    data = as.data.frame(Titanic),
    x = Class,
    y = Survived,
    counts = Freq,
    p.adjust.method = "fdr"
  )

  expect_snapshot(select(df1, -expression))
  expect_snapshot(df1[["expression"]])

  # 4 levels -> C(4,2) = 6 pairs
  expect_identical(nrow(df1), 6L)
})

# no adjustment --------------------------------------------------

test_that("pairwise_contingency_table works - no adjustment", {
  set.seed(123)
  df1 <- pairwise_contingency_table(
    data = mtcars,
    x = cyl,
    y = am,
    p.adjust.method = "none"
  )

  expect_snapshot(select(df1, -expression))
  expect_snapshot(df1[["expression"]])

  # with no adjustment, raw and adjusted should be equal
  expect_identical(df1$p.value, df1$p.value.adj)
})

# data with NAs --------------------------------------------------

test_that("pairwise_contingency_table works - data with NAs", {
  set.seed(123)
  df1 <- pairwise_contingency_table(
    data = msleep,
    x = vore,
    y = conservation,
    p.adjust.method = "holm"
  )

  expect_snapshot(select(df1, -expression))
  expect_snapshot(df1[["expression"]])
})

# custom conf.level and alternative --------------------------------------------------

test_that("pairwise_contingency_table works - custom conf.level and alternative", {
  set.seed(123)
  df1 <- pairwise_contingency_table(
    data = mtcars,
    x = cyl,
    y = am,
    conf.level = 0.90,
    alternative = "greater",
    p.adjust.method = "holm"
  )

  expect_snapshot(select(df1, -expression))
  expect_snapshot(df1[["expression"]])
})

# custom digits --------------------------------------------------

test_that("pairwise_contingency_table works - custom digits", {
  set.seed(123)
  df1 <- pairwise_contingency_table(
    data = mtcars,
    x = cyl,
    y = am,
    digits = 4L,
    p.adjust.method = "BH"
  )

  expect_snapshot(select(df1, -expression))
  expect_snapshot(df1[["expression"]])
})

#' @title One-sample tests
#' @name one_sample_test
#'
#' @param x A numeric variable from the data frame `data`.
#' @param test.value A number indicating the true value of the mean (Default:
#'   `0`).
#' @param effsize.type Type of effect size needed for *parametric* tests. The
#'   argument can be `"d"` (for Cohen's *d*) or `"g"` (for Hedge's *g*).
#' @param exact A logical indicating whether you want exact p-values to be computed.
#'   Relevant only when `type = "nonparametric"` (Default: `FALSE`).
#' @inheritParams long_to_wide_converter
#' @inheritParams extract_stats_type
#' @inheritParams add_expression_col
#' @inheritParams two_sample_test
#' @inheritParams oneway_anova
#' @inheritParams stats::t.test
#' @inheritParams insight::format_value
#'
#' @description
#' Parametric, non-parametric, robust, and Bayesian one-sample tests.
#'
#' @section One-sample tests:
#'
#' ```{r child="man/rmd-fragments/table_intro.Rmd"}
#' ```
#'
#' ```{r child="man/rmd-fragments/one_sample_test.Rmd"}
#' ```
#'
#' @returns
#'
#' ```{r child="man/rmd-fragments/return.Rmd"}
#' ```
#'
#' @autoglobal
#'
#' @example man/examples/examples-one-sample-test.R
#'
#' @template citation
#'
#' @export
one_sample_test <- function(
  data,
  x,
  type = "parametric",
  test.value = 0,
  alternative = "two.sided",
  digits = 2L,
  conf.level = 0.95,
  tr = 0.2,
  bf.prior = 0.707,
  effsize.type = "g",
  exact = FALSE,
  ...
) {
  type <- extract_stats_type(type)
  x_vec <- stats::na.omit(pull(data, {{ x }}))

  # parametric ---------------------------------------

  if (type == "parametric") {
    .f <- stats::t.test
    .f.es <- switch(
      match.arg(effsize.type, c("g", "d", "unbiased", "biased")),
      g = ,
      unbiased = effectsize::hedges_g,
      d = ,
      biased = effectsize::cohens_d
    )
  }

  # non-parametric ---------------------------------------

  if (type == "nonparametric") {
    .f <- stats::wilcox.test
    .f.es <- effectsize::rank_biserial
  }

  if (type %in% c("parametric", "nonparametric")) {
    stats_df <- exec(
      .f,
      x = x_vec,
      mu = test.value,
      alternative = alternative,
      exact = exact
    ) |>
      tidy_model_parameters() |>
      select(-matches("^est|^conf|^diff|^term|^ci"))

    ez_df <- exec(
      .f.es,
      x = x_vec,
      mu = test.value,
      verbose = FALSE,
      ci = conf.level
    ) |>
      tidy_model_effectsize()

    stats_df <- bind_cols(stats_df, ez_df)
  }

  # robust ---------------------------------------

  if (type == "robust") {
    stats_df <- exec(
      WRS2::trimcibt,
      x = x_vec,
      nv = test.value,
      tr = tr,
      alpha = 1.0 - conf.level
    ) |>
      tidy_model_parameters()
  }

  # Bayesian ---------------------------------------

  if (type == "bayes") {
    stats_df <- BayesFactor::ttestBF(
      x = x_vec,
      rscale = bf.prior,
      mu = test.value
    ) |>
      tidy_model_parameters(ci = conf.level)
  }

  # expression ---------------------------------------

  add_expression_col(stats_df, n = length(x_vec), digits = digits)
}

run_one_sample_tests_with_parameters <- function(title, x, test.value) {
  cases_data <- tidyr::expand_grid(
    type = c("bayes", "parametric", "nonparametric", "robust"),
    conf.level = c(0.95, 0.90)
  )
  cases_data <- dplyr::mutate(
    cases_data,
    effsize.type = rep_len(c("g", "d"), length.out = nrow(cases_data))
  )

  patrick::with_parameters_test_that(
    title,
    {
      set.seed(123L)
      res <- one_sample_test(
        data = msleep,
        x = {{ x }},
        type = type,
        conf.level = conf.level,
        effsize.type = effsize.type,
        conf.method = conf.method,
        test.value = test.value,
        digits = 3L
      )

      # Bayesian estimation results are too platform-sensitive, so don't
      # snapshot them; only recording Bayes Factors is enough
      if (type == "bayes") {
        expect_snapshot(names(res))
        expect_snapshot(res$bf10[[1L]])
      } else {
        expect_snapshot(select(res, -expression))
        expect_snapshot(res[["expression"]])
      }
    },
    .cases = cases_data
  )
}

run_one_sample_tests_with_parameters(
  "one-sample-test without missing data: ",
  sleep_total,
  5.0
)
run_one_sample_tests_with_parameters(
  "one-sample-test with missing data: ",
  brainwt,
  0.25
)

test_that(desc = " parametric t-tests", code = {
  # one-sample t-test (with NAs) ---------

  set.seed(123)
  df_1 <- purrr::pmap_dfr(
    .l = list(
      data = list(msleep),
      x = list("brainwt"),
      test.value = list(0.25),
      effsize.type = list("d", "g", "d", "g"),
      alternative = c("two.sided", "less", "greater", "two.sided"),
      var.equal = list(TRUE, FALSE, TRUE, FALSE),
      conf.level = list(0.89, 0.99, 0.90, 0.50)
    ),
    .f = one_sample_test
  )

  set.seed(123)
  expect_snapshot(df_1)

  # parametric t-test (between-subjects without NAs) ---------

  set.seed(123)
  df_2_between <- purrr::pmap_dfr(
    .l = list(
      data = list(mtcars),
      x = list("am"),
      y = list("wt"),
      effsize.type = list("d", "g", "d", "g"),
      var.equal = list(TRUE, FALSE, TRUE, FALSE),
      alternative = c("two.sided", "less", "greater", "two.sided"),
      conf.level = list(0.89, 0.99, 0.90, 0.50)
    ),
    .f = two_sample_test
  )

  set.seed(123)
  expect_snapshot(df_2_between)

  # parametric t-test (within-subjects with NAs) ---------

  set.seed(123)
  df_2_within <- purrr::pmap_dfr(
    .l = list(
      data = list(filter(bugs_long, condition %in% c("HDHF", "HDLF"))),
      x = list("condition"),
      y = list("desire"),
      paired = list(TRUE),
      effsize.type = list("d", "g", "d", "g"),
      var.equal = list(TRUE, FALSE, TRUE, FALSE),
      conf.level = list(0.89, 0.99, 0.90, 0.50)
    ),
    .f = two_sample_test
  )

  set.seed(123)
  expect_snapshot(df_2_within)

  # parametric ANOVA (within-subjects with NAs) ---------

  set.seed(123)
  df_3_between <- purrr::pmap_dfr(
    .l = list(
      data = list(msleep),
      x = list("vore"),
      y = list("sleep_rem"),
      effsize.type = list("eta", "omega", "eta", "omega"),
      var.equal = list(TRUE, FALSE, TRUE, FALSE),
      conf.level = list(0.89, 0.80, 0.90, 0.50)
    ),
    .f = oneway_anova
  )

  set.seed(123)
  expect_snapshot(df_3_between)

  # parametric ANOVA (within-subjects with NAs) ---------

  set.seed(123)
  df_3_within <- purrr::pmap_dfr(
    .l = list(
      data = list(bugs_long),
      x = list("condition"),
      y = list("desire"),
      paired = list(TRUE),
      effsize.type = list("eta", "omega"),
      conf.level = list(0.89, 0.90)
    ),
    .f = oneway_anova
  )

  set.seed(123)
  expect_snapshot(df_3_within)
})

---
title: "statsExpressions: R Package for Tidy Dataframes and Expressions with Statistical Details"
output:
  rmarkdown::html_vignette:
    toc: true
    toc_depth: 4
bibliography: paper.bib
csl: apa.csl
link-citations: yes
vignette: >
  %\VignetteIndexEntry{statsExpressions: R Package for Tidy Dataframes and Expressions with Statistical Details}
  %\VignetteEngine{knitr::rmarkdown}
  %\VignetteEncoding{UTF-8}
---

```{r}
#| label = "setup",
#| message = FALSE,
#| warning = FALSE,
#| include = FALSE,
#| echo = FALSE
source("setup.R")

pkgs <- "ggplot2"

successfully_loaded <- purrr::map_lgl(pkgs, requireNamespace, quietly = TRUE)
can_evaluate <- all(successfully_loaded)

if (can_evaluate) {
  purrr::walk(pkgs, library, character.only = TRUE)
} else {
  knitr::opts_chunk$set(eval = FALSE)
}
```

This vignette can be cited as:

```{r}
#| label = "citation",
#| echo = FALSE,
#| comment = ""
citation("statsExpressions")
```

## Summary

The `{statsExpressions}` package has two key aims: to provide a consistent syntax
to do statistical analysis with tidy data, and to provide statistical
expressions (i.e., pre-formatted in-text statistical results) for plotting
functions. Currently, it supports common types of statistical approaches and
tests: parametric, nonparametric, robust, and Bayesian *t*-test, one-way ANOVA,
correlation analyses, contingency table analyses, and meta-analyses. The
functions are pipe-friendly and compatible with tidy data.

## Statement of Need

Statistical packages exhibit substantial diversity in terms of their syntax and
expected input and output data type. For example, some functions expect vectors
as inputs, while others expect data frames. Depending on whether it is a repeated
measures design or not, functions from the same package might expect data to be
in wide or tidy format. Some functions can internally omit missing values, while
others do not. Furthermore, the statistical test objects returned by the test
functions might not have all required information (e.g., degrees of freedom,
significance, Bayes factor, etc.) accessible in a consistent data type.
Depending on the specific test object and statistic in question, details may be
returned as a list, a matrix, an array, or a data frame. This diversity can make
it difficult to easily access all needed information for hypothesis testing and
estimation, and to switch from one statistical approach to another.

This is where `{statsExpressions}` comes in: It can be thought of as a unified
portal through which most of the functionality in these underlying packages can
be accessed, with a simpler interface and with tidy data format.

## Comparison to Other Packages

Unlike `{broom}` [@Robinson2021] or `{parameters}` [@Lüdecke2020parameters], the
goal of `{statsExpressions}` is not to convert model objects into tidy data frames,
but to provide a consistent and easy syntax to carry out statistical tests.
Additionally, none of these packages return statistical expressions.

## Consistent Syntax for Statistical Analysis

The package offers functions that allow users choose a statistical approach
without changing the syntax (i.e., by only specifying a single argument). The
functions always require a data frame in tidy format [@Wickham2019], and work
with missing data. Moreover, they always return a data frame that can be further
utilized downstream in the workflow (such as visualization).

| Function            | Parametric | Non-parametric | Robust | Bayesian |
| :------------------ | :--------- | :------------- | :----- | :------- |
| `one_sample_test`   | ✅         | ✅             | ✅     | ✅       |
| `two_sample_test`   | ✅         | ✅             | ✅     | ✅       |
| `oneway_anova`      | ✅         | ✅             | ✅     | ✅       |
| `corr_test`         | ✅         | ✅             | ✅     | ✅       |
| `contingency_table` | ✅         | ✅             | -      | ✅       |
| `meta_analysis`     | ✅         | -              | ✅     | ✅       |

: A summary table listing the primary functions in the package and the
statistical approaches they support. More detailed description of the
tests and outputs from these functions can be found on the package website: <https://www.indrapatil.com/statsExpressions/articles/>.

`{statsExpressions}` internally relies on `{stats}` package for parametric and
non-parametric [@base2021], `{WRS2}` package for robust [@Mair2020], and
`{BayesFactor}` package for Bayesian statistics [@Morey2020]. The random-effects
meta-analysis is carried out using `{metafor}` (parametric) [@Viechtbauer2010],
`{metaplus}` (robust) [@Beath2016], and `{metaBMA}` (Bayesian) [@Heck2019] packages.
Additionally, it relies on `easystats` packages [@Ben-Shachar2020;
@Lüdecke2020parameters;
@Lüdecke2020performance; @Lüdecke2019; @Makowski2019; @Makowski2020] to compute
appropriate effect size/posterior estimates and their confidence/credible
intervals.

## Tidy Dataframes from Statistical Analysis

To illustrate the simplicity of this syntax, let's say we want to run a one-way
ANOVA. If we first run a non-parametric ANOVA and then decide to run a robust
ANOVA instead, the syntax remains the same and the statistical approach can be
modified by changing a single argument:

```{r}
#| label = "df_p"
oneway_anova(mtcars, cyl, wt, type = "nonparametric")

oneway_anova(mtcars, cyl, wt, type = "robust")
```

These functions are also compatible with other popular data manipulation
packages. For example, we can use combination of `{dplyr}` and `{statsExpressions}` to repeat the same
statistical analysis across grouping variables.

```{r}
#| label = "grouped_df"
# running one-sample proportion test for `vs` at all levels of `am`
mtcars |>
  group_by(am) |>
  group_modify(~ contingency_table(.x, vs), .keep = TRUE) |>
  ungroup()
```

## Custom Statistical Workflows

### Pairwise comparisons with automatic *p*-value adjustment

When an omnibus test (e.g., one-way ANOVA) is significant, you typically follow
up with pairwise comparisons. The `pairwise_comparisons()` function handles this
with built-in *p*-value adjustment across all pairwise tests:

```{r}
#| label = "pairwise"
pairwise_comparisons(
  data            = mtcars,
  x               = cyl,
  y               = wt,
  type            = "parametric",
  var.equal       = FALSE,
  p.adjust.method = "holm"
)
```

Each row contains a formatted `expression` column with the adjusted *p*-value,
ready for use as a plot annotation. The `p.adjust.method` argument supports all
methods from `stats::p.adjust()` (e.g., `"holm"`, `"bonferroni"`, `"BH"`,
`"fdr"`, `"none"`).

### Chaining multiple tests and adjusting *p*-values

You can chain different statistical tests on the same data, consolidate the
results into a single data frame, and apply *p*-value correction across all
comparisons:

```{r}
#| label = "custom_workflow"
multi_test_results <- dplyr::bind_rows(
  two_sample_test(mtcars, am, wt, type = "parametric"),
  two_sample_test(mtcars, am, wt, type = "nonparametric"),
  two_sample_test(mtcars, am, wt, type = "robust")
) |>
  dplyr::mutate(p.value = stats::p.adjust(p.value, method = "holm"))

dplyr::select(multi_test_results, method, effectsize, estimate, p.value)
```

### Generating formatted expressions from custom results

The `add_expression_col()` function creates publication-ready plotmath
expressions from any data frame containing statistical details. This is useful
when you run your own tests outside `{statsExpressions}` and want to generate
a formatted expression for plot annotations:

```{r}
#| label = "custom_expression"
# suppose you have run your own statistical test
custom_stats <- cbind.data.frame(
  statistic  = 2.18,
  df         = 18,
  p.value    = 0.041,
  estimate   = 0.65,
  conf.level = 0.95,
  conf.low   = 0.03,
  conf.high  = 1.27,
  method     = "Student's t-test"
)

# generate a formatted expression
add_expression_col(
  data           = custom_stats,
  statistic.text = list(quote(italic("t"))),
  effsize.text   = list(quote(italic("d")["Cohen"])),
  n              = 20L,
  digits         = 2L,
  digits.df      = 0L
)$expression[[1]]
```

## Expressions for Plots

In addition to other details contained in the data frame, there is also a column
titled `expression`, which contains a pre-formatted text with statistical
details. These expressions (Figure 1) attempt to follow the gold standard in
statistical reporting for both Bayesian [@van2020jasp] and Frequentist
[@american2019publication] frameworks.

```{r}
#| label = "expr_template",
#| echo = FALSE,
#| fig.cap = "The templates used in `{statsExpressions}` to display statistical details in a
#| plot."
knitr::include_graphics("stats_reporting_format.png")
```

This expression can be easily displayed in a plot (Figure 2). Displaying statistical
results in the context of a visualization is indeed a philosophy adopted by the
`{ggstatsplot}` package [@Patil2021], and `{statsExpressions}` functions as its
statistical processing backend.

```{r}
#| label = "anova_example",
#| eval = requireNamespace("ggplot2", quietly = TRUE),
#| fig.width = 8,
#| fig.cap = "Example illustrating how `{statsExpressions}` functions can be used to display
#| results from a statistical test in a plot."
# needed libraries
library(ggplot2)

# Example 1: Performing a t-test on raw tidy data and extracting the formatted expression
# for direct use in a plot annotation
res_ttest <- two_sample_test(mtcars, am, wt, type = "parametric")

ggplot(mtcars, aes(as.factor(am), wt)) +
  geom_boxplot() +
  labs(
    x = "Transmission (0 = automatic, 1 = manual)",
    y = "Weight (1000 lbs)",
    title = "Vehicle Weight by Transmission Type",
    subtitle = res_ttest$expression[[1]] # Extract formatted p-value and effect size
  )

# Example 2: One-way ANOVA
res_anova <- oneway_anova(iris, Species, Sepal.Length, type = "nonparametric")

ggplot(iris, aes(x = Sepal.Length, y = Species)) +
  geom_boxplot() + # use 'expression' column to display results in the subtitle
  labs(
    x = "Penguin Species",
    y = "Body mass (in grams)",
    title = "Kruskal-Wallis Rank Sum Test",
    subtitle = res_anova$expression[[1]]
  )
```

## Licensing and Availability

`{statsExpressions}` is licensed under the GNU General Public License (v3.0), with all
source code stored at [GitHub](https://github.com/IndrajeetPatil/statsExpressions/).
In the spirit of honest and open science, requests and suggestions for fixes,
feature updates, as well as general questions and concerns are encouraged via
direct interaction with contributors and developers by filing an
[issue](https://github.com/IndrajeetPatil/statsExpressions/issues).

## Acknowledgements

I would like to acknowledge the support of Mina Cikara, Fiery Cushman, and Iyad
Rahwan during the development of this project. `{statsExpressions}` relies heavily
on the [`easystats`](https://github.com/easystats/easystats) ecosystem, a
collaborative project created to facilitate the usage of `R` for statistical
analyses. Thus, I would like to thank the [members of easystats](https://github.com/orgs/easystats/people) as well as the users.

## References

**Hypothesis testing** and **Effect size estimation**

| Type       | Test                                             | Effect size | CI available? | Function used            |
| :--------- | :----------------------------------------------- | :---------- | :------------ | :----------------------- |
| Parametric | Meta-analysis via random-effects models          | *beta*      | Yes           | `metafor::rma()`         |
| Robust     | Meta-analysis via robust random-effects models   | *beta*      | Yes           | `metaplus::metaplus()`   |
| Bayesian   | Meta-analysis via Bayesian random-effects models | *beta*      | Yes           | `metaBMA::meta_random()` |

---
title: "Test and effect size details"
output:
  rmarkdown::html_vignette:
    toc: true
    toc_depth: 4
    keep_md: true
vignette: >
  %\VignetteIndexEntry{Test and effect size details}
  %\VignetteEngine{knitr::rmarkdown}
  %\VignetteEncoding{UTF-8}
---

```{r}
#| label = "setup",
#| message = FALSE,
#| warning = FALSE,
#| include = FALSE,
#| echo = FALSE
source("setup.R")
```

This vignette can be cited as:

```{r citation, echo=FALSE, comment = ""}
citation("statsExpressions")
```

## Introduction

Here a go-to summary about statistical test carried out and the returned effect
size for each function is provided. This should be useful if one needs to find
out more information about how an argument is resolved in the underlying package
or if one wishes to browse the source code. So, for example, if you want to know
more about how one-way (between-subjects) ANOVA, you can run
`?stats::oneway.test` in your R console.

Abbreviations used: CI = Confidence Interval

## Data requirements

All functions expect data in **long (tidy) format** — one row per observation.
A few additional requirements are worth noting:

- **Within-subjects (repeated measures) designs**: The data must contain exactly
  *one* observation per subject per condition (a complete, balanced block design).
  If you have multiple trials per subject-condition cell, aggregate them first
  (e.g., by taking the mean) before passing the data.
  You can verify this with `table(data$subject, data$condition)` — every cell
  should equal `1`.

- **`subject.id` argument**: For within-subjects designs, always specify
  `subject.id` explicitly. If omitted, the function pairs observations by
  row order within each condition, so any data that is not already sorted
  identically within every condition level can produce silently incorrect
  paired tests — even with exactly two conditions and no missing values.

- **Missing data**: Missing values are handled internally by removing any subject
  who has `NA` in *any* condition, ensuring a balanced design is maintained.

## Summary of functionality

```{r child="../man/rmd-fragments/functionality.Rmd"}
```

## Summary of tests and effect sizes

Here a go-to summary about statistical test carried out and the returned effect
size for each function is provided. This should be useful if one needs to find
out more information about how an argument is resolved in the underlying package
or if one wishes to browse the source code. So, for example, if you want to know
more about how one-way (between-subjects) ANOVA, you can run
`?stats::oneway.test` in your R console.

### `centrality_description()`

```{r child="../man/rmd-fragments/centrality_description.Rmd"}
```

### `oneway_anova()`

```{r child="../man/rmd-fragments/oneway_anova.Rmd"}
```

### `two_sample_test()`

```{r child="../man/rmd-fragments/two_sample_test.Rmd"}
```

### `one_sample_test()`

```{r child="../man/rmd-fragments/one_sample_test.Rmd"}
```

### `corr_test()`

```{r child="../man/rmd-fragments/corr_test.Rmd"}
```

### `contingency_table()`

```{r child="../man/rmd-fragments/contingency_table.Rmd"}
```

### `meta_analysis()`

```{r child="../man/rmd-fragments/meta_analysis.Rmd"}
```

## Effect size interpretation

See `{effectsize}`'s interpretation functions to check different rules/conventions
to interpret effect sizes:

<https://easystats.github.io/effectsize/reference/index.html#section-interpretation>

## References

  - For parametric and non-parametric effect sizes:
    <https://easystats.github.io/effectsize/articles/>

  - For robust effect sizes:
    <https://CRAN.R-project.org/package=WRS2/vignettes/WRS2.pdf>

  - For Bayesian posterior estimates:
    <https://easystats.github.io/bayestestR/articles/bayes_factors.html>

## Suggestions

If you find any bugs or have any suggestions/remarks, please file an issue on GitHub:
<https://github.com/IndrajeetPatil/statsExpressions/issues>

#### two-way table

**Hypothesis testing**

| Type                      | Design   | Test                                | Function used                       |
| :------------------------ | :------- | :---------------------------------- | :---------------------------------- |
| Parametric/Non-parametric | Unpaired | Pearson's chi-squared test          | `stats::chisq.test()`               |
| Bayesian                  | Unpaired | Bayesian Pearson's chi-squared test | `BayesFactor::contingencyTableBF()` |
| Parametric/Non-parametric | Paired   | McNemar's chi-squared test          | `stats::mcnemar.test()`             |
| Bayesian                  | Paired   | No                                  | No                                  |

**Effect size estimation**

| Type                      | Design   | Effect size  | CI available? | Function used             |
| :------------------------ | :------- | :----------- | :------------ | :------------------------ |
| Parametric/Non-parametric | Unpaired | Cramer's *V* | Yes           | `effectsize::cramers_v()` |
| Bayesian                  | Unpaired | Cramer's *V* | Yes           | `effectsize::cramers_v()` |
| Parametric/Non-parametric | Paired   | Cohen's *g*  | Yes           | `effectsize::cohens_g()`  |
| Bayesian                  | Paired   | No           | No            | No                        |

#### one-way table

**Hypothesis testing**

| Type                      | Test                                      | Function used         |
| :------------------------ | :---------------------------------------- | :-------------------- |
| Parametric/Non-parametric | Goodness of fit chi-squared test          | `stats::chisq.test()` |
| Bayesian                  | Bayesian Goodness of fit chi-squared test | (custom)              |

**Effect size estimation**

| Type                      | Effect size   | CI available? | Function used              |
| :------------------------ | :------------ | :------------ | :------------------------- |
| Parametric/Non-parametric | Pearson's *C* | Yes           | `effectsize::pearsons_c()` |
| Bayesian                  | No            | No            | No                         |

The returned tibble data frame can contain some or all of the following columns (the exact columns will depend on the statistical test):

  - `statistic`: the numeric value of a statistic

  - `df`: the numeric value of a parameter being modeled (often degrees
    of freedom for the test)

  - `df.error` and `df`: relevant only if the statistic in question has
    two degrees of freedom (e.g. anova)

  - `p.value`: the two-sided *p*-value associated with the observed statistic
  
  - `method`: the name of the inferential statistical test

  - `estimate`: estimated value of the effect size

  - `conf.low`: lower bound for the effect size estimate

  - `conf.high`: upper bound for the effect size estimate
  
  - `conf.level`: width of the confidence interval
  
  - `conf.method`: method used to compute confidence interval
  
  - `conf.distribution`: statistical distribution for the effect
  
  - `effectsize`: the name of the effect size

  - `n.obs`: number of observations
  
  - `expression`: pre-formatted expression containing statistical details

For examples, see [data frame output vignette](https://www.indrapatil.com/statsExpressions/articles/web_only/dataframe_outputs.html).

| Type           | Measure      | Function used                         |
| :------------- | :----------- | :------------------------------------ |
| Parametric     | mean         | `datawizard::describe_distribution()` |
| Non-parametric | median       | `datawizard::describe_distribution()` |
| Robust         | trimmed mean | `datawizard::describe_distribution()` |
| Bayesian       | MAP          | `datawizard::describe_distribution()` |

**Hypothesis testing**

| Type           | Test                                     | Function used            |
| :------------- | :--------------------------------------- | :----------------------- |
| Parametric     | One-sample Student's *t*-test            | `stats::t.test()`        |
| Non-parametric | One-sample Wilcoxon test                 | `stats::wilcox.test()`   |
| Robust         | Bootstrap-*t* method for one-sample test | `WRS2::trimcibt()`       |
| Bayesian       | One-sample Student's *t*-test            | `BayesFactor::ttestBF()` |

**Effect size estimation**

| Type           | Effect size                     | CI available? | Function used                                      |
| :------------- | :------------------------------ | :------------ | :------------------------------------------------- |
| Parametric     | Cohen's *d*, Hedge's *g*        | Yes           | `effectsize::cohens_d()`, `effectsize::hedges_g()` |
| Non-parametric | *r* (rank-biserial correlation) | Yes           | `effectsize::rank_biserial()`                      |
| Robust         | trimmed mean                    | Yes           | `WRS2::trimcibt()`                                 |
| Bayesian       | difference                      | Yes           | `bayestestR::describe_posterior()`                 |

#### between-subjects

**Hypothesis testing**

| Type           | No. of groups | Test                          | Function used            |
| :------------- | :------------ | :---------------------------- | :----------------------- |
| Parametric     | 2             | Student's or Welch's *t*-test | `stats::t.test()`        |
| Non-parametric | 2             | Mann-Whitney *U* test         | `stats::wilcox.test()`   |
| Robust         | 2             | Yuen's test for trimmed means | `WRS2::yuen()`           |
| Bayesian       | 2             | Student's *t*-test            | `BayesFactor::ttestBF()` |

**Effect size estimation**

| Type           | No. of groups | Effect size                                             | CI available? | Function used                                      |
| :------------- | :------------ | :------------------------------------------------------ | :------------ | :------------------------------------------------- |
| Parametric     | 2             | Cohen's *d*, Hedge's *g*                                | Yes           | `effectsize::cohens_d()`, `effectsize::hedges_g()` |
| Non-parametric | 2             | *r* (rank-biserial correlation)                         | Yes           | `effectsize::rank_biserial()`                      |
| Robust         | 2             | Algina-Keselman-Penfield robust standardized difference | Yes           | `WRS2::akp.effect()`                               |
| Bayesian       | 2             | difference                                              | Yes           | `bayestestR::describe_posterior()`                 |

#### within-subjects

**Data requirement**: Paired tests assume exactly **one observation per subject
per condition**. If your data has multiple trials per cell, aggregate first
(e.g., take the mean).

**Hypothesis testing**

| Type           | No. of groups | Test                                               | Function used            |
| :------------- | :------------ | :------------------------------------------------- | :----------------------- |
| Parametric     | 2             | Student's *t*-test                                 | `stats::t.test()`        |
| Non-parametric | 2             | Wilcoxon signed-rank test                          | `stats::wilcox.test()`   |
| Robust         | 2             | Yuen's test on trimmed means for dependent samples | `WRS2::yuend()`          |
| Bayesian       | 2             | Student's *t*-test                                 | `BayesFactor::ttestBF()` |

**Effect size estimation**

| Type           | No. of groups | Effect size                                             | CI available? | Function used                                      |
| :------------- | :------------ | :------------------------------------------------------ | :------------ | :------------------------------------------------- |
| Parametric     | 2             | Cohen's *d*, Hedge's *g*                                | Yes           | `effectsize::cohens_d()`, `effectsize::hedges_g()` |
| Non-parametric | 2             | *r* (rank-biserial correlation)                         | Yes           | `effectsize::rank_biserial()`                      |
| Robust         | 2             | Algina-Keselman-Penfield robust standardized difference | Yes           | `WRS2::wmcpAKP()`                                  |
| Bayesian       | 2             | difference                                              | Yes           | `bayestestR::describe_posterior()`                 |

#### between-subjects

**Hypothesis testing**

| Type           | Equal variance? | Test                      | *p*-value adjustment? | Function used                     |
| :------------- | :-------------- | :------------------------ | :-------------------- | :-------------------------------- |
| Parametric     | No              | Games-Howell test         | Yes                   | `PMCMRplus::gamesHowellTest()`    |
| Parametric     | Yes             | Student's *t*-test        | Yes                   | `stats::pairwise.t.test()`        |
| Non-parametric | No              | Dunn test                 | Yes                   | `PMCMRplus::kwAllPairsDunnTest()` |
| Robust         | No              | Yuen's trimmed means test | Yes                   | `WRS2::lincon()`                  |
| Bayesian       | `NA`            | Student's *t*-test        | `NA`                  | `BayesFactor::ttestBF()`          |

**Effect size estimation**

Not supported.

#### within-subjects

**Data requirement**: Paired pairwise tests assume exactly **one observation per
subject per condition**. If your data has multiple trials per cell, aggregate
first (e.g., take the mean).

**Hypothesis testing**

| Type           | Test                      | *p*-value adjustment? | Function used                     |
| :------------- | :------------------------ | :-------------------- | :-------------------------------- |
| Parametric     | Student's *t*-test        | Yes                   | `stats::pairwise.t.test()`        |
| Non-parametric | Durbin-Conover test       | Yes                   | `PMCMRplus::durbinAllPairsTest()` |
| Robust         | Yuen's trimmed means test | Yes                   | `WRS2::rmmcp()`                   |
| Bayesian       | Student's *t*-test        | `NA`                  | `BayesFactor::ttestBF()`          |

**Effect size estimation**

Not supported.

The `{statsExpressions}` package has two key aims: 

- to provide a consistent syntax to do statistical analysis with tidy data (in pipe-friendly manner),
- to provide statistical expressions (pre-formatted in-text statistical
results) for plotting functions.

Statistical packages exhibit substantial diversity in terms of their syntax and
expected input type. This can make it difficult to switch from one statistical
approach to another. For example, some functions expect vectors as inputs, while
others expect dataframes. Depending on whether it is a repeated measures design
or not, different functions might expect data to be in wide or long format. Some
functions can internally omit missing values, while other functions error in
their presence. Furthermore, if someone wishes to utilize the objects returned
by these packages downstream in their workflow, this is not straightforward
either because even functions from the same package can return a list, a matrix,
an array, a dataframe, etc., depending on the function.

This is where `{statsExpressions}` comes in: It can be thought of as a unified
portal through which most of the functionality in these underlying packages can
be accessed, with a simpler interface and no requirement to change data format.

This package forms the statistical processing backend for [`ggstatsplot`](https://www.indrapatil.com/ggstatsplot/) package.

For more documentation, see the dedicated [website](https://www.indrapatil.com/statsExpressions/).

---
title: "Data frame outputs"
output:
  rmarkdown::html_vignette:
    toc: true
    toc_depth: 4
vignette: >
  %\VignetteIndexEntry{Data frame outputs}
  %\VignetteEngine{knitr::rmarkdown}
  %\VignetteEncoding{UTF-8}
---

```{r}
#| label = "setup",
#| message = FALSE,
#| warning = FALSE,
#| include = FALSE,
#| echo = FALSE
source("../setup.R")

pkgs <- c(
  "ggplot2",
  "metaplus"
)

successfully_loaded <- purrr::map_lgl(pkgs, requireNamespace, quietly = TRUE)
can_evaluate <- all(successfully_loaded)

if (can_evaluate) {
  purrr::walk(pkgs, library, character.only = TRUE)
} else {
  knitr::opts_chunk$set(eval = FALSE)
}
```

This vignette can be cited as:

```{r}
#| label = "citation",
#| echo = FALSE,
#| comment = ""
citation("statsExpressions")
```

## One-sample test output

```{r}
#| label = "onesample",
#| file = "../../man/examples/examples-one-sample-test.R"
```

## Two-sample test output

### within-subjects design

```{r}
#| label = "twosample_w"
# ----------------------- within-subjects -------------------------------------

# data
df <- dplyr::filter(bugs_long, condition %in% c("LDLF", "LDHF"))

# for reproducibility
set.seed(123)

# ----------------------- parametric ---------------------------------------

two_sample_test(
  df,
  condition,
  desire,
  subject.id = subject,
  paired = TRUE,
  type = "parametric"
)

# ----------------------- non-parametric -----------------------------------

two_sample_test(
  df,
  condition,
  desire,
  subject.id = subject,
  paired = TRUE,
  type = "nonparametric"
)

# ----------------------- robust --------------------------------------------

two_sample_test(
  df,
  condition,
  desire,
  subject.id = subject,
  paired = TRUE,
  type = "robust"
)

# ----------------------- Bayesian ---------------------------------------

two_sample_test(
  df,
  condition,
  desire,
  subject.id = subject,
  paired = TRUE,
  type = "bayes"
)
```

### between-subjects design

```{r}
#| label = "twosample_b"
# ----------------------- between-subjects -------------------------------------

# for reproducibility
set.seed(123)

# ----------------------- parametric ---------------------------------------

# unequal variance
two_sample_test(ToothGrowth, supp, len, type = "parametric")

# equal variance
two_sample_test(ToothGrowth, supp, len, type = "parametric", var.equal = TRUE)

# biased (Cohen's d) effect size
two_sample_test(ToothGrowth, supp, len, type = "parametric", effsize.type = "d")

# ----------------------- non-parametric -----------------------------------

two_sample_test(ToothGrowth, supp, len, type = "nonparametric")

# ----------------------- robust --------------------------------------------

two_sample_test(ToothGrowth, supp, len, type = "robust")

# ----------------------- Bayesian ---------------------------------------

two_sample_test(ToothGrowth, supp, len, type = "bayes")
```

## One-way ANOVAs

### within-subjects design

```{r}
#| label = "anova_w"
suppressPackageStartupMessages(library(afex))

# ----------------------- parametric ---------------------------------------

set.seed(123)
oneway_anova(
  data       = bugs_long,
  x          = condition,
  y          = desire,
  paired     = TRUE,
  subject.id = subject,
  type       = "p"
)

# ----------------------- non-parametric -----------------------------------

set.seed(123)
oneway_anova(
  data       = bugs_long,
  x          = condition,
  y          = desire,
  paired     = TRUE,
  subject.id = subject,
  type       = "np"
)

# ----------------------- robust --------------------------------------------

set.seed(123)
oneway_anova(
  data       = bugs_long,
  x          = condition,
  y          = desire,
  paired     = TRUE,
  subject.id = subject,
  type       = "r"
)

# ----------------------- Bayesian ---------------------------------------

set.seed(123)
oneway_anova(
  data       = bugs_long,
  x          = condition,
  y          = desire,
  paired     = TRUE,
  subject.id = subject,
  type       = "bayes"
)
```

### between-subjects design

```{r}
#| label = "anova_b"

# ----------------------- parametric ---------------------------------------

# unequal variance
set.seed(123)
oneway_anova(
  data      = iris,
  x         = Species,
  y         = Sepal.Length,
  type      = "p"
)

# equal variance
set.seed(123)
oneway_anova(
  data      = iris,
  x         = Species,
  y         = Sepal.Length,
  var.equal = TRUE,
  type      = "p"
)

# ----------------------- non-parametric -----------------------------------

set.seed(123)
oneway_anova(
  data      = iris,
  x         = Species,
  y         = Sepal.Length,
  type      = "np"
)

# ----------------------- robust --------------------------------------------

set.seed(123)
oneway_anova(
  data      = iris,
  x         = Species,
  y         = Sepal.Length,
  type      = "r"
)

# ----------------------- Bayesian ---------------------------------------

set.seed(123)
oneway_anova(
  data      = iris,
  x         = Species,
  y         = Sepal.Length,
  type      = "bayes"
)
```

## Contingency table analysis output

```{r}
#| label = "crosstabs"
#### -------------------- association test ------------------------ ####

# ------------------------ frequentist ---------------------------------

# unpaired

set.seed(123)
contingency_table(
  data = mtcars,
  x = am,
  y = vs,
  paired = FALSE
)

# paired

paired_data <- dplyr::tibble(
  response_before = structure(
    c(1L, 2L, 1L, 2L),
    levels = c("no", "yes"),
    class = "factor"
  ),
  response_after = structure(
    c(1L, 1L, 2L, 2L),
    levels = c("no", "yes"),
    class = "factor"
  ),
  Freq = c(65L, 25L, 5L, 5L)
)

set.seed(123)
contingency_table(
  data = paired_data,
  x = response_before,
  y = response_after,
  paired = TRUE,
  counts = Freq
)

# ------------------------ Bayesian -------------------------------------

# unpaired

set.seed(123)
contingency_table(
  data = mtcars,
  x = am,
  y = vs,
  paired = FALSE,
  type = "bayes"
)

# paired

set.seed(123)
contingency_table(
  data = paired_data,
  x = response_before,
  y = response_after,
  paired = TRUE,
  counts = Freq,
  type = "bayes"
)

#### -------------------- goodness-of-fit test -------------------- ####

# ------------------------ frequentist ---------------------------------

set.seed(123)
contingency_table(
  data = as.data.frame(HairEyeColor),
  x = Eye,
  counts = Freq
)

# ------------------------ Bayesian -------------------------------------

set.seed(123)
contingency_table(
  data = as.data.frame(HairEyeColor),
  x = Eye,
  counts = Freq,
  ratio = c(0.2, 0.2, 0.3, 0.3),
  type = "bayes"
)
```

## Correlation analysis output

```{r}
#| label = "corr",
#| file = "../../man/examples/examples-corr-test.R"
```

## Random-effects meta-analysis output

```{r}
#| label = "meta"
library(metaplus)

# renaming columns to `{statsExpressions}` conventions
df <- dplyr::rename(mag, estimate = yi, std.error = sei)

# ----------------------- parametric ---------------------------------------

set.seed(123)
meta_analysis(df, type = "parametric")

# ----------------------- robust --------------------------------------------

set.seed(123)
meta_analysis(df, type = "robust")

# ----------------------- Bayesian ---------------------------------------

# suppress warnings about divergent transitions after warmup
set.seed(123)
suppressWarnings(meta_analysis(df, type = "bayes"))
```

## Centrality description

```{r}
#| label = "centrality",
#| file = "../../man/examples/examples-centrality-description.R"
```

## Pairwise comparisons for one-way design

### Between-subjects design

```{r}
# ----------------------- parametric -----------------------

# if `var.equal = TRUE`, then Student's *t*-test will be run
pairwise_comparisons(
  data            = ggplot2::msleep,
  x               = vore,
  y               = brainwt,
  type            = "parametric",
  var.equal       = TRUE,
  paired          = FALSE,
  p.adjust.method = "bonferroni"
)

# if `var.equal = FALSE`, then Games-Howell test will be run
pairwise_comparisons(
  data            = ggplot2::msleep,
  x               = vore,
  y               = brainwt,
  type            = "parametric",
  var.equal       = FALSE,
  paired          = FALSE,
  p.adjust.method = "bonferroni"
)

# ----------------------- non-parametric -------------------

pairwise_comparisons(
  data            = ggplot2::msleep,
  x               = vore,
  y               = brainwt,
  type            = "nonparametric",
  paired          = FALSE,
  p.adjust.method = "none"
)

# ----------------------- robust ---------------------------

pairwise_comparisons(
  data            = ggplot2::msleep,
  x               = vore,
  y               = brainwt,
  type            = "robust",
  paired          = FALSE,
  p.adjust.method = "fdr"
)

# ----------------------- Bayesian -------------------------

pairwise_comparisons(
  data   = ggplot2::msleep,
  x      = vore,
  y      = brainwt,
  type   = "bayes",
  paired = FALSE
)
```


### Within-subjects design

```{r}
# ----------------------- parametric -----------------------

pairwise_comparisons(
  data            = bugs_long,
  x               = condition,
  y               = desire,
  subject.id      = subject,
  type            = "parametric",
  paired          = TRUE,
  p.adjust.method = "BH"
)

# ----------------------- non-parametric -------------------

pairwise_comparisons(
  data            = bugs_long,
  x               = condition,
  y               = desire,
  subject.id      = subject,
  type            = "nonparametric",
  paired          = TRUE,
  p.adjust.method = "BY"
)

# ----------------------- robust ---------------------------

pairwise_comparisons(
  data            = bugs_long,
  x               = condition,
  y               = desire,
  subject.id      = subject,
  type            = "robust",
  paired          = TRUE,
  p.adjust.method = "hommel"
)

# ----------------------- Bayesian -------------------------

pairwise_comparisons(
  data       = bugs_long,
  x          = condition,
  y          = desire,
  subject.id = subject,
  type       = "bayes",
  paired     = TRUE,
  bf.prior   = 0.77
)
```

## Suggestions

If you find any bugs or have any suggestions/remarks, please file an issue on GitHub: <https://github.com/IndrajeetPatil/statsExpressions/issues>

The table below provides summary about:

- statistical test carried out for inferential statistics
- type of effect size estimate and a measure of uncertainty for this estimate
- functions used internally to compute these details

**Hypothesis testing** and **Effect size estimation**

| Type           | Test                                         | CI available? | Function used                |
| :------------- | :------------------------------------------- | :------------ | :--------------------------- |
| Parametric     | Pearson's correlation coefficient            | Yes           | `correlation::correlation()` |
| Non-parametric | Spearman's rank correlation coefficient      | Yes           | `correlation::correlation()` |
| Robust         | Winsorized Pearson's correlation coefficient | Yes           | `correlation::correlation()` |
| Bayesian       | Bayesian Pearson's correlation coefficient   | Yes           | `correlation::correlation()` |

#### between-subjects

**Hypothesis testing**

| Type           | No. of groups | Test                                            | Function used            |
| :------------- | :------------ | :---------------------------------------------- | :----------------------- |
| Parametric     | > 2           | Fisher's or Welch's one-way ANOVA               | `stats::oneway.test()`   |
| Non-parametric | > 2           | Kruskal-Wallis one-way ANOVA                    | `stats::kruskal.test()`  |
| Robust         | > 2           | Heteroscedastic one-way ANOVA for trimmed means | `WRS2::t1way()`          |
| Bayesian       | > 2           | Fisher's ANOVA                                  | `BayesFactor::anovaBF()` |

**Effect size estimation**

| Type           | No. of groups | Effect size                                | CI available? | Function used                                              |
| :------------- | :------------ | :----------------------------------------- | :------------ | :--------------------------------------------------------- |
| Parametric     | > 2           | partial eta-squared, partial omega-squared | Yes           | `effectsize::omega_squared()`, `effectsize::eta_squared()` |
| Non-parametric | > 2           | rank epsilon squared                       | Yes           | `effectsize::rank_epsilon_squared()`                       |
| Robust         | > 2           | Explanatory measure of effect size         | Yes           | `WRS2::t1way()`                                            |
| Bayesian       | > 2           | Bayesian R-squared                         | Yes           | `performance::r2_bayes()`                                  |

#### within-subjects

**Data requirement**: Repeated measures tests assume a *complete* design with
exactly **one observation per subject per condition**. If your data has multiple
trials per cell, aggregate first (e.g., take the mean). Verify with
`table(data$subject, data$condition)` — every cell should equal `1`.

**Hypothesis testing**

| Type           | No. of groups | Test                                                              | Function used            |
| :------------- | :------------ | :---------------------------------------------------------------- | :----------------------- |
| Parametric     | > 2           | One-way repeated measures ANOVA                                   | `afex::aov_ez()`         |
| Non-parametric | > 2           | Friedman rank sum test                                            | `stats::friedman.test()` |
| Robust         | > 2           | Heteroscedastic one-way repeated measures ANOVA for trimmed means | `WRS2::rmanova()`        |
| Bayesian       | > 2           | One-way repeated measures ANOVA                                   | `BayesFactor::anovaBF()` |

**Effect size estimation**

| Type           | No. of groups | Effect size                                                     | CI available? | Function used                                              |
| :------------- | :------------ | :-------------------------------------------------------------- | :------------ | :--------------------------------------------------------- |
| Parametric     | > 2           | partial eta-squared, partial omega-squared                      | Yes           | `effectsize::omega_squared()`, `effectsize::eta_squared()` |
| Non-parametric | > 2           | Kendall's coefficient of concordance                            | Yes           | `effectsize::kendalls_w()`                                 |
| Robust         | > 2           | Algina-Keselman-Penfield robust standardized difference average | Yes           | `WRS2::wmcpAKP()`                                          |
| Bayesian       | > 2           | Bayesian R-squared                                              | Yes           | `performance::r2_bayes()`                                  |

**Summary of available analyses**

| Test                       | Function                 |
| :------------------------- | :----------------------- |
| one-sample *t*-test        | `one_sample_test()`      |
| two-sample *t*-test        | `two_sample_test()`      |
| one-way ANOVA              | `oneway_anova()`         |
| correlation analysis       | `corr_test()`            |
| contingency table analysis | `contingency_table()`    |
| meta-analysis              | `meta_analysis()`        |
| pairwise comparisons       | `pairwise_comparisons()` |
| pairwise contingency table | `pairwise_contingency_table()` |

**Summary of details available for analyses**

| Analysis                        | Hypothesis testing | Effect size estimation |
| :------------------------------ | :----------------- | :--------------------- |
| (one/two-sample) *t*-test       | ✅                 | ✅                     |
| one-way ANOVA                   | ✅                 | ✅                     |
| correlation                     | ✅                 | ✅                     |
| (one/two-way) contingency table | ✅                 | ✅                     |
| random-effects meta-analysis    | ✅                 | ✅                     |

**Summary of supported statistical approaches**

| Description                                       | Parametric | Non-parametric | Robust | Bayesian |
| :------------------------------------------------ | :--------- | :------------- | :----- | :------- |
| Between group/condition comparisons               | ✅         | ✅             | ✅     | ✅       |
| Within group/condition comparisons                | ✅         | ✅             | ✅     | ✅       |
| Distribution of a numeric variable                | ✅         | ✅             | ✅     | ✅       |
| Correlation between two variables                 | ✅         | ✅             | ✅     | ✅       |
| Association between categorical variables         | ✅         | ✅             | ❌     | ✅       |
| Equal proportions for categorical variable levels | ✅         | ✅             | ❌     | ✅       |
| Random-effects meta-analysis                      | ✅         | ❌             | ✅     | ✅       |

# contingency_table works

    Code
      select(df1, -expression)
    Output
      # A tibble: 1 x 12
        statistic    df p.value method                     effectsize        estimate
            <dbl> <int>   <dbl> <chr>                      <chr>                <dbl>
      1      8.74     2  0.0126 Pearson's Chi-squared test Cramer's V (adj.)    0.464
        conf.level conf.low conf.high conf.method conf.distribution n.obs
             <dbl>    <dbl>     <dbl> <chr>       <chr>             <int>
      1       0.99        0     0.937 ncp         chisq                32

---

    Code
      df1[["expression"]]
    Output
      [[1]]
      list(chi["Pearson"]^2 * "(" * 2 * ")" == "8.74073", italic(p) == 
          "0.01265", widehat(italic("V"))["Cramer"] == "0.46431", CI["99%"] ~ 
          "[" * "0.00000", "0.93683" * "]", italic("n")["obs"] == "32")
      

---

    Code
      select(df2, -expression)
    Output
      # A tibble: 1 x 12
        statistic    df   p.value method                     effectsize       
            <dbl> <int>     <dbl> <chr>                      <chr>            
      1      457.     1 2.30e-101 Pearson's Chi-squared test Cramer's V (adj.)
        estimate conf.level conf.low conf.high conf.method conf.distribution n.obs
           <dbl>      <dbl>    <dbl>     <dbl> <chr>       <chr>             <int>
      1    0.455       0.95    0.413     0.497 ncp         chisq              2201

---

    Code
      df2[["expression"]]
    Output
      [[1]]
      list(chi["Pearson"]^2 * "(" * 1 * ")" == "456.87", italic(p) == 
          "2.30e-101", widehat(italic("V"))["Cramer"] == "0.46", CI["95%"] ~ 
          "[" * "0.41", "0.50" * "]", italic("n")["obs"] == "2,201")
      

---

    Code
      select(df3, -expression)
    Output
      # A tibble: 1 x 12
        statistic    df p.value method                     effectsize        estimate
            <dbl> <int>   <dbl> <chr>                      <chr>                <dbl>
      1      15.8    15   0.399 Pearson's Chi-squared test Cramer's V (adj.)   0.0558
        conf.level conf.low conf.high conf.method conf.distribution n.obs
             <dbl>    <dbl>     <dbl> <chr>       <chr>             <int>
      1       0.99        0     0.252 ncp         chisq                52

---

    Code
      df3[["expression"]]
    Output
      [[1]]
      list(chi["Pearson"]^2 * "(" * 15 * ")" == "15.75", italic(p) == 
          "0.40", widehat(italic("V"))["Cramer"] == "0.06", CI["99%"] ~ 
          "[" * "0.00", "0.25" * "]", italic("n")["obs"] == "52")
      

# paired contingency_table works 

    Code
      select(df1, -expression)
    Output
      # A tibble: 1 x 11
        statistic    df  p.value method                     effectsize estimate
            <dbl> <dbl>    <dbl> <chr>                      <chr>         <dbl>
      1      13.3     1 0.000261 McNemar's Chi-squared test Cohen's g     0.333
        conf.level conf.low conf.high conf.method n.obs
             <dbl>    <dbl>     <dbl> <chr>       <int>
      1       0.95    0.164     0.427 binomial      100

---

    Code
      df1[["expression"]]
    Output
      [[1]]
      list(chi["McNemar"]^2 * "(" * 1 * ")" == "13.33333", italic(p) == 
          "0.00026", widehat(italic("g"))["Cohen"] == "0.33333", CI["95%"] ~ 
          "[" * "0.16436", "0.42663" * "]", italic("n")["pairs"] == 
          "100")
      

---

    Code
      select(df2, -expression)
    Output
      # A tibble: 1 x 11
        statistic    df  p.value method                     effectsize estimate
            <dbl> <dbl>    <dbl> <chr>                      <chr>         <dbl>
      1      13.3     1 0.000261 McNemar's Chi-squared test Cohen's g     0.333
        conf.level conf.low conf.high conf.method n.obs
             <dbl>    <dbl>     <dbl> <chr>       <int>
      1        0.9    0.229       0.5 binomial       95

---

    Code
      df2[["expression"]]
    Output
      [[1]]
      list(chi["McNemar"]^2 * "(" * 1 * ")" == "13.333", italic(p) == 
          "2.607e-04", widehat(italic("g"))["Cohen"] == "0.333", CI["90%"] ~ 
          "[" * "0.229", "0.500" * "]", italic("n")["pairs"] == "95")
      

# Goodness of Fit contingency_table works without counts

    Code
      select(df1, -expression)
    Output
      # A tibble: 1 x 12
        statistic    df p.value method                                   effectsize 
            <dbl> <dbl>   <dbl> <chr>                                    <chr>      
      1      1.12     1   0.289 Chi-squared test for given probabilities Pearson's C
        estimate conf.level conf.low conf.high conf.method conf.distribution n.obs
           <dbl>      <dbl>    <dbl>     <dbl> <chr>       <chr>             <int>
      1    0.184       0.99        0     0.541 ncp         chisq                32

---

    Code
      df1[["expression"]]
    Output
      [[1]]
      list(chi["gof"]^2 * "(" * 1 * ")" == "1.12500", italic(p) == 
          "0.28884", widehat(italic("C"))["Pearson"] == "0.18429", 
          CI["99%"] ~ "[" * "0.00000", "0.54074" * "]", italic("n")["obs"] == 
              "32")
      

---

    Code
      select(df2, -expression)
    Output
      # A tibble: 1 x 12
        statistic    df   p.value method                                   effectsize 
            <dbl> <dbl>     <dbl> <chr>                                    <chr>      
      1      722.     1 3.92e-159 Chi-squared test for given probabilities Pearson's C
        estimate conf.level conf.low conf.high conf.method conf.distribution n.obs
           <dbl>      <dbl>    <dbl>     <dbl> <chr>       <chr>             <int>
      1    0.497       0.95    0.474         1 ncp         chisq              2201

---

    Code
      df2[["expression"]]
    Output
      [[1]]
      list(chi["gof"]^2 * "(" * 1 * ")" == "722.45", italic(p) == "3.92e-159", 
          widehat(italic("C"))["Pearson"] == "0.50", CI["95%"] ~ "[" * 
              "0.47", "1.00" * "]", italic("n")["obs"] == "2,201")
      

---

    Code
      select(df3, -expression)
    Output
      # A tibble: 1 x 12
        statistic    df     p.value method                                  
            <dbl> <dbl>       <dbl> <chr>                                   
      1      33.8     3 0.000000223 Chi-squared test for given probabilities
        effectsize  estimate conf.level conf.low conf.high conf.method
        <chr>          <dbl>      <dbl>    <dbl>     <dbl> <chr>      
      1 Pearson's C    0.555       0.95    0.385     0.658 ncp        
        conf.distribution n.obs
        <chr>             <int>
      1 chisq                76

---

    Code
      df3[["expression"]]
    Output
      [[1]]
      list(chi["gof"]^2 * "(" * 3 * ")" == "33.76", italic(p) == "2.23e-07", 
          widehat(italic("C"))["Pearson"] == "0.55", CI["95%"] ~ "[" * 
              "0.38", "0.66" * "]", italic("n")["obs"] == "76")
      

# bayesian (proportion test)

    Code
      select(df1, -expression)
    Output
      # A tibble: 1 x 3
         bf10 prior.scale method                                     
        <dbl>       <dbl> <chr>                                      
      1 0.247           1 Bayesian one-way contingency table analysis

---

    Code
      df1[["expression"]]
    Output
      [[1]]
      list(log[e] * (BF["01"]) == "1.40", italic("a")["Gunel-Dickey"] == 
          "1.00")
      

---

    Code
      select(df2, -expression)
    Output
      # A tibble: 1 x 3
         bf10 prior.scale method                                     
        <dbl>       <dbl> <chr>                                      
      1 0.579          10 Bayesian one-way contingency table analysis

---

    Code
      df2[["expression"]]
    Output
      [[1]]
      list(log[e] * (BF["01"]) == "0.55", italic("a")["Gunel-Dickey"] == 
          "10.00")
      

# bayesian (contingency tab)

    Code
      df1[["expression"]]
    Output
      [[1]]
      list(log[e] * (BF["01"]) == "-2.82", widehat(italic("V"))["Cramer"]^"posterior" == 
          "0.41", CI["95%"]^ETI ~ "[" * "0.00", "0.68" * "]", italic("a")["Gunel-Dickey"] == 
          "1.00")
      

---

    Code
      df2[["expression"]]
    Output
      [[1]]
      list(log[e] * (BF["01"]) == "3.29", widehat(italic("V"))["Cramer"]^"posterior" == 
          "0.00", CI["95%"]^ETI ~ "[" * "0.00", "0.26" * "]", italic("a")["Gunel-Dickey"] == 
          "1.00")
      

# contingency_table() expression is invariant to `options(OutDec)`:  dec=.

    Code
      df[["expression"]]
    Output
      [[1]]
      list(chi["Pearson"]^2 * "(" * 2 * ")" == "8.74073", italic(p) == 
          "0.01265", widehat(italic("V"))["Cramer"] == "0.46431", CI["99%"] ~ 
          "[" * "0.00000", "0.93683" * "]", italic("n")["obs"] == "32")
      

# contingency_table() expression is invariant to `options(OutDec)`:  dec=,

    Code
      df[["expression"]]
    Output
      [[1]]
      list(chi["Pearson"]^2 * "(" * 2 * ")" == "8.74073", italic(p) == 
          "0.01265", widehat(italic("V"))["Cramer"] == "0.46431", CI["99%"] ~ 
          "[" * "0.00000", "0.93683" * "]", italic("n")["obs"] == "32")
      

# parametric anova subtitles work (without NAs)

    Code
      select(df, -expression)
    Output
      # A tibble: 1 x 13
        statistic    df df.error   p.value
            <dbl> <dbl>    <dbl>     <dbl>
      1      20.2     2     19.0 0.0000196
        method                                                   effectsize estimate
        <chr>                                                    <chr>         <dbl>
      1 One-way analysis of means (not assuming equal variances) Eta2          0.681
        conf.level conf.low conf.high conf.method conf.distribution n.obs
             <dbl>    <dbl>     <dbl> <chr>       <chr>             <int>
      1       0.95    0.437         1 ncp         F                    32

---

    Code
      df[["expression"]]
    Output
      [[1]]
      list(italic("F")["Welch"](2, 18.97383) == "20.24946", italic(p) == 
          "0.00002", widehat(eta["p"]^2) == "0.68097", CI["95%"] ~ 
          "[" * "0.43668", "1.00000" * "]", italic("n")["obs"] == "32")
      

---

    Code
      select(df1, -expression)
    Output
      # A tibble: 1 x 13
        statistic    df df.error    p.value method                    effectsize
            <dbl> <dbl>    <dbl>      <dbl> <chr>                     <chr>     
      1      22.9     2       29 0.00000107 One-way analysis of means Eta2      
        estimate conf.level conf.low conf.high conf.method conf.distribution n.obs
           <dbl>      <dbl>    <dbl>     <dbl> <chr>       <chr>             <int>
      1    0.612       0.95    0.404         1 ncp         F                    32

---

    Code
      df1[["expression"]]
    Output
      [[1]]
      list(italic("F")["Fisher"](2, 29) == "22.91139", italic(p) == 
          "1.07468e-06", widehat(eta["p"]^2) == "0.61242", CI["95%"] ~ 
          "[" * "0.40360", "1.00000" * "]", italic("n")["obs"] == "32")
      

# parametric anova subtitles with partial omega-squared

    Code
      select(df1, -expression)
    Output
      # A tibble: 1 x 13
        statistic    df df.error p.value
            <dbl> <dbl>    <dbl>   <dbl>
      1      2.27     3     24.0   0.107
        method                                                   effectsize estimate
        <chr>                                                    <chr>         <dbl>
      1 One-way analysis of means (not assuming equal variances) Omega2        0.119
        conf.level conf.low conf.high conf.method conf.distribution n.obs
             <dbl>    <dbl>     <dbl> <chr>       <chr>             <int>
      1       0.95        0         1 ncp         F                    51

---

    Code
      df1[["expression"]]
    Output
      [[1]]
      list(italic("F")["Welch"](3, 24.0475) == "2.2653", italic(p) == 
          "0.1066", widehat(omega["p"]^2) == "0.1192", CI["95%"] ~ 
          "[" * "0.0000", "1.0000" * "]", italic("n")["obs"] == "51")
      

# paired parametric anova subtitles work (without NAs)

    Code
      select(df1, -expression)
    Output
      # A tibble: 1 x 17
        term      sumsq sum.squares.error    df df.error meansq statistic  p.value
        <chr>     <dbl>             <dbl> <dbl>    <dbl>  <dbl>     <dbl>    <dbl>
      1 condition 1656.              318.  1.15     171.   1.86      776. 1.32e-69
        method                                              effectsize       estimate
        <chr>                                               <chr>               <dbl>
      1 ANOVA estimation for factorial designs using 'afex' Omega2 (partial)    0.707
        conf.level conf.low conf.high conf.method conf.distribution n.obs
             <dbl>    <dbl>     <dbl> <chr>       <chr>             <int>
      1       0.99    0.658         1 ncp         F                   150

---

    Code
      df1[["expression"]]
    Output
      [[1]]
      list(italic("F")["Fisher"](1.149, 171.217) == "776.318", italic(p) == 
          "1.325e-69", widehat(omega["p"]^2) == "0.707", CI["99%"] ~ 
          "[" * "0.658", "1.000" * "]", italic("n")["pairs"] == "150")
      

# corr_test works - parametric

    Code
      select(df1, -expression)
    Output
      # A tibble: 1 x 13
        parameter1 parameter2 effectsize          estimate conf.level conf.low
        <chr>      <chr>      <chr>                  <dbl>      <dbl>    <dbl>
      1 brainwt    sleep_rem  Pearson correlation   -0.221        0.9   -0.438
        conf.high statistic df.error p.value method              n.obs conf.method
            <dbl>     <dbl>    <int>   <dbl> <chr>               <int> <chr>      
      1    0.0201     -1.54       46   0.131 Pearson correlation    48 normal     

---

    Code
      df1[["expression"]]
    Output
      [[1]]
      list(italic("t")["Student"] * "(" * 46 * ")" == "-1.539", italic(p) == 
          "0.131", widehat(italic("r"))["Pearson"] == "-0.221", CI["90%"] ~ 
          "[" * "-0.438", "0.020" * "]", italic("n")["pairs"] == "48")
      

---

    Code
      select(df2, -expression)
    Output
      # A tibble: 1 x 13
        parameter1 parameter2 effectsize          estimate conf.level conf.low
        <chr>      <chr>      <chr>                  <dbl>      <dbl>    <dbl>
      1 wt         mpg        Pearson correlation   -0.868       0.95   -0.934
        conf.high statistic df.error  p.value method              n.obs conf.method
            <dbl>     <dbl>    <int>    <dbl> <chr>               <int> <chr>      
      1    -0.744     -9.56       30 1.29e-10 Pearson correlation    32 normal     

---

    Code
      df2[["expression"]]
    Output
      [[1]]
      list(italic("t")["Student"] * "(" * 30 * ")" == "-9.559", italic(p) == 
          "1.294e-10", widehat(italic("r"))["Pearson"] == "-0.868", 
          CI["95%"] ~ "[" * "-0.934", "-0.744" * "]", italic("n")["pairs"] == 
              "32")
      

# corr_test works - robust

    Code
      select(df1, -expression)
    Output
      # A tibble: 1 x 13
        parameter1 parameter2  effectsize                     estimate conf.level
        <chr>      <chr>       <chr>                             <dbl>      <dbl>
      1 brainwt    sleep_total Winsorized Pearson correlation   -0.549        0.5
        conf.low conf.high statistic df.error   p.value method                        
           <dbl>     <dbl>     <dbl>    <int>     <dbl> <chr>                         
      1   -0.611    -0.481     -4.83       54 0.0000117 Winsorized Pearson correlation
        n.obs conf.method
        <int> <chr>      
      1    56 normal     

---

    Code
      df1[["expression"]]
    Output
      [[1]]
      list(italic("t")["Student"] * "(" * 54 * ")" == "-4.8286", italic(p) == 
          "1.1723e-05", widehat(italic("r"))["Winsorized"] == "-0.5491", 
          CI["50%"] ~ "[" * "-0.6106", "-0.4812" * "]", italic("n")["pairs"] == 
              "56")
      

---

    Code
      select(df2, -expression)
    Output
      # A tibble: 1 x 13
        parameter1 parameter2 effectsize                     estimate conf.level
        <chr>      <chr>      <chr>                             <dbl>      <dbl>
      1 wt         mpg        Winsorized Pearson correlation   -0.864       0.95
        conf.low conf.high statistic df.error  p.value method                        
           <dbl>     <dbl>     <dbl>    <int>    <dbl> <chr>                         
      1   -0.932    -0.738     -9.41       30 1.84e-10 Winsorized Pearson correlation
        n.obs conf.method
        <int> <chr>      
      1    32 normal     

---

    Code
      df2[["expression"]]
    Output
      [[1]]
      list(italic("t")["Student"] * "(" * 30 * ")" == "-9.41", italic(p) == 
          "1.84e-10", widehat(italic("r"))["Winsorized"] == "-0.86", 
          CI["95%"] ~ "[" * "-0.93", "-0.74" * "]", italic("n")["pairs"] == 
              "32")
      

# corr_test works - nonparametric

    Code
      select(df1, -expression)
    Output
      # A tibble: 1 x 12
        parameter1 parameter2  effectsize           estimate conf.level conf.low
        <chr>      <chr>       <chr>                   <dbl>      <dbl>    <dbl>
      1 brainwt    sleep_total Spearman correlation   -0.594        0.5   -0.652
        conf.high statistic    p.value method               n.obs conf.method
            <dbl>     <dbl>      <dbl> <chr>                <int> <chr>      
      1    -0.528    46627. 0.00000143 Spearman correlation    56 normal     

---

    Code
      df1[["expression"]]
    Output
      [[1]]
      list(italic("S") == "46627.1234", italic(p) == "1.4262e-06", 
          widehat(rho)["Spearman"] == "-0.5935", CI["50%"] ~ "[" * 
              "-0.6518", "-0.5283" * "]", italic("n")["pairs"] == "56")
      

---

    Code
      select(df2, -expression)
    Output
      # A tibble: 1 x 12
        parameter1 parameter2 effectsize           estimate conf.level conf.low
        <chr>      <chr>      <chr>                   <dbl>      <dbl>    <dbl>
      1 wt         mpg        Spearman correlation   -0.886       0.95   -0.945
        conf.high statistic  p.value method               n.obs conf.method
            <dbl>     <dbl>    <dbl> <chr>                <int> <chr>      
      1    -0.774    10292. 1.49e-11 Spearman correlation    32 normal     

---

    Code
      df2[["expression"]]
    Output
      [[1]]
      list(italic("S") == "10292.3186", italic(p) == "1.4876e-11", 
          widehat(rho)["Spearman"] == "-0.8864", CI["95%"] ~ "[" * 
              "-0.9447", "-0.7740" * "]", italic("n")["pairs"] == "32")
      

# corr_test works - Bayesian

    Code
      df1[["expression"]]
    Output
      [[1]]
      list(log[e] * (BF["01"]) == "0.49", widehat(rho)["Pearson"]^"posterior" == 
          "-0.21", CI["99%"]^HDI ~ "[" * "-0.47", "0.05" * "]", italic("r")["beta"]^"JZS" == 
          "1.25")
      

---

    Code
      df2[["expression"]]
    Output
      [[1]]
      list(log[e] * (BF["01"]) == "-17.84", widehat(rho)["Pearson"]^"posterior" == 
          "-0.84", CI["95%"]^HDI ~ "[" * "-0.93", "-0.73" * "]", italic("r")["beta"]^"JZS" == 
          "1.41")
      

# bayesian (independent samples t-test)

    Code
      df[["expression"]]
    Output
      [[1]]
      list(log[e] * (BF["01"]) == "-0.18", widehat(delta)["difference"]^"posterior" == 
          "3.16", CI["99%"]^ETI ~ "[" * "-1.43", "8.05" * "]", italic("r")["Cauchy"]^"JZS" == 
          "0.71")
      

# bayesian (paired t-test)

    Code
      df[["expression"]]
    Output
      [[1]]
      list(log[e] * (BF["01"]) == "-3.70", widehat(delta)["difference"]^"posterior" == 
          "1.09", CI["95%"]^ETI ~ "[" * "0.49", "1.70" * "]", italic("r")["Cauchy"]^"JZS" == 
          "0.80")
      

# t_nonparametric works - between-subjects design

    Code
      select(df, -expression)
    Output
      # A tibble: 1 x 13
        parameter1 parameter2 statistic   p.value method                 alternative
        <chr>      <chr>          <dbl>     <dbl> <chr>                  <chr>      
      1 wt         am              230. 0.0000435 Wilcoxon rank sum test two.sided  
        effectsize        estimate conf.level conf.low conf.high conf.method n.obs
        <chr>                <dbl>      <dbl>    <dbl>     <dbl> <chr>       <int>
      1 r (rank biserial)    0.866        0.9    0.749     0.931 normal         32

---

    Code
      df[["expression"]]
    Output
      [[1]]
      list(italic("W")["Mann-Whitney"] == "230.500", italic(p) == "4.347e-05", 
          widehat(italic("r"))["biserial"]^"rank" == "0.866", CI["90%"] ~ 
              "[" * "0.749", "0.931" * "]", italic("n")["obs"] == "32")
      

# nonparametric works - within-subjects design

    Code
      select(df, -expression)
    Output
      # A tibble: 1 x 13
        parameter1 parameter2 statistic  p.value method                    alternative
        <chr>      <chr>          <dbl>    <dbl> <chr>                     <chr>      
      1 desire     condition       1796 0.000430 Wilcoxon signed rank test two.sided  
        effectsize        estimate conf.level conf.low conf.high conf.method n.obs
        <chr>                <dbl>      <dbl>    <dbl>     <dbl> <chr>       <int>
      1 r (rank biserial)    0.487       0.99    0.215     0.690 normal         90

---

    Code
      df[["expression"]]
    Output
      [[1]]
      list(italic("V")["Wilcoxon"] == "1796.00000", italic(p) == "0.00043", 
          widehat(italic("r"))["biserial"]^"rank" == "0.48737", CI["99%"] ~ 
              "[" * "0.21481", "0.68950" * "]", italic("n")["pairs"] == 
              "90")
      

# meta_analysis works - bayesian

    Code
      dplyr::select(df, -expression)
    Output
      # A tibble: 2 x 19
        term    effectsize                       estimate std.error conf.level
        <chr>   <chr>                               <dbl>     <dbl>      <dbl>
      1 Overall meta-analytic posterior estimate   -0.650     0.222       0.95
      2 tau     meta-analytic posterior estimate    0.486     0.184       0.95
        conf.low conf.high weight  bf10  rhat   ess component prior.distribution
           <dbl>     <dbl>  <dbl> <dbl> <dbl> <dbl> <chr>     <chr>             
      1   -1.12     -0.251     NA  53.0    NA    NA meta      Student's t       
      2    0.205     0.917     NA  53.0    NA    NA meta      Inverse gamma     
        prior.location prior.scale method                                 conf.method
                 <dbl>       <dbl> <chr>                                  <chr>      
      1              0       0.707 Bayesian meta-analysis using 'metaBMA' ETI        
      2              1       0.15  Bayesian meta-analysis using 'metaBMA' ETI        
        log_e_bf10 n.obs
             <dbl> <int>
      1       3.97    16
      2       3.97    16

---

    Code
      df[["expression"]]
    Output
      [[1]]
      list(log[e] * (BF["01"]) == "-3.970", widehat(delta)["difference"]^"posterior" == 
          "-0.650", CI["95%"]^ETI ~ "[" * "-1.121", "-0.251" * "]", 
          italic("r")["Cauchy"]^"JZS" == "0.707")
      
      [[2]]
      list(log[e] * (BF["01"]) == "-3.970", widehat(delta)["difference"]^"posterior" == 
          "0.486", CI["95%"]^ETI ~ "[" * "0.205", "0.917" * "]", italic("r")["Cauchy"]^"JZS" == 
          "0.150")
      

# meta_analysis works - parametric

    Code
      select(df, -expression)
    Output
      # A tibble: 1 x 13
        term    effectsize                     estimate std.error conf.level conf.low
        <chr>   <chr>                             <dbl>     <dbl>      <dbl>    <dbl>
      1 Overall meta-analytic summary estimate   -0.767     0.212       0.95    -1.18
        conf.high statistic  p.value weight method                        conf.method
            <dbl>     <dbl>    <dbl>  <dbl> <chr>                         <chr>      
      1    -0.351     -3.62 0.000295     NA Meta-analysis using 'metafor' Wald       
        n.obs
        <int>
      1    16

---

    Code
      df[["expression"]]
    Output
      [[1]]
      list(italic("z") == "-3.62", italic(p) == "2.95e-04", widehat(beta)["summary"]^"meta" == 
          "-0.77", CI["95%"] ~ "[" * "-1.18", "-0.35" * "]", italic("n")["effects"] == 
          "16")
      

---

    Code
      meta_analysis(mtcars)
    Condition
      Error:
      ! Cannot find the object/variable ('estimate') specified for the 'yi' argument.

# expr_anova_robust works - between-subjects

    Code
      select(df1, -expression)
    Output
      # A tibble: 1 x 11
        statistic    df df.error   p.value
            <dbl> <dbl>    <dbl>     <dbl>
      1      20.2     2     19.0 0.0000196
        method                                           
        <chr>                                            
      1 A heteroscedastic one-way ANOVA for trimmed means
        effectsize                         estimate conf.level conf.low conf.high
        <chr>                                 <dbl>      <dbl>    <dbl>     <dbl>
      1 Explanatory measure of effect size    0.859       0.95    0.853     0.864
        n.obs
        <int>
      1    32

---

    Code
      df1[["expression"]]
    Output
      [[1]]
      list(italic("F")["trimmed-means"](2, 18.97383) == "20.24946", 
          italic(p) == "0.00002", widehat(xi) == "0.85858", CI["95%"] ~ 
              "[" * "0.85268", "0.86448" * "]", italic("n")["obs"] == 
              "32")
      

---

    Code
      select(df2, -expression)
    Output
      # A tibble: 1 x 11
        statistic    df df.error p.value
            <dbl> <dbl>    <dbl>   <dbl>
      1    0.0503     2     21.7   0.951
        method                                           
        <chr>                                            
      1 A heteroscedastic one-way ANOVA for trimmed means
        effectsize                         estimate conf.level conf.low conf.high
        <chr>                                 <dbl>      <dbl>    <dbl>     <dbl>
      1 Explanatory measure of effect size    0.201       0.99   0.0872     0.754
        n.obs
        <int>
      1    71

---

    Code
      df2[["expression"]]
    Output
      [[1]]
      list(italic("F")["trimmed-means"](2, 21.6869) == "0.0503", italic(p) == 
          "0.9511", widehat(xi) == "0.2013", CI["99%"] ~ "[" * "0.0872", 
          "0.7537" * "]", italic("n")["obs"] == "71")
      

# expr_anova_robust works - within-subjects

    Code
      select(df1, -expression)
    Output
      # A tibble: 1 x 11
        statistic    df df.error  p.value
            <dbl> <dbl>    <dbl>    <dbl>
      1      21.0  2.73     145. 1.15e-10
        method                                                             
        <chr>                                                              
      1 A heteroscedastic one-way repeated measures ANOVA for trimmed means
        effectsize                                                      estimate
        <chr>                                                              <dbl>
      1 Algina-Keselman-Penfield robust standardized difference average    0.664
        conf.level conf.low conf.high n.obs
             <dbl>    <dbl>     <dbl> <int>
      1       0.95    0.466     0.971    88

---

    Code
      df1[["expression"]]
    Output
      [[1]]
      list(italic("F")["trimmed-means"](2.7303, 144.7051) == "20.9752", 
          italic(p) == "1.1462e-10", widehat(delta)["R-avg"]^"AKP" == 
              "0.6635", CI["95%"] ~ "[" * "0.4660", "0.9707" * "]", 
          italic("n")["pairs"] == "88")
      

---

    Code
      select(df2, -expression)
    Output
      # A tibble: 1 x 11
        statistic    df df.error p.value
            <dbl> <dbl>    <dbl>   <dbl>
      1      22.1     1        3  0.0182
        method                                                             
        <chr>                                                              
      1 A heteroscedastic one-way repeated measures ANOVA for trimmed means
        effectsize                                                      estimate
        <chr>                                                              <dbl>
      1 Algina-Keselman-Penfield robust standardized difference average     -Inf
        conf.level conf.low conf.high n.obs
             <dbl>    <dbl>     <dbl> <int>
      1       0.95     -Inf       NaN     4

---

    Code
      df2[["expression"]]
    Output
      [[1]]
      list(italic("F")["trimmed-means"](1, 3) == "22.09", italic(p) == 
          "0.02", widehat(delta)["R-avg"]^"AKP" == "-Inf", CI["95%"] ~ 
          "[" * "-Inf", "NA" * "]", italic("n")["pairs"] == "4")
      

#  parametric t-tests

    Code
      df_1
    Output
      # A tibble: 4 x 15
           mu statistic df.error p.value method            alternative effectsize
        <dbl>     <dbl>    <dbl>   <dbl> <chr>             <chr>       <chr>     
      1  0.25     0.242       55   0.810 One Sample t-test two.sided   Cohen's d 
      2  0.25     0.242       55   0.595 One Sample t-test less        Hedges' g 
      3  0.25     0.242       55   0.405 One Sample t-test greater     Cohen's d 
      4  0.25     0.242       55   0.810 One Sample t-test two.sided   Hedges' g 
        estimate conf.level conf.low conf.high conf.method conf.distribution n.obs
           <dbl>      <dbl>    <dbl>     <dbl> <chr>       <chr>             <int>
      1   0.0323       0.89  -0.181      0.246 ncp         t                    56
      2   0.0319       0.99  -0.308      0.371 ncp         t                    56
      3   0.0323       0.9   -0.188      0.252 ncp         t                    56
      4   0.0319       0.5   -0.0572     0.121 ncp         t                    56
        expression
        <list>    
      1 <language>
      2 <language>
      3 <language>
      4 <language>

---

    Code
      df_2_between
    Output
      # A tibble: 4 x 18
        parameter1 parameter2 mean.parameter1 mean.parameter2 statistic df.error
        <chr>      <chr>                <dbl>           <dbl>     <dbl>    <dbl>
      1 wt         am                    3.77            2.41      5.26     30  
      2 wt         am                    3.77            2.41      5.49     29.2
      3 wt         am                    3.77            2.41      5.26     30  
      4 wt         am                    3.77            2.41      5.49     29.2
           p.value method                  alternative effectsize estimate conf.level
             <dbl> <chr>                   <chr>       <chr>         <dbl>      <dbl>
      1 0.0000113  Two Sample t-test       two.sided   Cohen's d      1.93       0.89
      2 1.000      Welch Two Sample t-test less        Hedges' g      1.88       0.99
      3 0.00000563 Two Sample t-test       greater     Cohen's d      1.93       0.9 
      4 0.00000627 Welch Two Sample t-test two.sided   Hedges' g      1.88       0.5 
        conf.low conf.high conf.method conf.distribution n.obs expression
           <dbl>     <dbl> <chr>       <chr>             <int> <list>    
      1     1.23      2.61 ncp         t                    32 <language>
      2  -Inf         2.86 ncp         t                    32 <language>
      3     1.36    Inf    ncp         t                    32 <language>
      4     1.58      2.15 ncp         t                    32 <language>

---

    Code
      df_2_within
    Output
      # A tibble: 4 x 16
        term   group     statistic df.error  p.value method        alternative
        <chr>  <chr>         <dbl>    <dbl>    <dbl> <chr>         <chr>      
      1 desire condition      3.61       89 0.000500 Paired t-test two.sided  
      2 desire condition      3.61       89 0.000500 Paired t-test two.sided  
      3 desire condition      3.61       89 0.000500 Paired t-test two.sided  
      4 desire condition      3.61       89 0.000500 Paired t-test two.sided  
        effectsize estimate conf.level conf.low conf.high conf.method
        <chr>         <dbl>      <dbl>    <dbl>     <dbl> <chr>      
      1 Cohen's d     0.381       0.89   0.205      0.554 ncp        
      2 Hedges' g     0.378       0.99   0.0978     0.656 ncp        
      3 Cohen's d     0.381       0.9    0.200      0.559 ncp        
      4 Hedges' g     0.378       0.5    0.304      0.450 ncp        
        conf.distribution n.obs expression
        <chr>             <int> <list>    
      1 t                    90 <language>
      2 t                    90 <language>
      3 t                    90 <language>
      4 t                    90 <language>

---

    Code
      df_3_between
    Output
      # A tibble: 4 x 14
        statistic    df df.error p.value
            <dbl> <dbl>    <dbl>   <dbl>
      1      4.14     3     52    0.0105
      2      2.63     3     11.1  0.102 
      3      4.14     3     52    0.0105
      4      2.63     3     11.1  0.102 
        method                                                   effectsize estimate
        <chr>                                                    <chr>         <dbl>
      1 One-way analysis of means                                Eta2          0.193
      2 One-way analysis of means (not assuming equal variances) Omega2        0.245
      3 One-way analysis of means                                Eta2          0.193
      4 One-way analysis of means (not assuming equal variances) Omega2        0.245
        conf.level conf.low conf.high conf.method conf.distribution n.obs expression
             <dbl>    <dbl>     <dbl> <chr>       <chr>             <int> <list>    
      1       0.89   0.0585         1 ncp         F                    56 <language>
      2       0.8    0              1 ncp         F                    56 <language>
      3       0.9    0.0545         1 ncp         F                    56 <language>
      4       0.5    0.0974         1 ncp         F                    56 <language>

---

    Code
      df_3_within
    Output
      # A tibble: 2 x 18
        term      sumsq sum.squares.error    df df.error meansq statistic  p.value
        <chr>     <dbl>             <dbl> <dbl>    <dbl>  <dbl>     <dbl>    <dbl>
      1 condition  233.              984.  2.63     229.   4.30      20.6 8.27e-11
      2 condition  233.              984.  2.63     229.   4.30      20.6 8.27e-11
        method                                              effectsize       estimate
        <chr>                                               <chr>               <dbl>
      1 ANOVA estimation for factorial designs using 'afex' Eta2 (partial)     0.191 
      2 ANOVA estimation for factorial designs using 'afex' Omega2 (partial)   0.0783
        conf.level conf.low conf.high conf.method conf.distribution n.obs expression
             <dbl>    <dbl>     <dbl> <chr>       <chr>             <int> <list>    
      1       0.89   0.136          1 ncp         F                    88 <language>
      2       0.9    0.0362         1 ncp         F                    88 <language>

# bayesian (between-subjects - anova)

    Code
      dim(df1)
    Output
      [1]  7 17

---

    Code
      df1[["expression"]][[1]]
    Output
      list(log[e] * (BF["01"]) == "1.54", widehat(italic(R^"2"))["Bayesian"]^"posterior" == 
          "0.00", CI["95%"]^HDI ~ "[" * "0.00", "0.09" * "]", italic("r")["Cauchy"]^"JZS" == 
          "0.71")

---

    Code
      dim(df2)
    Output
      [1]  6 17

---

    Code
      df2[["expression"]][[1]]
    Output
      list(log[e] * (BF["01"]) == "-65.10", widehat(italic(R^"2"))["Bayesian"]^"posterior" == 
          "0.61", CI["95%"]^HDI ~ "[" * "0.54", "0.67" * "]", italic("r")["Cauchy"]^"JZS" == 
          "0.71")

# bayesian (within-subjects - anova)

    Code
      dim(df1)
    Output
      [1]  7 19

---

    Code
      df1[["expression"]][[1]]
    Output
      list(log[e] * (BF["01"]) == "-1.96", widehat(italic(R^"2"))["Bayesian"]^"posterior" == 
          "0.89", CI["95%"]^HDI ~ "[" * "0.85", "0.92" * "]", italic("r")["Cauchy"]^"JZS" == 
          "0.88")

---

    Code
      dim(df2)
    Output
      [1]  8 19

---

    Code
      df2[["expression"]][[1]]
    Output
      list(log[e] * (BF["01"]) == "-21.04", widehat(italic(R^"2"))["Bayesian"]^"posterior" == 
          "0.53", CI["95%"]^HDI ~ "[" * "0.46", "0.59" * "]", italic("r")["Cauchy"]^"JZS" == 
          "0.71")

# Bayesian ANOVA with if_all() filtering and row replication

    Code
      colnames(df_between)
    Output
       [1] "term"               "pd"                 "prior.distribution"
       [4] "prior.location"     "prior.scale"        "bf10"              
       [7] "method"             "log_e_bf10"         "effectsize"        
      [10] "estimate"           "std.dev"            "conf.level"        
      [13] "conf.low"           "conf.high"          "conf.method"       
      [16] "n.obs"              "expression"        

---

    Code
      nrow(df_between)
    Output
      [1] 6

---

    Code
      colnames(df_within)
    Output
       [1] "term"               "pd"                 "prior.distribution"
       [4] "prior.location"     "prior.scale"        "effect"            
       [7] "bf10"               "method"             "log_e_bf10"        
      [10] "effectsize"         "estimate"           "std.dev"           
      [13] "conf.level"         "conf.low"           "conf.high"         
      [16] "conf.method"        "component"          "n.obs"             
      [19] "expression"        

---

    Code
      nrow(df_within)
    Output
      [1] 7

# tidy_model_parameters handles Bayesian ANOVA correctly

    Code
      dim(result_between)
    Output
      [1]  6 15

# between-subjects

    Code
      select(df1, -expression)
    Output
      # A tibble: 1 x 14
        parameter1 parameter2 statistic df.error      p.value
        <chr>      <chr>          <dbl>    <int>        <dbl>
      1 length     genre           51.4        8 0.0000000217
        method                       effectsize      estimate conf.level conf.low
        <chr>                        <chr>              <dbl>      <dbl>    <dbl>
      1 Kruskal-Wallis rank sum test Epsilon2 (rank)    0.328       0.95    0.258
        conf.high conf.method          conf.iterations n.obs
            <dbl> <chr>                          <int> <int>
      1         1 percentile bootstrap             100   158

---

    Code
      df1[["expression"]]
    Output
      [[1]]
      list(chi["Kruskal-Wallis"]^2 * "(" * 8 * ")" == "51.43", italic(p) == 
          "2.17e-08", widehat(epsilon)["ordinal"]^2 == "0.33", CI["95%"] ~ 
          "[" * "0.26", "1.00" * "]", italic("n")["obs"] == "158")
      

---

    Code
      select(df2, -expression)
    Output
      # A tibble: 1 x 14
        parameter1  parameter2 statistic df.error p.value method                      
        <chr>       <chr>          <dbl>    <int>   <dbl> <chr>                       
      1 sleep_total vore            3.30        3   0.348 Kruskal-Wallis rank sum test
        effectsize      estimate conf.level conf.low conf.high conf.method         
        <chr>              <dbl>      <dbl>    <dbl>     <dbl> <chr>               
      1 Epsilon2 (rank)   0.0440       0.99  0.00729         1 percentile bootstrap
        conf.iterations n.obs
                  <int> <int>
      1             100    76

---

    Code
      df2[["expression"]]
    Output
      [[1]]
      list(chi["Kruskal-Wallis"]^2 * "(" * 3 * ")" == "3.30", italic(p) == 
          "0.35", widehat(epsilon)["ordinal"]^2 == "0.04", CI["99%"] ~ 
          "[" * "7.29e-03", "1.00" * "]", italic("n")["obs"] == "76")
      

# within-subjects

    Code
      select(df1, -expression)
    Output
      # A tibble: 1 x 14
        parameter1 parameter2 statistic df.error  p.value method                
        <chr>      <chr>          <dbl>    <dbl>    <dbl> <chr>                 
      1 desire     condition       55.8        3 4.56e-12 Friedman rank sum test
        effectsize  estimate conf.level conf.low conf.high conf.method         
        <chr>          <dbl>      <dbl>    <dbl>     <dbl> <chr>               
      1 Kendall's W    0.211       0.99    0.140         1 percentile bootstrap
        conf.iterations n.obs
                  <int> <int>
      1             100    88

---

    Code
      df1[["expression"]]
    Output
      [[1]]
      list(chi["Friedman"]^2 * "(" * 3 * ")" == "55.83", italic(p) == 
          "4.56e-12", widehat(italic("W"))["Kendall"] == "0.21", CI["99%"] ~ 
          "[" * "0.14", "1.00" * "]", italic("n")["pairs"] == "88")
      

---

    Code
      select(df2, -expression)
    Output
      # A tibble: 1 x 14
        parameter1 parameter2 statistic df.error  p.value method                
        <chr>      <chr>          <dbl>    <dbl>    <dbl> <chr>                 
      1 value      condition        410        3 1.51e-88 Friedman rank sum test
        effectsize  estimate conf.level conf.low conf.high conf.method         
        <chr>          <dbl>      <dbl>    <dbl>     <dbl> <chr>               
      1 Kendall's W    0.911        0.9    0.906         1 percentile bootstrap
        conf.iterations n.obs
                  <int> <int>
      1             100   150

---

    Code
      df2[["expression"]]
    Output
      [[1]]
      list(chi["Friedman"]^2 * "(" * 3 * ")" == "410.00", italic(p) == 
          "1.51e-88", widehat(italic("W"))["Kendall"] == "0.91", CI["90%"] ~ 
          "[" * "0.91", "1.00" * "]", italic("n")["pairs"] == "150")
      

# parametric t-test works (between-subjects without NAs)

    Code
      select(df1, -expression)
    Output
      # A tibble: 1 x 17
        parameter1 parameter2 mean.parameter1 mean.parameter2 statistic df.error
        <chr>      <chr>                <dbl>           <dbl>     <dbl>    <dbl>
      1 len        supp                  20.7            17.0      1.92       58
        p.value method            alternative effectsize estimate conf.level conf.low
          <dbl> <chr>             <chr>       <chr>         <dbl>      <dbl>    <dbl>
      1  0.0604 Two Sample t-test two.sided   Cohen's d     0.495       0.99   -0.184
        conf.high conf.method conf.distribution n.obs
            <dbl> <chr>       <chr>             <int>
      1      1.17 ncp         t                    60

---

    Code
      df1[["expression"]]
    Output
      [[1]]
      list(italic("t")["Student"] * "(" * 58 * ")" == "1.91527", italic(p) == 
          "0.06039", widehat(italic("d"))["Cohen"] == "0.49452", CI["99%"] ~ 
          "[" * "-0.18354", "1.16839" * "]", italic("n")["obs"] == 
          "60")
      

# parametric t-test works (between-subjects with NAs)

    Code
      select(df1, -expression)
    Output
      # A tibble: 1 x 17
        parameter1 parameter2 mean.parameter1 mean.parameter2 statistic df.error
        <chr>      <chr>                <dbl>           <dbl>     <dbl>    <dbl>
      1 len        supp                  20.7            17.0      1.92     55.3
        p.value method                  alternative effectsize estimate conf.level
          <dbl> <chr>                   <chr>       <chr>         <dbl>      <dbl>
      1  0.0606 Welch Two Sample t-test two.sided   Hedges' g     0.488        0.9
        conf.low conf.high conf.method conf.distribution n.obs
           <dbl>     <dbl> <chr>       <chr>             <int>
      1   0.0599     0.911 ncp         t                    60

---

    Code
      df1[["expression"]]
    Output
      [[1]]
      list(italic("t")["Welch"] * "(" * 55.309 * ")" == "1.915", italic(p) == 
          "0.061", widehat(italic("g"))["Hedges"] == "0.488", CI["90%"] ~ 
          "[" * "0.060", "0.911" * "]", italic("n")["obs"] == "60")
      

# parametric t-test works (within-subjects without NAs)

    Code
      select(df1, -expression)
    Output
      # A tibble: 1 x 15
        term  group     statistic df.error  p.value method        alternative
        <chr> <chr>         <dbl>    <dbl>    <dbl> <chr>         <chr>      
      1 value condition      34.8      149 1.85e-73 Paired t-test two.sided  
        effectsize estimate conf.level conf.low conf.high conf.method
        <chr>         <dbl>      <dbl>    <dbl>     <dbl> <chr>      
      1 Hedges' g      2.83        0.5     2.70      2.95 ncp        
        conf.distribution n.obs
        <chr>             <int>
      1 t                   150

---

    Code
      df1[["expression"]]
    Output
      [[1]]
      list(italic("t")["Student"] * "(" * 149 * ")" == "34.8152", italic(p) == 
          "1.8496e-73", widehat(italic("g"))["Hedges"] == "2.8283", 
          CI["50%"] ~ "[" * "2.6996", "2.9462" * "]", italic("n")["pairs"] == 
              "150")
      

# parametric t-test works (within-subjects with NAs)

    Code
      select(df1, -expression)
    Output
      # A tibble: 1 x 15
        term   group     statistic df.error  p.value method        alternative
        <chr>  <chr>         <dbl>    <dbl>    <dbl> <chr>         <chr>      
      1 desire condition      3.61       89 0.000500 Paired t-test two.sided  
        effectsize estimate conf.level conf.low conf.high conf.method
        <chr>         <dbl>      <dbl>    <dbl>     <dbl> <chr>      
      1 Cohen's d     0.381       0.95    0.166     0.594 ncp        
        conf.distribution n.obs
        <chr>             <int>
      1 t                    90

---

    Code
      df1[["expression"]]
    Output
      [[1]]
      list(italic("t")["Student"] * "(" * 89 * ")" == "3.613", italic(p) == 
          "5.000e-04", widehat(italic("d"))["Cohen"] == "0.381", CI["95%"] ~ 
          "[" * "0.166", "0.594" * "]", italic("n")["pairs"] == "90")
      

# `pairwise_comparisons()` works for between-subjects design

    Code
      df1
    Output
      # A tibble: 6 x 6
        group1  group2  p.value p.adjust.method test        expression
        <chr>   <chr>     <dbl> <chr>           <chr>       <list>    
      1 carni   herbi     1     Bonferroni      Student's t <language>
      2 carni   insecti   1     Bonferroni      Student's t <language>
      3 carni   omni      1     Bonferroni      Student's t <language>
      4 herbi   insecti   1     Bonferroni      Student's t <language>
      5 herbi   omni      0.979 Bonferroni      Student's t <language>
      6 insecti omni      1     Bonferroni      Student's t <language>

---

    Code
      df1[["expression"]]
    Output
      [[1]]
      list(italic(p)["Bonferroni" - adj.] == "1.00")
      
      [[2]]
      list(italic(p)["Bonferroni" - adj.] == "1.00")
      
      [[3]]
      list(italic(p)["Bonferroni" - adj.] == "1.00")
      
      [[4]]
      list(italic(p)["Bonferroni" - adj.] == "1.00")
      
      [[5]]
      list(italic(p)["Bonferroni" - adj.] == "0.98")
      
      [[6]]
      list(italic(p)["Bonferroni" - adj.] == "1.00")
      

---

    Code
      df2
    Output
      # A tibble: 6 x 9
        group1  group2  statistic p.value alternative distribution p.adjust.method
        <chr>   <chr>       <dbl>   <dbl> <chr>       <chr>        <chr>          
      1 carni   herbi        2.17       1 two.sided   q            Bonferroni     
      2 carni   insecti     -2.17       1 two.sided   q            Bonferroni     
      3 carni   omni         1.10       1 two.sided   q            Bonferroni     
      4 herbi   insecti     -2.41       1 two.sided   q            Bonferroni     
      5 herbi   omni        -1.87       1 two.sided   q            Bonferroni     
      6 insecti omni         2.19       1 two.sided   q            Bonferroni     
        test         expression
        <chr>        <list>    
      1 Games-Howell <language>
      2 Games-Howell <language>
      3 Games-Howell <language>
      4 Games-Howell <language>
      5 Games-Howell <language>
      6 Games-Howell <language>

---

    Code
      df2[["expression"]]
    Output
      [[1]]
      list(italic(p)["Bonferroni" - adj.] == "1.00")
      
      [[2]]
      list(italic(p)["Bonferroni" - adj.] == "1.00")
      
      [[3]]
      list(italic(p)["Bonferroni" - adj.] == "1.00")
      
      [[4]]
      list(italic(p)["Bonferroni" - adj.] == "1.00")
      
      [[5]]
      list(italic(p)["Bonferroni" - adj.] == "1.00")
      
      [[6]]
      list(italic(p)["Bonferroni" - adj.] == "1.00")
      

---

    Code
      df3
    Output
      # A tibble: 6 x 9
        group1  group2  statistic p.value alternative distribution p.adjust.method
        <chr>   <chr>       <dbl>   <dbl> <chr>       <chr>        <chr>          
      1 carni   herbi       0.582  0.561  two.sided   z            None           
      2 carni   insecti     1.88   0.0595 two.sided   z            None           
      3 carni   omni        1.14   0.254  two.sided   z            None           
      4 herbi   insecti     1.63   0.102  two.sided   z            None           
      5 herbi   omni        0.717  0.474  two.sided   z            None           
      6 insecti omni        1.14   0.254  two.sided   z            None           
        test  expression
        <chr> <list>    
      1 Dunn  <language>
      2 Dunn  <language>
      3 Dunn  <language>
      4 Dunn  <language>
      5 Dunn  <language>
      6 Dunn  <language>

---

    Code
      df3[["expression"]]
    Output
      [[1]]
      list(italic(p)[unadj.] == "0.56")
      
      [[2]]
      list(italic(p)[unadj.] == "0.06")
      
      [[3]]
      list(italic(p)[unadj.] == "0.25")
      
      [[4]]
      list(italic(p)[unadj.] == "0.10")
      
      [[5]]
      list(italic(p)[unadj.] == "0.47")
      
      [[6]]
      list(italic(p)[unadj.] == "0.25")
      

---

    Code
      df4
    Output
      # A tibble: 6 x 10
        group1  group2  estimate conf.level conf.low conf.high p.value p.adjust.method
        <chr>   <chr>      <dbl>      <dbl>    <dbl>     <dbl>   <dbl> <chr>          
      1 carni   herbi   -0.0323        0.95  -0.248     0.184    0.790 FDR            
      2 carni   insecti  0.0451        0.95  -0.0484    0.139    0.552 FDR            
      3 carni   omni     0.00520       0.95  -0.114     0.124    0.898 FDR            
      4 herbi   insecti  0.0774        0.95  -0.133     0.288    0.552 FDR            
      5 herbi   omni     0.0375        0.95  -0.182     0.257    0.790 FDR            
      6 insecti omni    -0.0399        0.95  -0.142     0.0625   0.552 FDR            
        test                 expression
        <chr>                <list>    
      1 Yuen's trimmed means <language>
      2 Yuen's trimmed means <language>
      3 Yuen's trimmed means <language>
      4 Yuen's trimmed means <language>
      5 Yuen's trimmed means <language>
      6 Yuen's trimmed means <language>

---

    Code
      df4[["expression"]]
    Output
      [[1]]
      list(italic(p)["FDR" - adj.] == "0.79")
      
      [[2]]
      list(italic(p)["FDR" - adj.] == "0.55")
      
      [[3]]
      list(italic(p)["FDR" - adj.] == "0.90")
      
      [[4]]
      list(italic(p)["FDR" - adj.] == "0.55")
      
      [[5]]
      list(italic(p)["FDR" - adj.] == "0.79")
      
      [[6]]
      list(italic(p)["FDR" - adj.] == "0.55")
      

---

    Code
      df5
    Output
      # A tibble: 3 x 6
        group1 group2 p.value p.adjust.method test        expression
        <chr>  <chr>    <dbl> <chr>           <chr>       <list>    
      1 PG     PG-13  0.316   Holm            Student's t <language>
      2 PG     R      0.00283 Holm            Student's t <language>
      3 PG-13  R      0.00310 Holm            Student's t <language>

---

    Code
      df5[["expression"]]
    Output
      [[1]]
      list(italic(p)["Holm" - adj.] == "0.32")
      
      [[2]]
      list(italic(p)["Holm" - adj.] == "2.83e-03")
      
      [[3]]
      list(italic(p)["Holm" - adj.] == "3.10e-03")
      

---

    Code
      df6
    Output
      # A tibble: 6 x 9
        group1  group2  statistic p.value alternative distribution p.adjust.method
        <chr>   <chr>       <dbl>   <dbl> <chr>       <chr>        <chr>          
      1 carni   herbi        2.17       1 two.sided   q            Holm           
      2 carni   insecti     -2.17       1 two.sided   q            Holm           
      3 carni   omni         1.10       1 two.sided   q            Holm           
      4 herbi   insecti     -2.41       1 two.sided   q            Holm           
      5 herbi   omni        -1.87       1 two.sided   q            Holm           
      6 insecti omni         2.19       1 two.sided   q            Holm           
        test         expression
        <chr>        <list>    
      1 Games-Howell <language>
      2 Games-Howell <language>
      3 Games-Howell <language>
      4 Games-Howell <language>
      5 Games-Howell <language>
      6 Games-Howell <language>

---

    Code
      df6[["expression"]]
    Output
      [[1]]
      list(italic(p)["Holm" - adj.] == "1.00")
      
      [[2]]
      list(italic(p)["Holm" - adj.] == "1.00")
      
      [[3]]
      list(italic(p)["Holm" - adj.] == "1.00")
      
      [[4]]
      list(italic(p)["Holm" - adj.] == "1.00")
      
      [[5]]
      list(italic(p)["Holm" - adj.] == "1.00")
      
      [[6]]
      list(italic(p)["Holm" - adj.] == "1.00")
      

# dropped levels are not included

    Code
      df1
    Output
      # A tibble: 1 x 9
        group1 group2 statistic p.value alternative distribution p.adjust.method
        <chr>  <chr>      <dbl>   <dbl> <chr>       <chr>        <chr>          
      1 carni  omni        1.10   0.447 two.sided   q            None           
        test         expression
        <chr>        <list>    
      1 Games-Howell <language>

---

    Code
      df1[["expression"]]
    Output
      [[1]]
      list(italic(p)[unadj.] == "0.45")
      

# data without NAs

    Code
      df
    Output
      # A tibble: 3 x 6
        group1     group2      p.value p.adjust.method test        expression
        <chr>      <chr>         <dbl> <chr>           <chr>       <list>    
      1 setosa     versicolor 1.32e-15 FDR             Student's t <language>
      2 setosa     virginica  6.64e-32 FDR             Student's t <language>
      3 versicolor virginica  2.77e- 9 FDR             Student's t <language>

---

    Code
      df[["expression"]]
    Output
      [[1]]
      list(italic(p)["FDR" - adj.] == "1.32e-15")
      
      [[2]]
      list(italic(p)["FDR" - adj.] == "6.64e-32")
      
      [[3]]
      list(italic(p)["FDR" - adj.] == "2.77e-09")
      

# `pairwise_comparisons()` works for within-subjects design - NAs

    Code
      df1
    Output
      # A tibble: 6 x 6
        group1 group2  p.value p.adjust.method test        expression
        <chr>  <chr>     <dbl> <chr>           <chr>       <list>    
      1 HDHF   HDLF   3.18e- 3 Bonferroni      Student's t <language>
      2 HDHF   LDHF   4.21e- 1 Bonferroni      Student's t <language>
      3 HDHF   LDLF   3.95e-12 Bonferroni      Student's t <language>
      4 HDLF   LDHF   3.37e- 1 Bonferroni      Student's t <language>
      5 HDLF   LDLF   7.94e- 3 Bonferroni      Student's t <language>
      6 LDHF   LDLF   1.33e- 8 Bonferroni      Student's t <language>

---

    Code
      df1[["expression"]]
    Output
      [[1]]
      list(italic(p)["Bonferroni" - adj.] == "0.003")
      
      [[2]]
      list(italic(p)["Bonferroni" - adj.] == "0.421")
      
      [[3]]
      list(italic(p)["Bonferroni" - adj.] == "3.950e-12")
      
      [[4]]
      list(italic(p)["Bonferroni" - adj.] == "0.337")
      
      [[5]]
      list(italic(p)["Bonferroni" - adj.] == "0.008")
      
      [[6]]
      list(italic(p)["Bonferroni" - adj.] == "1.331e-08")
      

---

    Code
      df2
    Output
      # A tibble: 6 x 9
        group1 group2 statistic  p.value alternative distribution p.adjust.method
        <chr>  <chr>      <dbl>    <dbl> <chr>       <chr>        <chr>          
      1 HDHF   HDLF        4.78 1.44e- 5 two.sided   t            BY             
      2 HDHF   LDHF        2.44 4.47e- 2 two.sided   t            BY             
      3 HDHF   LDLF        8.01 5.45e-13 two.sided   t            BY             
      4 HDLF   LDHF        2.34 4.96e- 2 two.sided   t            BY             
      5 HDLF   LDLF        3.23 5.05e- 3 two.sided   t            BY             
      6 LDHF   LDLF        5.57 4.64e- 7 two.sided   t            BY             
        test           expression
        <chr>          <list>    
      1 Durbin-Conover <language>
      2 Durbin-Conover <language>
      3 Durbin-Conover <language>
      4 Durbin-Conover <language>
      5 Durbin-Conover <language>
      6 Durbin-Conover <language>

---

    Code
      df2[["expression"]]
    Output
      [[1]]
      list(italic(p)["BY" - adj.] == "1.436e-05")
      
      [[2]]
      list(italic(p)["BY" - adj.] == "0.045")
      
      [[3]]
      list(italic(p)["BY" - adj.] == "5.447e-13")
      
      [[4]]
      list(italic(p)["BY" - adj.] == "0.050")
      
      [[5]]
      list(italic(p)["BY" - adj.] == "0.005")
      
      [[6]]
      list(italic(p)["BY" - adj.] == "4.635e-07")
      

---

    Code
      df3
    Output
      # A tibble: 6 x 11
        group1 group2 estimate conf.level conf.low conf.high     p.value  p.crit
        <chr>  <chr>     <dbl>      <dbl>    <dbl>     <dbl>       <dbl>   <dbl>
      1 HDHF   HDLF      1.03        0.95   0.140      1.92  0.00999     0.0127 
      2 HDHF   LDHF      0.454       0.95  -0.104      1.01  0.0520      0.025  
      3 HDHF   LDLF      1.95        0.95   1.09       2.82  0.000000564 0.00851
      4 HDLF   LDHF     -0.676       0.95  -1.61       0.256 0.0520      0.05   
      5 HDLF   LDLF      0.889       0.95   0.0244     1.75  0.0203      0.0169 
      6 LDHF   LDLF      1.35        0.95   0.560      2.14  0.000102    0.0102 
        p.adjust.method test                 expression
        <chr>           <chr>                <list>    
      1 Hommel          Yuen's trimmed means <language>
      2 Hommel          Yuen's trimmed means <language>
      3 Hommel          Yuen's trimmed means <language>
      4 Hommel          Yuen's trimmed means <language>
      5 Hommel          Yuen's trimmed means <language>
      6 Hommel          Yuen's trimmed means <language>

---

    Code
      df3[["expression"]]
    Output
      [[1]]
      list(italic(p)["Hommel" - adj.] == "0.010")
      
      [[2]]
      list(italic(p)["Hommel" - adj.] == "0.052")
      
      [[3]]
      list(italic(p)["Hommel" - adj.] == "5.642e-07")
      
      [[4]]
      list(italic(p)["Hommel" - adj.] == "0.052")
      
      [[5]]
      list(italic(p)["Hommel" - adj.] == "0.020")
      
      [[6]]
      list(italic(p)["Hommel" - adj.] == "1.017e-04")
      

---

    Code
      df4
    Output
      # A tibble: 6 x 18
        group1 group2 term       effectsize      estimate conf.level conf.low
        <chr>  <chr>  <chr>      <chr>              <dbl>      <dbl>    <dbl>
      1 HDHF   HDLF   Difference Bayesian t-test    1.10        0.95   0.488 
      2 HDHF   LDHF   Difference Bayesian t-test    0.450       0.95  -0.0551
      3 HDHF   LDLF   Difference Bayesian t-test    2.13        0.95   1.62  
      4 HDLF   LDHF   Difference Bayesian t-test   -0.649       0.95  -1.32  
      5 HDLF   LDLF   Difference Bayesian t-test    0.976       0.95   0.380 
      6 LDHF   LDLF   Difference Bayesian t-test    1.66        0.95   1.15  
        conf.high    pd prior.distribution prior.location prior.scale     bf10
            <dbl> <dbl> <chr>                       <dbl>       <dbl>    <dbl>
      1    1.72   1     cauchy                          0       0.707 4.16e+ 1
      2    0.951  0.954 cauchy                          0       0.707 5.83e- 1
      3    2.63   1     cauchy                          0       0.707 1.20e+10
      4    0.0583 0.968 cauchy                          0       0.707 6.98e- 1
      5    1.60   0.999 cauchy                          0       0.707 1.81e+ 1
      6    2.15   1     cauchy                          0       0.707 4.81e+ 6
        conf.method log_e_bf10 n.obs expression test       
        <chr>            <dbl> <int> <list>     <chr>      
      1 ETI              3.73     88 <language> Student's t
      2 ETI             -0.539    88 <language> Student's t
      3 ETI             23.2      88 <language> Student's t
      4 ETI             -0.359    88 <language> Student's t
      5 ETI              2.90     88 <language> Student's t
      6 ETI             15.4      88 <language> Student's t

---

    Code
      df4[["expression"]]
    Output
      [[1]]
      list(log[e] * (BF["01"]) == "-3.73")
      
      [[2]]
      list(log[e] * (BF["01"]) == "0.54")
      
      [[3]]
      list(log[e] * (BF["01"]) == "-23.21")
      
      [[4]]
      list(log[e] * (BF["01"]) == "0.36")
      
      [[5]]
      list(log[e] * (BF["01"]) == "-2.90")
      
      [[6]]
      list(log[e] * (BF["01"]) == "-15.39")
      

# `pairwise_comparisons()` works for within-subjects design - without NAs

    Code
      df1
    Output
      # A tibble: 3 x 6
        group1 group2  p.value p.adjust.method test        expression
        <chr>  <chr>     <dbl> <chr>           <chr>       <list>    
      1 Wine A Wine B 0.732    None            Student's t <language>
      2 Wine A Wine C 0.0142   None            Student's t <language>
      3 Wine B Wine C 0.000675 None            Student's t <language>

---

    Code
      df1[["expression"]]
    Output
      [[1]]
      list(italic(p)[unadj.] == "0.732")
      
      [[2]]
      list(italic(p)[unadj.] == "0.014")
      
      [[3]]
      list(italic(p)[unadj.] == "6.754e-04")
      

---

    Code
      df2
    Output
      # A tibble: 3 x 9
        group1 group2 statistic  p.value alternative distribution p.adjust.method
        <chr>  <chr>      <dbl>    <dbl> <chr>       <chr>        <chr>          
      1 Wine A Wine B      1.05 0.301    two.sided   t            None           
      2 Wine A Wine C      3.66 0.000691 two.sided   t            None           
      3 Wine B Wine C      2.62 0.0123   two.sided   t            None           
        test           expression
        <chr>          <list>    
      1 Durbin-Conover <language>
      2 Durbin-Conover <language>
      3 Durbin-Conover <language>

---

    Code
      df2[["expression"]]
    Output
      [[1]]
      list(italic(p)[unadj.] == "0.301")
      
      [[2]]
      list(italic(p)[unadj.] == "6.915e-04")
      
      [[3]]
      list(italic(p)[unadj.] == "0.012")
      

---

    Code
      df3
    Output
      # A tibble: 3 x 11
        group1 group2 estimate conf.level conf.low conf.high p.value p.crit
        <chr>  <chr>     <dbl>      <dbl>    <dbl>     <dbl>   <dbl>  <dbl>
      1 Wine A Wine B   0.0214       0.95 -0.0216     0.0645 0.195   0.05  
      2 Wine A Wine C   0.114        0.95  0.0215     0.207  0.00492 0.0169
      3 Wine B Wine C   0.0821       0.95  0.00891    0.155  0.00878 0.025 
        p.adjust.method test                 expression
        <chr>           <chr>                <list>    
      1 None            Yuen's trimmed means <language>
      2 None            Yuen's trimmed means <language>
      3 None            Yuen's trimmed means <language>

---

    Code
      df3[["expression"]]
    Output
      [[1]]
      list(italic(p)[unadj.] == "0.195")
      
      [[2]]
      list(italic(p)[unadj.] == "0.005")
      
      [[3]]
      list(italic(p)[unadj.] == "0.009")
      

---

    Code
      df4
    Output
      # A tibble: 3 x 18
        group1 group2 term       effectsize      estimate conf.level conf.low
        <chr>  <chr>  <chr>      <chr>              <dbl>      <dbl>    <dbl>
      1 Wine A Wine B Difference Bayesian t-test  0.00721       0.95  -0.0418
      2 Wine A Wine C Difference Bayesian t-test  0.0755        0.95   0.0127
      3 Wine B Wine C Difference Bayesian t-test  0.0693        0.95   0.0303
        conf.high    pd prior.distribution prior.location prior.scale   bf10
            <dbl> <dbl> <chr>                       <dbl>       <dbl>  <dbl>
      1    0.0562 0.624 cauchy                          0       0.707  0.235
      2    0.140  0.990 cauchy                          0       0.707  3.71 
      3    0.110  1.000 cauchy                          0       0.707 50.5  
        conf.method log_e_bf10 n.obs expression test       
        <chr>            <dbl> <int> <list>     <chr>      
      1 ETI              -1.45    22 <language> Student's t
      2 ETI               1.31    22 <language> Student's t
      3 ETI               3.92    22 <language> Student's t

---

    Code
      df4[["expression"]]
    Output
      [[1]]
      list(log[e] * (BF["01"]) == "1.45")
      
      [[2]]
      list(log[e] * (BF["01"]) == "-1.31")
      
      [[3]]
      list(log[e] * (BF["01"]) == "-3.92")
      

# additional arguments are passed to underlying methods

    Code
      df1
    Output
      # A tibble: 6 x 6
        group1 group2  p.value p.adjust.method test        expression
        <chr>  <chr>     <dbl> <chr>           <chr>       <list>    
      1 HDHF   HDLF   2.65e- 4 None            Student's t <language>
      2 HDHF   LDHF   3.51e- 2 None            Student's t <language>
      3 HDHF   LDLF   3.29e-13 None            Student's t <language>
      4 HDLF   LDHF   9.72e- 1 None            Student's t <language>
      5 HDLF   LDLF   6.62e- 4 None            Student's t <language>
      6 LDHF   LDLF   1.11e- 9 None            Student's t <language>

---

    Code
      df1[["expression"]]
    Output
      [[1]]
      list(italic(p)[unadj.] == "2.65e-04")
      
      [[2]]
      list(italic(p)[unadj.] == "0.04")
      
      [[3]]
      list(italic(p)[unadj.] == "3.29e-13")
      
      [[4]]
      list(italic(p)[unadj.] == "0.97")
      
      [[5]]
      list(italic(p)[unadj.] == "6.62e-04")
      
      [[6]]
      list(italic(p)[unadj.] == "1.11e-09")
      

---

    Code
      df2
    Output
      # A tibble: 6 x 6
        group1 group2 p.value p.adjust.method test        expression
        <chr>  <chr>    <dbl> <chr>           <chr>       <list>    
      1 HDHF   HDLF    1.000  None            Student's t <language>
      2 HDHF   LDHF    0.965  None            Student's t <language>
      3 HDHF   LDLF    1.000  None            Student's t <language>
      4 HDLF   LDHF    0.0281 None            Student's t <language>
      5 HDLF   LDLF    0.999  None            Student's t <language>
      6 LDHF   LDLF    1.000  None            Student's t <language>

---

    Code
      df2[["expression"]]
    Output
      [[1]]
      list(italic(p)[unadj.] == "1.00")
      
      [[2]]
      list(italic(p)[unadj.] == "0.96")
      
      [[3]]
      list(italic(p)[unadj.] == "1.00")
      
      [[4]]
      list(italic(p)[unadj.] == "0.03")
      
      [[5]]
      list(italic(p)[unadj.] == "1.00")
      
      [[6]]
      list(italic(p)[unadj.] == "1.00")
      

---

    Code
      df3
    Output
      # A tibble: 3 x 6
        group1 group2 p.value p.adjust.method test        expression
        <chr>  <chr>    <dbl> <chr>           <chr>       <list>    
      1 4      6        0.995 None            Student's t <language>
      2 4      8        1.000 None            Student's t <language>
      3 6      8        0.997 None            Student's t <language>

---

    Code
      df3[["expression"]]
    Output
      [[1]]
      list(italic(p)[unadj.] == "0.99")
      
      [[2]]
      list(italic(p)[unadj.] == "1.00")
      
      [[3]]
      list(italic(p)[unadj.] == "1.00")
      

---

    Code
      df4
    Output
      # A tibble: 3 x 6
        group1 group2     p.value p.adjust.method test        expression
        <chr>  <chr>        <dbl> <chr>           <chr>       <list>    
      1 4      6      0.00532     None            Student's t <language>
      2 4      8      0.000000103 None            Student's t <language>
      3 6      8      0.00258     None            Student's t <language>

---

    Code
      df4[["expression"]]
    Output
      [[1]]
      list(italic(p)[unadj.] == "5.32e-03")
      
      [[2]]
      list(italic(p)[unadj.] == "1.03e-07")
      
      [[3]]
      list(italic(p)[unadj.] == "2.58e-03")
      

# tidy_model_expressions works - t

    Code
      select(df_t, -expression)
    Output
      # A tibble: 2 x 10
        term        estimate std.error conf.level conf.low conf.high statistic
        <chr>          <dbl>     <dbl>      <dbl>    <dbl>     <dbl>     <dbl>
      1 (Intercept)    6.05     0.309        0.95    5.42      6.68      19.6 
      2 mpg           -0.141    0.0147       0.95   -0.171    -0.111     -9.56
        df.error  p.value conf.method
           <int>    <dbl> <chr>      
      1       30 1.20e-18 Wald       
      2       30 1.29e-10 Wald       

---

    Code
      df_t[["expression"]]
    Output
      [[1]]
      list(widehat(italic(beta)) == "6.05", italic(t)("30") == "19.59", 
          italic(p) == "1.20e-18")
      
      [[2]]
      list(widehat(italic(beta)) == "-0.14", italic(t)("30") == "-9.56", 
          italic(p) == "1.29e-10")
      

---

    Code
      df_t_na[["expression"]]
    Output
      [[1]]
      list(widehat(italic(beta)) == "6.05", italic(t) == "19.59", italic(p) == 
          "1.20e-18")
      
      [[2]]
      list(widehat(italic(beta)) == "-0.14", italic(t) == "-9.56", 
          italic(p) == "1.29e-10")
      

---

    Code
      df_t_inf[["expression"]]
    Output
      [[1]]
      list(widehat(italic(beta)) == "6.05", italic(t) == "19.59", italic(p) == 
          "1.20e-18")
      
      [[2]]
      list(widehat(italic(beta)) == "-0.14", italic(t) == "-9.56", 
          italic(p) == "1.29e-10")
      

# tidy_model_expressions works - chi2

    Code
      select(df_chi, -expression)
    Output
      # A tibble: 3 x 10
        term          estimate std.error conf.level conf.low conf.high statistic
        <chr>            <dbl>     <dbl>      <dbl>    <dbl>     <dbl>     <dbl>
      1 age             0.0170   0.00923       0.95 -0.00106    0.0351 3.40     
      2 sex            -0.512    0.168         0.95 -0.840     -0.183  9.31     
      3 frailty(inst)  NA       NA             0.95 NA         NA      0.0000605
        df.error p.value conf.method
           <dbl>   <dbl> <chr>      
      1        1 0.0650  Wald       
      2        1 0.00228 Wald       
      3        1 0.994   Wald       

---

    Code
      df_chi[["expression"]]
    Output
      [[1]]
      list(widehat(italic(beta)) == "0.02", italic(chi)^2 * ("1") == 
          "3.40", italic(p) == "0.07")
      
      [[2]]
      list(widehat(italic(beta)) == "-0.51", italic(chi)^2 * ("1") == 
          "9.31", italic(p) == "2.28e-03")
      
      [[3]]
      NULL
      

# tidy_model_expressions works - z

    Code
      select(df_z, -expression)
    Output
      # A tibble: 3 x 10
        term        estimate std.error conf.level conf.low conf.high statistic
        <chr>          <dbl>     <dbl>      <dbl>    <dbl>     <dbl>     <dbl>
      1 (Intercept)   -0.780     0.225       0.95    -1.22    -0.342     -3.47
      2 SexFemale      2.29      0.120       0.95     2.06     2.53      19.1 
      3 AgeAdult      -0.556     0.228       0.95    -1.00    -0.108     -2.44
        df.error  p.value conf.method
           <dbl>    <dbl> <chr>      
      1      Inf 5.14e- 4 profile    
      2      Inf 1.54e-81 profile    
      3      Inf 1.45e- 2 profile    

---

    Code
      df_z[["expression"]]
    Output
      [[1]]
      list(widehat(italic(beta)) == "-0.78", italic(z) == "-3.47", 
          italic(p) == "5.14e-04")
      
      [[2]]
      list(widehat(italic(beta)) == "2.29", italic(z) == "19.13", italic(p) == 
          "1.54e-81")
      
      [[3]]
      list(widehat(italic(beta)) == "-0.56", italic(z) == "-2.44", 
          italic(p) == "0.01")
      

# tidy_model_expressions works - F

    Code
      select(df1, -expression)
    Output
      # A tibble: 3 x 11
        term  statistic    df df.error p.value group   sumsq meansq estimate
        <chr>     <dbl> <dbl>    <dbl>   <dbl> <chr>   <dbl>  <dbl>    <dbl>
      1 N         9.04      1       15 0.00885 Within 189.   189.   0.184   
      2 P         0.401     1       15 0.536   Within   8.40   8.40 0       
      3 N:P       1.02      1       15 0.329   Within  21.3   21.3  0.000457
        sum.squares.error mean.square.error
                    <dbl>             <dbl>
      1              314.              20.9
      2              314.              20.9
      3              314.              20.9

---

    Code
      df1[["expression"]]
    Output
      [[1]]
      list(widehat(italic(omega)[p]^2) == "0.18", italic(F)("1", "15") == 
          "9.04", italic(p) == "8.85e-03")
      
      [[2]]
      list(widehat(italic(omega)[p]^2) == "0.00", italic(F)("1", "15") == 
          "0.40", italic(p) == "0.54")
      
      [[3]]
      list(widehat(italic(omega)[p]^2) == "4.57e-04", italic(F)("1", 
          "15") == "1.02", italic(p) == "0.33")
      

---

    Code
      select(df2, -expression)
    Output
      # A tibble: 3 x 11
        term  statistic    df df.error p.value group   sumsq meansq estimate
        <chr>     <dbl> <dbl>    <dbl>   <dbl> <chr>   <dbl>  <dbl>    <dbl>
      1 N         9.04      1       15 0.00885 Within 189.   189.     0.376 
      2 P         0.401     1       15 0.536   Within   8.40   8.40   0.0261
      3 N:P       1.02      1       15 0.329   Within  21.3   21.3    0.0635
        sum.squares.error mean.square.error
                    <dbl>             <dbl>
      1              314.              20.9
      2              314.              20.9
      3              314.              20.9

---

    Code
      df2[["expression"]]
    Output
      [[1]]
      list(widehat(italic(eta)[p]^2) == "0.38", italic(F)("1", "15") == 
          "9.04", italic(p) == "8.85e-03")
      
      [[2]]
      list(widehat(italic(eta)[p]^2) == "0.03", italic(F)("1", "15") == 
          "0.40", italic(p) == "0.54")
      
      [[3]]
      list(widehat(italic(eta)[p]^2) == "0.06", italic(F)("1", "15") == 
          "1.02", italic(p) == "0.33")
      

# t_robust - within-subjects - without NAs

    Code
      select(df1, -expression)
    Output
      # A tibble: 1 x 14
        statistic df.error   p.value
            <dbl>    <dbl>     <dbl>
      1      28.7       89 2.23e-308
        method                                            
        <chr>                                             
      1 Yuen's test on trimmed means for dependent samples
        effectsize                                              estimate conf.level
        <chr>                                                      <dbl>      <dbl>
      1 Algina-Keselman-Penfield robust standardized difference     2.36       0.95
        conf.low conf.high    mu small medium large n.obs
           <dbl>     <dbl> <dbl> <dbl>  <dbl> <dbl> <int>
      1     1.96      2.61     0   0.1    0.3   0.5   150

---

    Code
      df1[["expression"]]
    Output
      [[1]]
      list(italic("t")["Yuen"] * "(" * 89 * ")" == "28.7230", italic(p) == 
          "2.2251e-308", widehat(delta)["R"]^"AKP" == "2.3582", CI["95%"] ~ 
          "[" * "1.9615", "2.6081" * "]", italic("n")["pairs"] == "150")
      

# t_robust - within-subjects - with NAs

    Code
      select(df1, -expression)
    Output
      # A tibble: 1 x 14
        statistic df.error p.value method                                            
            <dbl>    <dbl>   <dbl> <chr>                                             
      1      2.91       53 0.00528 Yuen's test on trimmed means for dependent samples
        effectsize                                              estimate conf.level
        <chr>                                                      <dbl>      <dbl>
      1 Algina-Keselman-Penfield robust standardized difference    0.410       0.95
        conf.low conf.high    mu small medium large n.obs
           <dbl>     <dbl> <dbl> <dbl>  <dbl> <dbl> <int>
      1    0.238     0.611     0   0.1    0.3   0.5    90

---

    Code
      df1[["expression"]]
    Output
      [[1]]
      list(italic("t")["Yuen"] * "(" * 53 * ")" == "2.909", italic(p) == 
          "0.005", widehat(delta)["R"]^"AKP" == "0.410", CI["95%"] ~ 
          "[" * "0.238", "0.611" * "]", italic("n")["pairs"] == "90")
      

# t_robust - between-subjects - without NAs

    Code
      select(df1, -expression)
    Output
      # A tibble: 1 x 10
        statistic df.error   p.value
            <dbl>    <dbl>     <dbl>
      1      5.84     13.6 0.0000485
        method                                              
        <chr>                                               
      1 Yuen's test on trimmed means for independent samples
        effectsize                                              estimate conf.level
        <chr>                                                      <dbl>      <dbl>
      1 Algina-Keselman-Penfield robust standardized difference     2.48       0.99
        conf.low conf.high n.obs
           <dbl>     <dbl> <int>
      1    0.738      5.13    32

---

    Code
      df1[["expression"]]
    Output
      [[1]]
      list(italic("t")["Yuen"] * "(" * 13.584 * ")" == "5.840", italic(p) == 
          "4.846e-05", widehat(delta)["R"]^"AKP" == "2.482", CI["99%"] ~ 
          "[" * "0.738", "5.128" * "]", italic("n")["obs"] == "32")
      

# t_robust - between-subjects - with NAs

    Code
      select(df1, -expression)
    Output
      # A tibble: 1 x 10
        statistic df.error p.value
            <dbl>    <dbl>   <dbl>
      1     0.452     13.8   0.658
        method                                              
        <chr>                                               
      1 Yuen's test on trimmed means for independent samples
        effectsize                                              estimate conf.level
        <chr>                                                      <dbl>      <dbl>
      1 Algina-Keselman-Penfield robust standardized difference   -0.358        0.9
        conf.low conf.high n.obs
           <dbl>     <dbl> <int>
      1    -7.16     0.406    29

---

    Code
      df1[["expression"]]
    Output
      [[1]]
      list(italic("t")["Yuen"] * "(" * 13.8476 * ")" == "0.4521", italic(p) == 
          "0.6582", widehat(delta)["R"]^"AKP" == "-0.3583", CI["90%"] ~ 
          "[" * "-7.1637", "0.4061" * "]", italic("n")["obs"] == "29")
      

# pairwise_contingency_table works - basic

    Code
      select(df1, -expression)
    Output
      # A tibble: 3 x 13
        group1 group2 p.value p.value.adj estimate conf.level conf.low conf.high
        <chr>  <chr>    <dbl>       <dbl>    <dbl>      <dbl>    <dbl>     <dbl>
      1 4      6      0.332        0.997     0.180       0.95        0     0.743
      2 4      8      0.00514      0.0154    0.568       0.95        0     0.983
      3 6      8      0.280        0.840     0.229       0.95        0     0.728
        effectsize        conf.method conf.distribution p.adjust.method
        <chr>             <chr>       <chr>             <chr>          
      1 Cramer's V (adj.) ncp         chisq             Bonferroni     
      2 Cramer's V (adj.) ncp         chisq             Bonferroni     
      3 Cramer's V (adj.) ncp         chisq             Bonferroni     
        test               
        <chr>              
      1 Fisher's exact test
      2 Fisher's exact test
      3 Fisher's exact test

---

    Code
      df1[["expression"]]
    Output
      [[1]]
      list(italic(p)["Bonferroni" - adj.] == "1.00")
      
      [[2]]
      list(italic(p)["Bonferroni" - adj.] == "0.02")
      
      [[3]]
      list(italic(p)["Bonferroni" - adj.] == "0.84")
      

# pairwise_contingency_table works - with counts

    Code
      select(df1, -expression)
    Output
      # A tibble: 6 x 13
        group1 group2  p.value p.value.adj estimate conf.level conf.low conf.high
        <chr>  <chr>     <dbl>       <dbl>    <dbl>      <dbl>    <dbl>     <dbl>
      1 1st    2nd    2.78e- 7    4.17e- 7    0.207       0.95   0.125     0.287 
      2 1st    3rd    3.68e-30    1.10e-29    0.357       0.95   0.296     0.419 
      3 1st    Crew   1.81e-34    1.09e-33    0.359       0.95   0.302     0.415 
      4 2nd    3rd    8.19e- 7    9.83e- 7    0.157       0.95   0.0926    0.220 
      5 2nd    Crew   2.77e- 8    5.54e- 8    0.164       0.95   0.105     0.222 
      6 3rd    Crew   5.98e- 1    5.98e- 1    0           0.95   0         0.0581
        effectsize        conf.method conf.distribution p.adjust.method
        <chr>             <chr>       <chr>             <chr>          
      1 Cramer's V (adj.) ncp         chisq             FDR            
      2 Cramer's V (adj.) ncp         chisq             FDR            
      3 Cramer's V (adj.) ncp         chisq             FDR            
      4 Cramer's V (adj.) ncp         chisq             FDR            
      5 Cramer's V (adj.) ncp         chisq             FDR            
      6 Cramer's V (adj.) ncp         chisq             FDR            
        test               
        <chr>              
      1 Fisher's exact test
      2 Fisher's exact test
      3 Fisher's exact test
      4 Fisher's exact test
      5 Fisher's exact test
      6 Fisher's exact test

---

    Code
      df1[["expression"]]
    Output
      [[1]]
      list(italic(p)["FDR" - adj.] == "4.17e-07")
      
      [[2]]
      list(italic(p)["FDR" - adj.] == "1.10e-29")
      
      [[3]]
      list(italic(p)["FDR" - adj.] == "1.09e-33")
      
      [[4]]
      list(italic(p)["FDR" - adj.] == "9.83e-07")
      
      [[5]]
      list(italic(p)["FDR" - adj.] == "5.54e-08")
      
      [[6]]
      list(italic(p)["FDR" - adj.] == "0.60")
      

# pairwise_contingency_table works - no adjustment

    Code
      select(df1, -expression)
    Output
      # A tibble: 3 x 13
        group1 group2 p.value p.value.adj estimate conf.level conf.low conf.high
        <chr>  <chr>    <dbl>       <dbl>    <dbl>      <dbl>    <dbl>     <dbl>
      1 4      6      0.332       0.332      0.180       0.95        0     0.743
      2 4      8      0.00514     0.00514    0.568       0.95        0     0.983
      3 6      8      0.280       0.280      0.229       0.95        0     0.728
        effectsize        conf.method conf.distribution p.adjust.method
        <chr>             <chr>       <chr>             <chr>          
      1 Cramer's V (adj.) ncp         chisq             None           
      2 Cramer's V (adj.) ncp         chisq             None           
      3 Cramer's V (adj.) ncp         chisq             None           
        test               
        <chr>              
      1 Fisher's exact test
      2 Fisher's exact test
      3 Fisher's exact test

---

    Code
      df1[["expression"]]
    Output
      [[1]]
      list(italic(p)[unadj.] == "0.33")
      
      [[2]]
      list(italic(p)[unadj.] == "5.14e-03")
      
      [[3]]
      list(italic(p)[unadj.] == "0.28")
      

# pairwise_contingency_table works - data with NAs

    Code
      select(df1, -expression)
    Output
      # A tibble: 6 x 13
        group1  group2  p.value p.value.adj estimate conf.level conf.low conf.high
        <chr>   <chr>     <dbl>       <dbl>    <dbl>      <dbl>    <dbl>     <dbl>
      1 carni   herbi     0.783       1        0           0.95        0     0.180
      2 carni   insecti   0.712       1        0           0.95        0     0.499
      3 carni   omni      0.138       0.828    0.306       0.95        0     0.713
      4 herbi   insecti   0.537       1        0           0.95        0     0.395
      5 herbi   omni      0.292       1        0.243       0.95        0     0.569
      6 insecti omni      0.455       1        0.343       0.95        0     1    
        effectsize        conf.method conf.distribution p.adjust.method
        <chr>             <chr>       <chr>             <chr>          
      1 Cramer's V (adj.) ncp         chisq             Holm           
      2 Cramer's V (adj.) ncp         chisq             Holm           
      3 Cramer's V (adj.) ncp         chisq             Holm           
      4 Cramer's V (adj.) ncp         chisq             Holm           
      5 Cramer's V (adj.) ncp         chisq             Holm           
      6 Cramer's V (adj.) ncp         chisq             Holm           
        test               
        <chr>              
      1 Fisher's exact test
      2 Fisher's exact test
      3 Fisher's exact test
      4 Fisher's exact test
      5 Fisher's exact test
      6 Fisher's exact test

---

    Code
      df1[["expression"]]
    Output
      [[1]]
      list(italic(p)["Holm" - adj.] == "1.00")
      
      [[2]]
      list(italic(p)["Holm" - adj.] == "1.00")
      
      [[3]]
      list(italic(p)["Holm" - adj.] == "0.83")
      
      [[4]]
      list(italic(p)["Holm" - adj.] == "1.00")
      
      [[5]]
      list(italic(p)["Holm" - adj.] == "1.00")
      
      [[6]]
      list(italic(p)["Holm" - adj.] == "1.00")
      

# pairwise_contingency_table works - custom conf.level and alternative

    Code
      select(df1, -expression)
    Output
      # A tibble: 3 x 13
        group1 group2 p.value p.value.adj estimate conf.level conf.low conf.high
        <chr>  <chr>    <dbl>       <dbl>    <dbl>      <dbl>    <dbl>     <dbl>
      1 4      6        0.961           1    0.180        0.9    0             1
      2 4      8        1.000           1    0.568        0.9    0.272         1
      3 6      8        0.975           1    0.229        0.9    0             1
        effectsize        conf.method conf.distribution p.adjust.method
        <chr>             <chr>       <chr>             <chr>          
      1 Cramer's V (adj.) ncp         chisq             Holm           
      2 Cramer's V (adj.) ncp         chisq             Holm           
      3 Cramer's V (adj.) ncp         chisq             Holm           
        test               
        <chr>              
      1 Fisher's exact test
      2 Fisher's exact test
      3 Fisher's exact test

---

    Code
      df1[["expression"]]
    Output
      [[1]]
      list(italic(p)["Holm" - adj.] == "1.00")
      
      [[2]]
      list(italic(p)["Holm" - adj.] == "1.00")
      
      [[3]]
      list(italic(p)["Holm" - adj.] == "1.00")
      

# pairwise_contingency_table works - custom digits

    Code
      select(df1, -expression)
    Output
      # A tibble: 3 x 13
        group1 group2 p.value p.value.adj estimate conf.level conf.low conf.high
        <chr>  <chr>    <dbl>       <dbl>    <dbl>      <dbl>    <dbl>     <dbl>
      1 4      6      0.332        0.332     0.180       0.95        0     0.743
      2 4      8      0.00514      0.0154    0.568       0.95        0     0.983
      3 6      8      0.280        0.332     0.229       0.95        0     0.728
        effectsize        conf.method conf.distribution p.adjust.method
        <chr>             <chr>       <chr>             <chr>          
      1 Cramer's V (adj.) ncp         chisq             FDR            
      2 Cramer's V (adj.) ncp         chisq             FDR            
      3 Cramer's V (adj.) ncp         chisq             FDR            
        test               
        <chr>              
      1 Fisher's exact test
      2 Fisher's exact test
      3 Fisher's exact test

---

    Code
      df1[["expression"]]
    Output
      [[1]]
      list(italic(p)["FDR" - adj.] == "0.3322")
      
      [[2]]
      list(italic(p)["FDR" - adj.] == "0.0154")
      
      [[3]]
      list(italic(p)["FDR" - adj.] == "0.3322")
      

# meta_analysis works - robust

    Code
      select(df, -expression)
    Output
      # A tibble: 1 x 13
        term    effectsize                     estimate std.error conf.low conf.high
        <chr>   <chr>                             <dbl>     <dbl>    <dbl>     <dbl>
      1 Overall meta-analytic summary estimate   -0.746     0.234    -1.26    -0.343
        statistic  p.value weight conf.level method                               
            <dbl>    <dbl>  <dbl>      <dbl> <chr>                                
      1     -3.20 0.000501     NA       0.95 Robust meta-analysis using 'metaplus'
        conf.method n.obs
        <chr>       <int>
      1 Wald           16

---

    Code
      df[["expression"]]
    Output
      [[1]]
      list(italic("z") == "-3.20", italic(p) == "5.01e-04", widehat(beta)["summary"]^"meta" == 
          "-0.75", CI["95%"] ~ "[" * "-1.26", "-0.34" * "]", italic("n")["effects"] == 
          "16")
      

# one-sample-test without missing data:  type=bayes, conf.level=0.95, effsize.type=g

    Code
      names(res)
    Output
       [1] "term"               "effectsize"         "estimate"          
       [4] "conf.level"         "conf.low"           "conf.high"         
       [7] "pd"                 "prior.distribution" "prior.location"    
      [10] "prior.scale"        "bf10"               "method"            
      [13] "conf.method"        "log_e_bf10"         "n.obs"             
      [16] "expression"        

---

    Code
      res$bf10[[1L]]
    Output
      [1] 1.199152e+15

# one-sample-test without missing data:  type=bayes, conf.level=0.9, effsize.type=d

    Code
      names(res)
    Output
       [1] "term"               "effectsize"         "estimate"          
       [4] "conf.level"         "conf.low"           "conf.high"         
       [7] "pd"                 "prior.distribution" "prior.location"    
      [10] "prior.scale"        "bf10"               "method"            
      [13] "conf.method"        "log_e_bf10"         "n.obs"             
      [16] "expression"        

---

    Code
      res$bf10[[1L]]
    Output
      [1] 1.199152e+15

# one-sample-test without missing data:  type=parametric, conf.level=0.95, effsize.type=g

    Code
      select(res, -expression)
    Output
      # A tibble: 1 x 14
           mu statistic df.error  p.value method            alternative effectsize
        <dbl>     <dbl>    <dbl>    <dbl> <chr>             <chr>       <chr>     
      1     5      11.1       82 4.70e-18 One Sample t-test two.sided   Hedges' g 
        estimate conf.level conf.low conf.high conf.method conf.distribution n.obs
           <dbl>      <dbl>    <dbl>     <dbl> <chr>       <chr>             <int>
      1     1.21       0.95    0.925      1.49 ncp         t                    83

---

    Code
      res[["expression"]]
    Output
      [[1]]
      list(italic("t")["Student"] * "(" * 82 * ")" == "11.124", italic(p) == 
          "4.695e-18", widehat(italic("g"))["Hedges"] == "1.210", CI["95%"] ~ 
          "[" * "0.925", "1.490" * "]", italic("n")["obs"] == "83")
      

# one-sample-test without missing data:  type=parametric, conf.level=0.9, effsize.type=d

    Code
      select(res, -expression)
    Output
      # A tibble: 1 x 14
           mu statistic df.error  p.value method            alternative effectsize
        <dbl>     <dbl>    <dbl>    <dbl> <chr>             <chr>       <chr>     
      1     5      11.1       82 4.70e-18 One Sample t-test two.sided   Cohen's d 
        estimate conf.level conf.low conf.high conf.method conf.distribution n.obs
           <dbl>      <dbl>    <dbl>     <dbl> <chr>       <chr>             <int>
      1     1.22        0.9    0.979      1.46 ncp         t                    83

---

    Code
      res[["expression"]]
    Output
      [[1]]
      list(italic("t")["Student"] * "(" * 82 * ")" == "11.124", italic(p) == 
          "4.695e-18", widehat(italic("d"))["Cohen"] == "1.221", CI["90%"] ~ 
          "[" * "0.979", "1.457" * "]", italic("n")["obs"] == "83")
      

# one-sample-test without missing data:  type=nonparametric, conf.level=0.95, effsize.type=g

    Code
      select(res, -expression)
    Output
      # A tibble: 1 x 11
        statistic  p.value method                    alternative effectsize       
            <dbl>    <dbl> <chr>                     <chr>       <chr>            
      1     3338. 4.43e-13 Wilcoxon signed rank test two.sided   r (rank biserial)
        estimate conf.level conf.low conf.high conf.method n.obs
           <dbl>      <dbl>    <dbl>     <dbl> <chr>       <int>
      1    0.915       0.95    0.865     0.948 normal         83

---

    Code
      res[["expression"]]
    Output
      [[1]]
      list(italic("V")["Wilcoxon"] == "3338.500", italic(p) == "4.428e-13", 
          widehat(italic("r"))["biserial"]^"rank" == "0.915", CI["95%"] ~ 
              "[" * "0.865", "0.948" * "]", italic("n")["obs"] == "83")
      

# one-sample-test without missing data:  type=nonparametric, conf.level=0.9, effsize.type=d

    Code
      select(res, -expression)
    Output
      # A tibble: 1 x 11
        statistic  p.value method                    alternative effectsize       
            <dbl>    <dbl> <chr>                     <chr>       <chr>            
      1     3338. 4.43e-13 Wilcoxon signed rank test two.sided   r (rank biserial)
        estimate conf.level conf.low conf.high conf.method n.obs
           <dbl>      <dbl>    <dbl>     <dbl> <chr>       <int>
      1    0.915        0.9    0.874     0.943 normal         83

---

    Code
      res[["expression"]]
    Output
      [[1]]
      list(italic("V")["Wilcoxon"] == "3338.500", italic(p) == "4.428e-13", 
          widehat(italic("r"))["biserial"]^"rank" == "0.915", CI["90%"] ~ 
              "[" * "0.874", "0.943" * "]", italic("n")["obs"] == "83")
      

# one-sample-test without missing data:  type=robust, conf.level=0.95, effsize.type=g

    Code
      select(res, -expression)
    Output
      # A tibble: 1 x 9
        statistic   p.value n.obs method                                 effectsize  
            <dbl>     <dbl> <int> <chr>                                  <chr>       
      1      9.70 2.23e-308    83 Bootstrap-t method for one-sample test Trimmed mean
        estimate conf.level conf.low conf.high
           <dbl>      <dbl>    <dbl>     <dbl>
      1     10.5       0.95     9.33      11.6

---

    Code
      res[["expression"]]
    Output
      [[1]]
      list(italic("t")["bootstrapped"] == "9.702", italic(p) == "2.225e-308", 
          widehat(mu)["trimmed"] == "10.482", CI["95%"] ~ "[" * "9.329", 
          "11.636" * "]", italic("n")["obs"] == "83")
      

# one-sample-test without missing data:  type=robust, conf.level=0.9, effsize.type=d

    Code
      select(res, -expression)
    Output
      # A tibble: 1 x 9
        statistic   p.value n.obs method                                 effectsize  
            <dbl>     <dbl> <int> <chr>                                  <chr>       
      1      9.70 2.23e-308    83 Bootstrap-t method for one-sample test Trimmed mean
        estimate conf.level conf.low conf.high
           <dbl>      <dbl>    <dbl>     <dbl>
      1     10.5        0.9     9.51      11.5

---

    Code
      res[["expression"]]
    Output
      [[1]]
      list(italic("t")["bootstrapped"] == "9.702", italic(p) == "2.225e-308", 
          widehat(mu)["trimmed"] == "10.482", CI["90%"] ~ "[" * "9.506", 
          "11.458" * "]", italic("n")["obs"] == "83")
      

# one-sample-test with missing data:  type=bayes, conf.level=0.95, effsize.type=g

    Code
      names(res)
    Output
       [1] "term"               "effectsize"         "estimate"          
       [4] "conf.level"         "conf.low"           "conf.high"         
       [7] "pd"                 "prior.distribution" "prior.location"    
      [10] "prior.scale"        "bf10"               "method"            
      [13] "conf.method"        "log_e_bf10"         "n.obs"             
      [16] "expression"        

---

    Code
      res$bf10[[1L]]
    Output
      [1] 0.1500561

# one-sample-test with missing data:  type=bayes, conf.level=0.9, effsize.type=d

    Code
      names(res)
    Output
       [1] "term"               "effectsize"         "estimate"          
       [4] "conf.level"         "conf.low"           "conf.high"         
       [7] "pd"                 "prior.distribution" "prior.location"    
      [10] "prior.scale"        "bf10"               "method"            
      [13] "conf.method"        "log_e_bf10"         "n.obs"             
      [16] "expression"        

---

    Code
      res$bf10[[1L]]
    Output
      [1] 0.1500561

# one-sample-test with missing data:  type=parametric, conf.level=0.95, effsize.type=g

    Code
      select(res, -expression)
    Output
      # A tibble: 1 x 14
           mu statistic df.error p.value method            alternative effectsize
        <dbl>     <dbl>    <dbl>   <dbl> <chr>             <chr>       <chr>     
      1  0.25     0.242       55   0.810 One Sample t-test two.sided   Hedges' g 
        estimate conf.level conf.low conf.high conf.method conf.distribution n.obs
           <dbl>      <dbl>    <dbl>     <dbl> <chr>       <chr>             <int>
      1   0.0319       0.95   -0.227     0.290 ncp         t                    56

---

    Code
      res[["expression"]]
    Output
      [[1]]
      list(italic("t")["Student"] * "(" * 55 * ")" == "0.242", italic(p) == 
          "0.810", widehat(italic("g"))["Hedges"] == "0.032", CI["95%"] ~ 
          "[" * "-0.227", "0.290" * "]", italic("n")["obs"] == "56")
      

# one-sample-test with missing data:  type=parametric, conf.level=0.9, effsize.type=d

    Code
      select(res, -expression)
    Output
      # A tibble: 1 x 14
           mu statistic df.error p.value method            alternative effectsize
        <dbl>     <dbl>    <dbl>   <dbl> <chr>             <chr>       <chr>     
      1  0.25     0.242       55   0.810 One Sample t-test two.sided   Cohen's d 
        estimate conf.level conf.low conf.high conf.method conf.distribution n.obs
           <dbl>      <dbl>    <dbl>     <dbl> <chr>       <chr>             <int>
      1   0.0323        0.9   -0.188     0.252 ncp         t                    56

---

    Code
      res[["expression"]]
    Output
      [[1]]
      list(italic("t")["Student"] * "(" * 55 * ")" == "0.242", italic(p) == 
          "0.810", widehat(italic("d"))["Cohen"] == "0.032", CI["90%"] ~ 
          "[" * "-0.188", "0.252" * "]", italic("n")["obs"] == "56")
      

# one-sample-test with missing data:  type=nonparametric, conf.level=0.95, effsize.type=g

    Code
      select(res, -expression)
    Output
      # A tibble: 1 x 11
        statistic   p.value method                    alternative effectsize       
            <dbl>     <dbl> <chr>                     <chr>       <chr>            
      1       262 0.0000125 Wilcoxon signed rank test two.sided   r (rank biserial)
        estimate conf.level conf.low conf.high conf.method n.obs
           <dbl>      <dbl>    <dbl>     <dbl> <chr>       <int>
      1   -0.672       0.95   -0.806    -0.472 normal         56

---

    Code
      res[["expression"]]
    Output
      [[1]]
      list(italic("V")["Wilcoxon"] == "262.000", italic(p) == "1.253e-05", 
          widehat(italic("r"))["biserial"]^"rank" == "-0.672", CI["95%"] ~ 
              "[" * "-0.806", "-0.472" * "]", italic("n")["obs"] == 
              "56")
      

# one-sample-test with missing data:  type=nonparametric, conf.level=0.9, effsize.type=d

    Code
      select(res, -expression)
    Output
      # A tibble: 1 x 11
        statistic   p.value method                    alternative effectsize       
            <dbl>     <dbl> <chr>                     <chr>       <chr>            
      1       262 0.0000125 Wilcoxon signed rank test two.sided   r (rank biserial)
        estimate conf.level conf.low conf.high conf.method n.obs
           <dbl>      <dbl>    <dbl>     <dbl> <chr>       <int>
      1   -0.672        0.9   -0.788    -0.509 normal         56

---

    Code
      res[["expression"]]
    Output
      [[1]]
      list(italic("V")["Wilcoxon"] == "262.000", italic(p) == "1.253e-05", 
          widehat(italic("r"))["biserial"]^"rank" == "-0.672", CI["90%"] ~ 
              "[" * "-0.788", "-0.509" * "]", italic("n")["obs"] == 
              "56")
      

# one-sample-test with missing data:  type=robust, conf.level=0.95, effsize.type=g

    Code
      select(res, -expression)
    Output
      # A tibble: 1 x 9
        statistic p.value n.obs method                                 effectsize  
            <dbl>   <dbl> <int> <chr>                                  <chr>       
      1     -13.2   0.005    56 Bootstrap-t method for one-sample test Trimmed mean
        estimate conf.level conf.low conf.high
           <dbl>      <dbl>    <dbl>     <dbl>
      1   0.0390       0.95  -0.0132    0.0911

---

    Code
      res[["expression"]]
    Output
      [[1]]
      list(italic("t")["bootstrapped"] == "-13.164", italic(p) == "0.005", 
          widehat(mu)["trimmed"] == "0.039", CI["95%"] ~ "[" * "-0.013", 
          "0.091" * "]", italic("n")["obs"] == "56")
      

# one-sample-test with missing data:  type=robust, conf.level=0.9, effsize.type=d

    Code
      select(res, -expression)
    Output
      # A tibble: 1 x 9
        statistic p.value n.obs method                                 effectsize  
            <dbl>   <dbl> <int> <chr>                                  <chr>       
      1     -13.2   0.005    56 Bootstrap-t method for one-sample test Trimmed mean
        estimate conf.level conf.low conf.high
           <dbl>      <dbl>    <dbl>     <dbl>
      1   0.0390        0.9  0.00419    0.0737

---

    Code
      res[["expression"]]
    Output
      [[1]]
      list(italic("t")["bootstrapped"] == "-13.164", italic(p) == "0.005", 
          widehat(mu)["trimmed"] == "0.039", CI["90%"] ~ "[" * "0.004", 
          "0.074" * "]", italic("n")["obs"] == "56")
      

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/data.R
\docType{data}
\name{bugs_long}
\alias{bugs_long}
\title{Tidy version of the "Bugs" dataset.}
\format{
A data frame with 372 rows and 6 variables
\itemize{
\item subject. Dummy identity number for each participant.
\item gender. Participant's gender (Female, Male).
\item region. Region of the world the participant was from.
\item education. Level of education.
\item condition. Condition of the experiment the participant gave rating
for (\strong{LDLF}: low freighteningness and low disgustingness; \strong{LFHD}: low
freighteningness and high disgustingness; \strong{HFHD}: high freighteningness
and low disgustingness; \strong{HFHD}: high freighteningness and high
disgustingness).
\item desire. The desire to kill an arthropod was indicated on a scale from
0 to 10.
}
}
\usage{
bugs_long
}
\description{
Tidy version of the "Bugs" dataset.
}
\details{
This data set, "Bugs", provides the extent to which men and women
want to kill arthropods that vary in freighteningness (low, high) and
disgustingness (low, high). Each participant rates their attitudes towards
all anthropods. Subset of the data reported by Ryan et al. (2013).
}
\examples{
dim(bugs_long)
head(bugs_long)
dplyr::glimpse(bugs_long)
}
\references{
Ryan, R. S., Wilde, M., & Crist, S. (2013). Compared to a small, supervised
lab experiment, a large, unsupervised web-based experiment on a previously
unknown effect has benefits that outweigh its potential costs. \emph{Computers in
Human Behavior}, \emph{29}(4), 1295-1301.
}
\keyword{datasets}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/tidy-model-expressions.R
\name{tidy_model_expressions}
\alias{tidy_model_expressions}
\title{Expressions with statistics for tidy regression data frames}
\usage{
tidy_model_expressions(
  data,
  statistic = NULL,
  digits = 2L,
  effsize.type = "omega",
  ...
)
}
\arguments{
\item{data}{A tidy data frame from regression model object (see
\code{\link[=tidy_model_parameters]{tidy_model_parameters()}}).}

\item{statistic}{Which statistic is to be displayed (either \code{"t"} or \code{"f"}or
\code{"z"} or \code{"chi"}) in the expression.}

\item{digits}{Number of digits for rounding or significant figures. May also
be \code{"signif"} to return significant figures or \code{"scientific"}
to return scientific notation. Control the number of digits by adding the
value as suffix, e.g. \code{digits = "scientific4"} to have scientific
notation with 4 decimal places, or \code{digits = "signif5"} for 5
significant figures (see also \code{\link[=signif]{signif()}}).}

\item{effsize.type}{Type of effect size needed for \emph{parametric} tests. The
argument can be \code{"eta"} (partial eta-squared) or \code{"omega"} (partial
omega-squared).}

\item{...}{Currently ignored.}
}
\description{
Expressions with statistics for tidy regression data frames
}
\details{
When any of the necessary numeric column values (\code{estimate}, \code{statistic},
\code{p.value}) are missing, for these rows, a \code{NULL} is returned instead of an
expression with empty strings.
}
\section{Citation}{
Patil, I., (2021). statsExpressions: R Package for Tidy Dataframes and Expressions with Statistical Details. Journal of Open Source Software, 6(61), 3236, https://doi.org/10.21105/joss.03236
}

\examples{
\dontshow{if (identical(Sys.getenv("NOT_CRAN"), "true")) withAutoprint(\{ # examplesIf}
# setup
set.seed(123)
library(statsExpressions)

# extract a tidy data frame
df <- tidy_model_parameters(lm(wt ~ am * cyl, mtcars))

# create a column containing expression; the expression will depend on `statistic`
tidy_model_expressions(df, statistic = "t")
tidy_model_expressions(df, statistic = "z")
tidy_model_expressions(df, statistic = "chi")

# f-statistic (requires a data frame with `df`, `df.error`, and effect-size columns)
df_f <- tidy_model_parameters(
  aov(wt ~ cyl, mtcars),
  es_type = "omega",
  table_wide = TRUE
)
tidy_model_expressions(df_f, statistic = "f")
df_f_eta <- tidy_model_parameters(
  aov(wt ~ cyl, mtcars),
  es_type = "eta",
  table_wide = TRUE
)
tidy_model_expressions(df_f_eta, statistic = "f", effsize.type = "eta")
\dontshow{\}) # examplesIf}
}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/data.R
\docType{data}
\name{iris_long}
\alias{iris_long}
\title{Edgar Anderson's Iris Data in long format.}
\format{
A data frame with 600 rows and 5 variables
\itemize{
\item id. Dummy identity number for each flower (150 flowers in total).
\item Species.	The species are \emph{Iris setosa}, \emph{versicolor}, and
\emph{virginica}.
\item condition. Factor giving a detailed description of the attribute
(Four levels: \code{"Petal.Length"}, \code{"Petal.Width"},  \code{"Sepal.Length"},
\code{"Sepal.Width"}).
\item attribute.	What attribute is being measured (\code{"Sepal"} or \code{"Pepal"}).
\item measure.	What aspect of the attribute is being measured (\code{"Length"}
or \code{"Width"}).
\item value.	Value of the measurement.
}
}
\usage{
iris_long
}
\description{
Edgar Anderson's Iris Data in long format.
}
\details{
This famous (Fisher's or Anderson's) iris data set gives the
measurements in centimeters of the variables sepal length and width and
petal length and width, respectively, for 50 flowers from each of 3 species
of iris. The species are Iris setosa, versicolor, and virginica.

This is a modified dataset from \code{{datasets}} package.
}
\examples{
dim(iris_long)
head(iris_long)
dplyr::glimpse(iris_long)
}
\keyword{datasets}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/long-to-wide-converter.R
\name{long_to_wide_converter}
\alias{long_to_wide_converter}
\title{Convert long/tidy data frame to wide format}
\usage{
long_to_wide_converter(
  data,
  x,
  y,
  subject.id = NULL,
  paired = TRUE,
  spread = TRUE,
  ...
)
}
\arguments{
\item{data}{A data frame (or a tibble) from which variables specified are to
be taken. Other data types (e.g., matrix,table, array, etc.) will \strong{not}
be accepted. Additionally, grouped data frames from \code{{dplyr}} should be
ungrouped before they are entered as \code{data}.}

\item{x}{The grouping (or independent) variable from \code{data}. In case of a
repeated measures or within-subjects design, if \code{subject.id} argument is
not available or not explicitly specified, the function assumes that the
data has already been sorted by such an id by the user and creates an
internal identifier. So if your data is \strong{not} sorted, the results \emph{can}
be inaccurate when there are more than two levels in \code{x} and there are
\code{NA}s present. The data is expected to be sorted by user in
subject-1, subject-2, ..., pattern.}

\item{y}{The response (or outcome or dependent) variable from \code{data}.}

\item{subject.id}{Relevant in case of a repeated measures or within-subjects
design (\code{paired = TRUE}, i.e.), it specifies the subject or repeated
measures identifier. \strong{Important}: Note that if this argument is \code{NULL}
(which is the default), the function assumes that the data has already been
sorted by such an id by the user and creates an internal identifier. So if
your data is \strong{not} sorted and you leave this argument unspecified, the
results \emph{can} be inaccurate when there are more than two levels in \code{x} and
there are \code{NA}s present.}

\item{paired}{Logical that decides whether the experimental design is
repeated measures/within-subjects or between-subjects. The default is
\code{FALSE}.}

\item{spread}{Logical that decides whether the data frame needs to be
converted from long/tidy to wide (default: \code{TRUE}).}

\item{...}{Currently ignored.}
}
\value{
A data frame with \code{NA}s removed while respecting the
between-or-within-subjects nature of the dataset.
}
\description{
This conversion is helpful mostly for repeated measures design, where
removing \code{NA}s by participant can be a bit tedious.
}
\section{Citation}{
Patil, I., (2021). statsExpressions: R Package for Tidy Dataframes and Expressions with Statistical Details. Journal of Open Source Software, 6(61), 3236, https://doi.org/10.21105/joss.03236
}

\examples{
# for reproducibility
library(statsExpressions)
set.seed(123)

# repeated measures design
long_to_wide_converter(
  bugs_long,
  condition,
  desire,
  subject.id = subject,
  paired = TRUE
)

# independent measures design
long_to_wide_converter(mtcars, cyl, wt, paired = FALSE)

}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/switch-functions.R
\name{extract_stats_type}
\alias{extract_stats_type}
\alias{stats_type_switch}
\title{Switch the type of statistics.}
\usage{
extract_stats_type(type)

stats_type_switch(type)
}
\arguments{
\item{type}{A character specifying the type of statistical approach:
\itemize{
\item \code{"parametric"}
\item \code{"nonparametric"}
\item \code{"robust"}
\item \code{"bayes"}
}

You can specify just the initial letter.}
}
\description{
Relevant mostly for \code{{ggstatsplot}} and \code{{statsExpressions}} packages, where
different statistical approaches are supported via this argument: parametric,
non-parametric, robust, and Bayesian. This switch function converts strings
entered by users to a common pattern for convenience.
}
\examples{
extract_stats_type("p")
extract_stats_type("bf")
}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/helpers-easystats.R
\name{tidy_model_parameters}
\alias{tidy_model_parameters}
\title{Convert \code{{parameters}} package output to \code{{tidyverse}} conventions}
\usage{
tidy_model_parameters(model, ...)
}
\arguments{
\item{model}{Statistical Model.}

\item{...}{Arguments passed to or from other methods. Non-documented
arguments are
\itemize{
\item \code{digits}, \code{p_digits}, \code{ci_digits} and \code{footer_digits} to set the number of
digits for the output. \code{groups} can be used to group coefficients. These
arguments will be passed to the print-method, or can directly be used in
\code{print()}, see documentation in \code{\link[parameters:print.parameters_model]{print.parameters_model()}}.
\item If \code{s_value = TRUE}, the p-value will be replaced by the S-value in the
output (cf. \emph{Rafi and Greenland 2020}).
\item \code{pd} adds an additional column with the \emph{probability of direction} (see
\code{\link[bayestestR:p_direction]{bayestestR::p_direction()}} for details). Furthermore, see 'Examples' in
\code{\link[parameters:model_parameters.default]{model_parameters.default()}}.
\item For developers, whose interest mainly is to get a "tidy" data frame of
model summaries, it is recommended to set \code{pretty_names = FALSE} to speed
up computation of the summary table.
}}
}
\description{
Convert \code{{parameters}} package output to \code{{tidyverse}} conventions
}
\section{Citation}{
Patil, I., (2021). statsExpressions: R Package for Tidy Dataframes and Expressions with Statistical Details. Journal of Open Source Software, 6(61), 3236, https://doi.org/10.21105/joss.03236
}

\examples{
model <- lm(mpg ~ wt + cyl, data = mtcars)
tidy_model_parameters(model)

}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/data.R
\docType{data}
\name{movies_long}
\alias{movies_long}
\title{Movie information and user ratings from IMDB.}
\format{
A data frame with 1,579 rows and 8 variables
\itemize{
\item title.  Title of the movie.
\item year.  Year of release.
\item budget.  Total budget (if known) in US dollars
\item length.  Length in minutes.
\item rating.  Average IMDB user rating.
\item votes.  Number of IMDB users who rated this movie.
\item mpaa.  MPAA rating.
\item genre. Different genres of movies (action, animation, comedy, drama,
documentary, romance, short).
}
}
\source{
\url{https://CRAN.R-project.org/package=ggplot2movies}
}
\usage{
movies_long
}
\description{
Movie information and user ratings from IMDB.
}
\details{
Modified dataset from \code{{ggplot2movies}} package.
}
\examples{
dim(movies_long)
head(movies_long)
dplyr::glimpse(movies_long)
}
\keyword{datasets}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/centrality-description.R
\name{centrality_description}
\alias{centrality_description}
\title{Data frame and expression for distribution properties}
\usage{
centrality_description(
  data,
  x,
  y,
  type = "parametric",
  conf.level = 0.95,
  tr = 0.2,
  digits = 2L,
  ...
)
}
\arguments{
\item{data}{A data frame (or a tibble) from which variables specified are to
be taken. Other data types (e.g., matrix,table, array, etc.) will \strong{not}
be accepted. Additionally, grouped data frames from \code{{dplyr}} should be
ungrouped before they are entered as \code{data}.}

\item{x}{The grouping (or independent) variable in \code{data}.}

\item{y}{The response (or outcome or dependent) variable from \code{data}.}

\item{type}{A character specifying the type of statistical approach:
\itemize{
\item \code{"parametric"}
\item \code{"nonparametric"}
\item \code{"robust"}
\item \code{"bayes"}
}

You can specify just the initial letter.}

\item{conf.level}{Scalar between \code{0} and \code{1} (default: \verb{95\%}
confidence/credible intervals, \code{0.95}). If \code{NULL}, no confidence intervals
will be computed.}

\item{tr}{Trim level for the mean when carrying out \code{robust} tests. In case
of an error, try reducing the value of \code{tr}, which is by default set to
\code{0.2}. Lowering the value might help.}

\item{digits}{Number of digits for rounding or significant figures. May also
be \code{"signif"} to return significant figures or \code{"scientific"}
to return scientific notation. Control the number of digits by adding the
value as suffix, e.g. \code{digits = "scientific4"} to have scientific
notation with 4 decimal places, or \code{digits = "signif5"} for 5
significant figures (see also \code{\link[=signif]{signif()}}).}

\item{...}{Currently ignored.}
}
\description{
Parametric, non-parametric, robust, and Bayesian measures of centrality.
}
\details{
This function describes a distribution for \code{y} variable for each level of the
grouping variable in \code{x} by a set of indices (e.g., measures of centrality,
dispersion, range, skewness, kurtosis, etc.). It additionally returns an
expression containing a specified centrality measure. The function internally
relies on \code{\link[datawizard:describe_distribution]{datawizard::describe_distribution()}} function.
}
\section{Centrality measures}{


The table below provides summary about:
\itemize{
\item statistical test carried out for inferential statistics
\item type of effect size estimate and a measure of uncertainty for this estimate
\item functions used internally to compute these details
}\tabular{lll}{
   Type \tab Measure \tab Function used \cr
   Parametric \tab mean \tab \code{datawizard::describe_distribution()} \cr
   Non-parametric \tab median \tab \code{datawizard::describe_distribution()} \cr
   Robust \tab trimmed mean \tab \code{datawizard::describe_distribution()} \cr
   Bayesian \tab MAP \tab \code{datawizard::describe_distribution()} \cr
}
}

\section{Citation}{
Patil, I., (2021). statsExpressions: R Package for Tidy Dataframes and Expressions with Statistical Details. Journal of Open Source Software, 6(61), 3236, https://doi.org/10.21105/joss.03236
}

\examples{
# for reproducibility
set.seed(123)

# ----------------------- parametric -----------------------

centrality_description(iris, Species, Sepal.Length, type = "parametric")

# ----------------------- non-parametric -------------------

centrality_description(mtcars, am, wt, type = "nonparametric")

# ----------------------- robust ---------------------------

centrality_description(ToothGrowth, supp, len, type = "robust")

# ----------------------- Bayesian -------------------------

centrality_description(sleep, group, extra, type = "bayes")
}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/one-sample-test.R
\name{one_sample_test}
\alias{one_sample_test}
\title{One-sample tests}
\usage{
one_sample_test(
  data,
  x,
  type = "parametric",
  test.value = 0,
  alternative = "two.sided",
  digits = 2L,
  conf.level = 0.95,
  tr = 0.2,
  bf.prior = 0.707,
  effsize.type = "g",
  exact = FALSE,
  ...
)
}
\arguments{
\item{data}{A data frame (or a tibble) from which variables specified are to
be taken. Other data types (e.g., matrix,table, array, etc.) will \strong{not}
be accepted. Additionally, grouped data frames from \code{{dplyr}} should be
ungrouped before they are entered as \code{data}.}

\item{x}{A numeric variable from the data frame \code{data}.}

\item{type}{A character specifying the type of statistical approach:
\itemize{
\item \code{"parametric"}
\item \code{"nonparametric"}
\item \code{"robust"}
\item \code{"bayes"}
}

You can specify just the initial letter.}

\item{test.value}{A number indicating the true value of the mean (Default:
\code{0}).}

\item{alternative}{a character string specifying the alternative
    hypothesis, must be one of \code{"two.sided"} (default),
    \code{"greater"} or \code{"less"}.  You can specify just the initial
    letter.}

\item{digits}{Number of digits for rounding or significant figures. May also
be \code{"signif"} to return significant figures or \code{"scientific"}
to return scientific notation. Control the number of digits by adding the
value as suffix, e.g. \code{digits = "scientific4"} to have scientific
notation with 4 decimal places, or \code{digits = "signif5"} for 5
significant figures (see also \code{\link[=signif]{signif()}}).}

\item{conf.level}{Scalar between \code{0} and \code{1} (default: \verb{95\%}
confidence/credible intervals, \code{0.95}). If \code{NULL}, no confidence intervals
will be computed.}

\item{tr}{Trim level for the mean when carrying out \code{robust} tests. In case
of an error, try reducing the value of \code{tr}, which is by default set to
\code{0.2}. Lowering the value might help.}

\item{bf.prior}{A number between \code{0.5} and \code{2} (default \code{0.707}), the prior
width to use in calculating Bayes factors and posterior estimates. In
addition to numeric arguments, several named values are also recognized:
\code{"medium"}, \code{"wide"}, and \code{"ultrawide"}, corresponding to \emph{r} scale values
of \code{1/2}, \code{sqrt(2)/2}, and \code{1}, respectively. In case of an ANOVA, this
value corresponds to scale for fixed effects.}

\item{effsize.type}{Type of effect size needed for \emph{parametric} tests. The
argument can be \code{"d"} (for Cohen's \emph{d}) or \code{"g"} (for Hedge's \emph{g}).}

\item{exact}{A logical indicating whether you want exact p-values to be computed.
Relevant only when \code{type = "nonparametric"} (Default: \code{FALSE}).}

\item{...}{Currently ignored.}
}
\value{
The returned tibble data frame can contain some or all of the following columns (the exact columns will depend on the statistical test):
\itemize{
\item \code{statistic}: the numeric value of a statistic
\item \code{df}: the numeric value of a parameter being modeled (often degrees
of freedom for the test)
\item \code{df.error} and \code{df}: relevant only if the statistic in question has
two degrees of freedom (e.g. anova)
\item \code{p.value}: the two-sided \emph{p}-value associated with the observed statistic
\item \code{method}: the name of the inferential statistical test
\item \code{estimate}: estimated value of the effect size
\item \code{conf.low}: lower bound for the effect size estimate
\item \code{conf.high}: upper bound for the effect size estimate
\item \code{conf.level}: width of the confidence interval
\item \code{conf.method}: method used to compute confidence interval
\item \code{conf.distribution}: statistical distribution for the effect
\item \code{effectsize}: the name of the effect size
\item \code{n.obs}: number of observations
\item \code{expression}: pre-formatted expression containing statistical details
}

For examples, see \href{https://www.indrapatil.com/statsExpressions/articles/web_only/dataframe_outputs.html}{data frame output vignette}.
}
\description{
Parametric, non-parametric, robust, and Bayesian one-sample tests.
}
\section{One-sample tests}{


The table below provides summary about:
\itemize{
\item statistical test carried out for inferential statistics
\item type of effect size estimate and a measure of uncertainty for this estimate
\item functions used internally to compute these details
}

\strong{Hypothesis testing}\tabular{lll}{
   Type \tab Test \tab Function used \cr
   Parametric \tab One-sample Student's \emph{t}-test \tab \code{stats::t.test()} \cr
   Non-parametric \tab One-sample Wilcoxon test \tab \code{stats::wilcox.test()} \cr
   Robust \tab Bootstrap-\emph{t} method for one-sample test \tab \code{WRS2::trimcibt()} \cr
   Bayesian \tab One-sample Student's \emph{t}-test \tab \code{BayesFactor::ttestBF()} \cr
}


\strong{Effect size estimation}\tabular{llll}{
   Type \tab Effect size \tab CI available? \tab Function used \cr
   Parametric \tab Cohen's \emph{d}, Hedge's \emph{g} \tab Yes \tab \code{effectsize::cohens_d()}, \code{effectsize::hedges_g()} \cr
   Non-parametric \tab \emph{r} (rank-biserial correlation) \tab Yes \tab \code{effectsize::rank_biserial()} \cr
   Robust \tab trimmed mean \tab Yes \tab \code{WRS2::trimcibt()} \cr
   Bayesian \tab difference \tab Yes \tab \code{bayestestR::describe_posterior()} \cr
}
}

\section{Citation}{
Patil, I., (2021). statsExpressions: R Package for Tidy Dataframes and Expressions with Statistical Details. Journal of Open Source Software, 6(61), 3236, https://doi.org/10.21105/joss.03236
}

\examples{
# for reproducibility
set.seed(123)

# ----------------------- parametric -----------------------

one_sample_test(mtcars, wt, test.value = 3)

# biased (Cohen's d) effect size
one_sample_test(mtcars, wt, test.value = 3, effsize.type = "d")

# ----------------------- non-parametric -------------------

one_sample_test(mtcars, wt, test.value = 3, type = "nonparametric")

# ----------------------- robust ---------------------------

one_sample_test(mtcars, wt, test.value = 3, type = "robust")

# ----------------------- Bayesian -------------------------

one_sample_test(mtcars, wt, test.value = 3, type = "bayes")
}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/add-expression-col.R
\name{add_expression_col}
\alias{add_expression_col}
\title{Template for expressions with statistical details}
\usage{
add_expression_col(
  data,
  paired = FALSE,
  statistic.text = NULL,
  effsize.text = NULL,
  prior.type = NULL,
  n = NULL,
  n.text = ifelse(paired, list(quote(italic("n")["pairs"])),
    list(quote(italic("n")["obs"]))),
  digits = 2L,
  digits.df = 0L,
  digits.df.error = digits.df,
  ...
)
}
\arguments{
\item{data}{A data frame containing details from the statistical analysis
and should contain some or all of the the following columns:
\itemize{
\item \emph{statistic}: the numeric value of a statistic.
\item \emph{df.error}: the numeric value of a parameter being modeled (often degrees
of freedom for the test); irrelevant. if there are no degrees of freedom.
\item \emph{df}: relevant if the statistic in question has two degrees of freedom.
\item \emph{p.value}: the two-sided \emph{p}-value associated with observed statistic.
\item \emph{method}: method describing the test carried out.
\item \emph{effectsize}: name of the effect size (if not present, same as \code{method}).
\item \emph{estimate}: estimated value of the effect size.
\item \emph{conf.level}: width for the confidence intervals.
\item \emph{conf.low}: lower bound for effect size estimate.
\item \emph{conf.high}: upper bound for effect size estimate.
\item \emph{bf10}: Bayes Factor value (if \code{bayesian = TRUE}).
}}

\item{paired}{Logical that decides whether the experimental design is
repeated measures/within-subjects or between-subjects. The default is
\code{FALSE}.}

\item{statistic.text}{A character that specifies the relevant test statistic.
For example, for tests with \emph{t}-statistic, \code{statistic.text = "t"}.}

\item{effsize.text}{A character that specifies the relevant effect size.}

\item{prior.type}{The type of prior.}

\item{n}{An integer specifying the sample size used for the test.}

\item{n.text}{A character that specifies the design, which will determine
what the \code{n} stands for. It defaults to \code{quote(italic("n")["pairs"])} if
\code{paired = TRUE}, and to \code{quote(italic("n")["obs"])} if \code{paired = FALSE}. If
you wish to customize this further, you will need to provide object of
\code{language} type.}

\item{digits, digits.df, digits.df.error}{Number of decimal places to display
for the parameters (default: \code{0L}).}

\item{...}{Currently ignored.}
}
\description{
Creates an expression from a data frame containing statistical details.
Ideally, this data frame would come from having run \code{tidy_model_parameters()}
on your model object.

This function is currently \strong{not} stable and should not be used outside of
this package context.
}
\section{Citation}{
Patil, I., (2021). statsExpressions: R Package for Tidy Dataframes and Expressions with Statistical Details. Journal of Open Source Software, 6(61), 3236, https://doi.org/10.21105/joss.03236
}

\examples{
set.seed(123)

# creating a data frame with stats results
stats_df <- cbind.data.frame(
  statistic  = 5.494,
  df         = 29.234,
  p.value    = 0.00001,
  estimate   = -1.980,
  conf.level = 0.95,
  conf.low   = -2.873,
  conf.high  = -1.088,
  method     = "Student's t-test"
)

# expression for *t*-statistic with Cohen's *d* as effect size
# note that the plotmath expressions need to be quoted
add_expression_col(
  data           = stats_df,
  statistic.text = list(quote(italic("t"))),
  effsize.text   = list(quote(italic("d"))),
  n              = 32L,
  n.text         = list(quote(italic("n")["no.obs"])),
  digits         = 3L,
  digits.df      = 3L
)

}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/corr-test.R
\name{corr_test}
\alias{corr_test}
\title{Correlation analyses}
\usage{
corr_test(
  data,
  x,
  y,
  type = "parametric",
  digits = 2L,
  conf.level = 0.95,
  tr = 0.2,
  bf.prior = 0.707,
  ...
)
}
\arguments{
\item{data}{A data frame (or a tibble) from which variables specified are to
be taken. Other data types (e.g., matrix,table, array, etc.) will \strong{not}
be accepted. Additionally, grouped data frames from \code{{dplyr}} should be
ungrouped before they are entered as \code{data}.}

\item{x}{The column in \code{data} containing the explanatory variable to be
plotted on the \code{x}-axis.}

\item{y}{The column in \code{data} containing the response (outcome) variable to
be plotted on the \code{y}-axis.}

\item{type}{A character specifying the type of statistical approach:
\itemize{
\item \code{"parametric"}
\item \code{"nonparametric"}
\item \code{"robust"}
\item \code{"bayes"}
}

You can specify just the initial letter.}

\item{digits}{Number of digits for rounding or significant figures. May also
be \code{"signif"} to return significant figures or \code{"scientific"}
to return scientific notation. Control the number of digits by adding the
value as suffix, e.g. \code{digits = "scientific4"} to have scientific
notation with 4 decimal places, or \code{digits = "signif5"} for 5
significant figures (see also \code{\link[=signif]{signif()}}).}

\item{conf.level}{Scalar between \code{0} and \code{1} (default: \verb{95\%}
confidence/credible intervals, \code{0.95}). If \code{NULL}, no confidence intervals
will be computed.}

\item{tr}{Trim level for the mean when carrying out \code{robust} tests. In case
of an error, try reducing the value of \code{tr}, which is by default set to
\code{0.2}. Lowering the value might help.}

\item{bf.prior}{A number between \code{0.5} and \code{2} (default \code{0.707}), the prior
width to use in calculating Bayes factors and posterior estimates. In
addition to numeric arguments, several named values are also recognized:
\code{"medium"}, \code{"wide"}, and \code{"ultrawide"}, corresponding to \emph{r} scale values
of \code{1/2}, \code{sqrt(2)/2}, and \code{1}, respectively. In case of an ANOVA, this
value corresponds to scale for fixed effects.}

\item{...}{Additional arguments (currently ignored).}
}
\value{
The returned tibble data frame can contain some or all of the following columns (the exact columns will depend on the statistical test):
\itemize{
\item \code{statistic}: the numeric value of a statistic
\item \code{df}: the numeric value of a parameter being modeled (often degrees
of freedom for the test)
\item \code{df.error} and \code{df}: relevant only if the statistic in question has
two degrees of freedom (e.g. anova)
\item \code{p.value}: the two-sided \emph{p}-value associated with the observed statistic
\item \code{method}: the name of the inferential statistical test
\item \code{estimate}: estimated value of the effect size
\item \code{conf.low}: lower bound for the effect size estimate
\item \code{conf.high}: upper bound for the effect size estimate
\item \code{conf.level}: width of the confidence interval
\item \code{conf.method}: method used to compute confidence interval
\item \code{conf.distribution}: statistical distribution for the effect
\item \code{effectsize}: the name of the effect size
\item \code{n.obs}: number of observations
\item \code{expression}: pre-formatted expression containing statistical details
}

For examples, see \href{https://www.indrapatil.com/statsExpressions/articles/web_only/dataframe_outputs.html}{data frame output vignette}.
}
\description{
Parametric, non-parametric, robust, and Bayesian correlation test.
}
\section{Correlation analyses}{


The table below provides summary about:
\itemize{
\item statistical test carried out for inferential statistics
\item type of effect size estimate and a measure of uncertainty for this estimate
\item functions used internally to compute these details
}

\strong{Hypothesis testing} and \strong{Effect size estimation}\tabular{llll}{
   Type \tab Test \tab CI available? \tab Function used \cr
   Parametric \tab Pearson's correlation coefficient \tab Yes \tab \code{correlation::correlation()} \cr
   Non-parametric \tab Spearman's rank correlation coefficient \tab Yes \tab \code{correlation::correlation()} \cr
   Robust \tab Winsorized Pearson's correlation coefficient \tab Yes \tab \code{correlation::correlation()} \cr
   Bayesian \tab Bayesian Pearson's correlation coefficient \tab Yes \tab \code{correlation::correlation()} \cr
}
}

\section{Citation}{
Patil, I., (2021). statsExpressions: R Package for Tidy Dataframes and Expressions with Statistical Details. Journal of Open Source Software, 6(61), 3236, https://doi.org/10.21105/joss.03236
}

\examples{
# for reproducibility
set.seed(123)

# ----------------------- parametric -----------------------

corr_test(mtcars, wt, mpg, type = "parametric")

# ----------------------- non-parametric -------------------

corr_test(mtcars, wt, mpg, type = "nonparametric")

# ----------------------- robust ---------------------------

corr_test(mtcars, wt, mpg, type = "robust")

# ----------------------- Bayesian -------------------------

corr_test(mtcars, wt, mpg, type = "bayes")
}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/meta-analysis.R
\name{meta_analysis}
\alias{meta_analysis}
\title{Random-effects meta-analysis}
\usage{
meta_analysis(
  data,
  type = "parametric",
  random = "mixture",
  digits = 2L,
  conf.level = 0.95,
  ...
)
}
\arguments{
\item{data}{A data frame. It \strong{must} contain columns named \code{estimate} (effect
sizes or outcomes)  and \code{std.error} (corresponding standard errors). These
two columns will be used:
\itemize{
\item as \code{yi}  and \code{sei} arguments in \code{\link[metafor:rma.uni]{metafor::rma()}} (for \strong{parametric} test)
\item as \code{yi}  and \code{sei} arguments in \code{\link[metaplus:metaplus]{metaplus::metaplus()}} (for \strong{robust} test)
\item as \code{y} and \code{SE} arguments in \code{\link[metaBMA:meta_random]{metaBMA::meta_random()}} (for \strong{Bayesian} test)
}}

\item{type}{A character specifying the type of statistical approach:
\itemize{
\item \code{"parametric"}
\item \code{"nonparametric"}
\item \code{"robust"}
\item \code{"bayes"}
}

You can specify just the initial letter.}

\item{random}{
The type of random effects distribution. One of "normal", "t-dist", "mixture", for standard normal, \eqn{t}-distribution or mixture of normals respectively.
}

\item{digits}{Number of digits for rounding or significant figures. May also
be \code{"signif"} to return significant figures or \code{"scientific"}
to return scientific notation. Control the number of digits by adding the
value as suffix, e.g. \code{digits = "scientific4"} to have scientific
notation with 4 decimal places, or \code{digits = "signif5"} for 5
significant figures (see also \code{\link[=signif]{signif()}}).}

\item{conf.level}{Scalar between \code{0} and \code{1} (default: \verb{95\%}
confidence/credible intervals, \code{0.95}). If \code{NULL}, no confidence intervals
will be computed.}

\item{...}{Additional arguments passed to the respective meta-analysis
function.}
}
\value{
The returned tibble data frame can contain some or all of the following columns (the exact columns will depend on the statistical test):
\itemize{
\item \code{statistic}: the numeric value of a statistic
\item \code{df}: the numeric value of a parameter being modeled (often degrees
of freedom for the test)
\item \code{df.error} and \code{df}: relevant only if the statistic in question has
two degrees of freedom (e.g. anova)
\item \code{p.value}: the two-sided \emph{p}-value associated with the observed statistic
\item \code{method}: the name of the inferential statistical test
\item \code{estimate}: estimated value of the effect size
\item \code{conf.low}: lower bound for the effect size estimate
\item \code{conf.high}: upper bound for the effect size estimate
\item \code{conf.level}: width of the confidence interval
\item \code{conf.method}: method used to compute confidence interval
\item \code{conf.distribution}: statistical distribution for the effect
\item \code{effectsize}: the name of the effect size
\item \code{n.obs}: number of observations
\item \code{expression}: pre-formatted expression containing statistical details
}

For examples, see \href{https://www.indrapatil.com/statsExpressions/articles/web_only/dataframe_outputs.html}{data frame output vignette}.
}
\description{
Parametric, non-parametric, robust, and Bayesian random-effects meta-analysis.
}
\note{
\strong{Important}: The function assumes that you have already downloaded the
needed package (\code{{metafor}}, \code{{metaplus}}, or \code{{metaBMA}}) for meta-analysis.
If they are not available, you will be asked to install them.
}
\section{Random-effects meta-analysis}{


The table below provides summary about:
\itemize{
\item statistical test carried out for inferential statistics
\item type of effect size estimate and a measure of uncertainty for this estimate
\item functions used internally to compute these details
}

\strong{Hypothesis testing} and \strong{Effect size estimation}\tabular{llll}{
   Type \tab Test \tab CI available? \tab Function used \cr
   Parametric \tab Pearson's correlation coefficient \tab Yes \tab \code{correlation::correlation()} \cr
   Non-parametric \tab Spearman's rank correlation coefficient \tab Yes \tab \code{correlation::correlation()} \cr
   Robust \tab Winsorized Pearson's correlation coefficient \tab Yes \tab \code{correlation::correlation()} \cr
   Bayesian \tab Bayesian Pearson's correlation coefficient \tab Yes \tab \code{correlation::correlation()} \cr
}
}

\section{Citation}{
Patil, I., (2021). statsExpressions: R Package for Tidy Dataframes and Expressions with Statistical Details. Journal of Open Source Software, 6(61), 3236, https://doi.org/10.21105/joss.03236
}

\examples{
\dontshow{if (identical(Sys.getenv("NOT_CRAN"), "true") && requireNamespace("metaplus", quietly = TRUE)) withAutoprint(\{ # examplesIf}
set.seed(123)
library(statsExpressions)

# let's use `mag` dataset from `{metaplus}`
data(mag, package = "metaplus")
dat <- dplyr::rename(mag, estimate = yi, std.error = sei)

# ----------------------- parametric ----------------------------------------
\dontshow{\}) # examplesIf}
\dontshow{if (identical(Sys.getenv("NOT_CRAN"), "true") && requireNamespace("metaplus") && requireNamespace("metafor")) withAutoprint(\{ # examplesIf}

meta_analysis(dat)
\dontshow{\}) # examplesIf}
\dontshow{if (identical(Sys.getenv("NOT_CRAN"), "true") && requireNamespace("metaplus")) withAutoprint(\{ # examplesIf}

# ----------------------- robust --------------------------------------------

meta_analysis(dat, type = "random", random = "normal")
\dontshow{\}) # examplesIf}
\dontshow{if (identical(Sys.getenv("NOT_CRAN"), "true") && requireNamespace("metaplus") && requireNamespace("metaBMA")) withAutoprint(\{ # examplesIf}

# ----------------------- Bayesian ------------------------------------------

meta_analysis(dat, type = "bayes")
\dontshow{\}) # examplesIf}
}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/pairwise-comparisons.R
\name{pairwise_comparisons}
\alias{pairwise_comparisons}
\title{Multiple pairwise comparison for one-way design}
\usage{
pairwise_comparisons(
  data,
  x,
  y,
  subject.id = NULL,
  type = "parametric",
  paired = FALSE,
  var.equal = FALSE,
  tr = 0.2,
  bf.prior = 0.707,
  p.adjust.method = "holm",
  digits = 2L,
  exact = FALSE,
  ...
)
}
\arguments{
\item{data}{A data frame (or a tibble) from which variables specified are to
be taken. Other data types (e.g., matrix,table, array, etc.) will \strong{not}
be accepted. Additionally, grouped data frames from \code{{dplyr}} should be
ungrouped before they are entered as \code{data}.}

\item{x}{The grouping (or independent) variable from \code{data}. In case of a
repeated measures or within-subjects design, if \code{subject.id} argument is
not available or not explicitly specified, the function assumes that the
data has already been sorted by such an id by the user and creates an
internal identifier. So if your data is \strong{not} sorted, the results \emph{can}
be inaccurate when there are more than two levels in \code{x} and there are
\code{NA}s present. The data is expected to be sorted by user in
subject-1, subject-2, ..., pattern.}

\item{y}{The response (or outcome or dependent) variable from \code{data}.}

\item{subject.id}{Relevant in case of a repeated measures or within-subjects
design (\code{paired = TRUE}, i.e.), it specifies the subject or repeated
measures identifier. \strong{Important}: Note that if this argument is \code{NULL}
(which is the default), the function assumes that the data has already been
sorted by such an id by the user and creates an internal identifier. So if
your data is \strong{not} sorted and you leave this argument unspecified, the
results \emph{can} be inaccurate when there are more than two levels in \code{x} and
there are \code{NA}s present.}

\item{type}{A character specifying the type of statistical approach:
\itemize{
\item \code{"parametric"}
\item \code{"nonparametric"}
\item \code{"robust"}
\item \code{"bayes"}
}

You can specify just the initial letter.}

\item{paired}{Logical that decides whether the experimental design is
repeated measures/within-subjects or between-subjects. The default is
\code{FALSE}.}

\item{var.equal}{a logical variable indicating whether to treat the
    two variances as being equal. If \code{TRUE} then the pooled
    variance is used to estimate the variance otherwise the Welch
    (or Satterthwaite) approximation to the degrees of freedom is used.}

\item{tr}{Trim level for the mean when carrying out \code{robust} tests. In case
of an error, try reducing the value of \code{tr}, which is by default set to
\code{0.2}. Lowering the value might help.}

\item{bf.prior}{A number between \code{0.5} and \code{2} (default \code{0.707}), the prior
width to use in calculating Bayes factors and posterior estimates. In
addition to numeric arguments, several named values are also recognized:
\code{"medium"}, \code{"wide"}, and \code{"ultrawide"}, corresponding to \emph{r} scale values
of \code{1/2}, \code{sqrt(2)/2}, and \code{1}, respectively. In case of an ANOVA, this
value corresponds to scale for fixed effects.}

\item{p.adjust.method}{Adjustment method for \emph{p}-values for multiple
comparisons. Possible methods are: \code{"holm"} (default), \code{"hochberg"},
\code{"hommel"}, \code{"bonferroni"}, \code{"BH"}, \code{"BY"}, \code{"fdr"}, \code{"none"}.}

\item{digits}{Number of digits for rounding or significant figures. May also
be \code{"signif"} to return significant figures or \code{"scientific"}
to return scientific notation. Control the number of digits by adding the
value as suffix, e.g. \code{digits = "scientific4"} to have scientific
notation with 4 decimal places, or \code{digits = "signif5"} for 5
significant figures (see also \code{\link[=signif]{signif()}}).}

\item{exact}{A logical indicating whether you want exact p-values to be computed.
Relevant only when \code{type = "nonparametric"} (Default: \code{FALSE}).}

\item{...}{Additional arguments passed to other methods.}
}
\value{
The returned tibble data frame can contain some or all of the following columns (the exact columns will depend on the statistical test):
\itemize{
\item \code{statistic}: the numeric value of a statistic
\item \code{df}: the numeric value of a parameter being modeled (often degrees
of freedom for the test)
\item \code{df.error} and \code{df}: relevant only if the statistic in question has
two degrees of freedom (e.g. anova)
\item \code{p.value}: the two-sided \emph{p}-value associated with the observed statistic
\item \code{method}: the name of the inferential statistical test
\item \code{estimate}: estimated value of the effect size
\item \code{conf.low}: lower bound for the effect size estimate
\item \code{conf.high}: upper bound for the effect size estimate
\item \code{conf.level}: width of the confidence interval
\item \code{conf.method}: method used to compute confidence interval
\item \code{conf.distribution}: statistical distribution for the effect
\item \code{effectsize}: the name of the effect size
\item \code{n.obs}: number of observations
\item \code{expression}: pre-formatted expression containing statistical details
}

For examples, see \href{https://www.indrapatil.com/statsExpressions/articles/web_only/dataframe_outputs.html}{data frame output vignette}.
}
\description{
Calculate parametric, non-parametric, robust, and Bayes Factor pairwise
comparisons between group levels with corrections for multiple testing.
}
\section{Pairwise comparison tests}{


The table below provides summary about:
\itemize{
\item statistical test carried out for inferential statistics
\item type of effect size estimate and a measure of uncertainty for this estimate
\item functions used internally to compute these details
}
\subsection{between-subjects}{

\strong{Hypothesis testing}\tabular{lllll}{
   Type \tab Equal variance? \tab Test \tab \emph{p}-value adjustment? \tab Function used \cr
   Parametric \tab No \tab Games-Howell test \tab Yes \tab \code{PMCMRplus::gamesHowellTest()} \cr
   Parametric \tab Yes \tab Student's \emph{t}-test \tab Yes \tab \code{stats::pairwise.t.test()} \cr
   Non-parametric \tab No \tab Dunn test \tab Yes \tab \code{PMCMRplus::kwAllPairsDunnTest()} \cr
   Robust \tab No \tab Yuen's trimmed means test \tab Yes \tab \code{WRS2::lincon()} \cr
   Bayesian \tab \code{NA} \tab Student's \emph{t}-test \tab \code{NA} \tab \code{BayesFactor::ttestBF()} \cr
}


\strong{Effect size estimation}

Not supported.
}

\subsection{within-subjects}{

\strong{Data requirement}: Paired pairwise tests assume exactly \strong{one observation per
subject per condition}. If your data has multiple trials per cell, aggregate
first (e.g., take the mean).

\strong{Hypothesis testing}\tabular{llll}{
   Type \tab Test \tab \emph{p}-value adjustment? \tab Function used \cr
   Parametric \tab Student's \emph{t}-test \tab Yes \tab \code{stats::pairwise.t.test()} \cr
   Non-parametric \tab Durbin-Conover test \tab Yes \tab \code{PMCMRplus::durbinAllPairsTest()} \cr
   Robust \tab Yuen's trimmed means test \tab Yes \tab \code{WRS2::rmmcp()} \cr
   Bayesian \tab Student's \emph{t}-test \tab \code{NA} \tab \code{BayesFactor::ttestBF()} \cr
}


\strong{Effect size estimation}

Not supported.
}
}

\section{Citation}{
Patil, I., (2021). statsExpressions: R Package for Tidy Dataframes and Expressions with Statistical Details. Journal of Open Source Software, 6(61), 3236, https://doi.org/10.21105/joss.03236
}

\examples{
\dontshow{if (identical(Sys.getenv("NOT_CRAN"), "true")) withAutoprint(\{ # examplesIf}
# for reproducibility
set.seed(123)
library(statsExpressions)

#------------------- between-subjects design ----------------------------

# parametric
# if `var.equal = TRUE`, then Student's t-test will be run
pairwise_comparisons(
  data            = mtcars,
  x               = cyl,
  y               = wt,
  type            = "parametric",
  var.equal       = TRUE,
  paired          = FALSE,
  p.adjust.method = "none"
)

# if `var.equal = FALSE`, then Games-Howell test will be run
pairwise_comparisons(
  data            = mtcars,
  x               = cyl,
  y               = wt,
  type            = "parametric",
  var.equal       = FALSE,
  paired          = FALSE,
  p.adjust.method = "bonferroni"
)

# non-parametric (Dunn test)
pairwise_comparisons(
  data            = mtcars,
  x               = cyl,
  y               = wt,
  type            = "nonparametric",
  paired          = FALSE,
  p.adjust.method = "none"
)

# robust (Yuen's trimmed means *t*-test)
pairwise_comparisons(
  data            = mtcars,
  x               = cyl,
  y               = wt,
  type            = "robust",
  paired          = FALSE,
  p.adjust.method = "fdr"
)

# Bayes Factor (Student's *t*-test)
pairwise_comparisons(
  data   = mtcars,
  x      = cyl,
  y      = wt,
  type   = "bayes",
  paired = FALSE
)

#------------------- within-subjects design ----------------------------

# parametric (Student's *t*-test)
pairwise_comparisons(
  data            = bugs_long,
  x               = condition,
  y               = desire,
  subject.id      = subject,
  type            = "parametric",
  paired          = TRUE,
  p.adjust.method = "BH"
)

# non-parametric (Durbin-Conover test)
pairwise_comparisons(
  data            = bugs_long,
  x               = condition,
  y               = desire,
  subject.id      = subject,
  type            = "nonparametric",
  paired          = TRUE,
  p.adjust.method = "BY"
)

# robust (Yuen's trimmed means t-test)
pairwise_comparisons(
  data            = bugs_long,
  x               = condition,
  y               = desire,
  subject.id      = subject,
  type            = "robust",
  paired          = TRUE,
  p.adjust.method = "hommel"
)

# Bayes Factor (Student's *t*-test)
pairwise_comparisons(
  data       = bugs_long,
  x          = condition,
  y          = desire,
  subject.id = subject,
  type       = "bayes",
  paired     = TRUE
)
\dontshow{\}) # examplesIf}
}
\references{
For more, see:
\url{https://www.indrapatil.com/ggstatsplot/articles/web_only/pairwise.html}
}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/contingency-table.R
\name{contingency_table}
\alias{contingency_table}
\title{Contingency table analyses}
\usage{
contingency_table(
  data,
  x,
  y = NULL,
  paired = FALSE,
  type = "parametric",
  counts = NULL,
  ratio = NULL,
  alternative = "two.sided",
  digits = 2L,
  conf.level = 0.95,
  sampling.plan = "indepMulti",
  fixed.margin = "rows",
  prior.concentration = 1,
  ...
)
}
\arguments{
\item{data}{A data frame (or a tibble) from which variables specified are to
be taken. Other data types (e.g., matrix,table, array, etc.) will \strong{not}
be accepted. Additionally, grouped data frames from \code{{dplyr}} should be
ungrouped before they are entered as \code{data}.}

\item{x}{The variable to use as the \strong{rows} in the contingency table.}

\item{y}{The variable to use as the \strong{columns} in the contingency table.
Default is \code{NULL}. If \code{NULL}, one-sample proportion test (a goodness of fit
test) will be run for the \code{x} variable.}

\item{paired}{Logical indicating whether data came from a within-subjects or
repeated measures design study (Default: \code{FALSE}).}

\item{type}{A character specifying the type of statistical approach:
\itemize{
\item \code{"parametric"}
\item \code{"nonparametric"}
\item \code{"robust"}
\item \code{"bayes"}
}

You can specify just the initial letter.}

\item{counts}{The variable in data containing counts, or \code{NULL} if each row
represents a single observation.}

\item{ratio}{A vector of proportions: the expected proportions for the
proportion test (should sum to \code{1}). Default is \code{NULL}, which means the null
is equal theoretical proportions across the levels of the nominal variable.
E.g., \code{ratio = c(0.5, 0.5)} for two levels,
\code{ratio = c(0.25, 0.25, 0.25, 0.25)} for four levels, etc.}

\item{alternative}{A character string specifying the alternative hypothesis;
Controls the type of CI returned: \code{"two.sided"} (default, two-sided CI),
\code{"greater"} or \code{"less"} (one-sided CI). Partial matching is allowed
(e.g., \code{"g"}, \code{"l"}, \code{"two"}...). See section \emph{One-Sided CIs} in
the \href{https://easystats.github.io/effectsize/}{effectsize_CIs vignette}.}

\item{digits}{Number of digits for rounding or significant figures. May also
be \code{"signif"} to return significant figures or \code{"scientific"}
to return scientific notation. Control the number of digits by adding the
value as suffix, e.g. \code{digits = "scientific4"} to have scientific
notation with 4 decimal places, or \code{digits = "signif5"} for 5
significant figures (see also \code{\link[=signif]{signif()}}).}

\item{conf.level}{Scalar between \code{0} and \code{1} (default: \verb{95\%}
confidence/credible intervals, \code{0.95}). If \code{NULL}, no confidence intervals
will be computed.}

\item{sampling.plan}{Character describing the sampling plan. Possible options:
\itemize{
\item \code{"indepMulti"} (independent multinomial; default)
\item \code{"poisson"}
\item \code{"jointMulti"} (joint multinomial)
\item \code{"hypergeom"} (hypergeometric).
For more, see \code{\link[BayesFactor:contingencyTableBF]{BayesFactor::contingencyTableBF()}}.
}}

\item{fixed.margin}{For the independent multinomial sampling plan, which
margin is fixed (\code{"rows"} or \code{"cols"}). Defaults to \code{"rows"}.}

\item{prior.concentration}{Specifies the prior concentration parameter, set
to \code{1} by default. It indexes the expected deviation from the null
hypothesis under the alternative, and corresponds to Gunel and Dickey's
(1974) \code{"a"} parameter.}

\item{...}{Additional arguments (currently ignored).}
}
\value{
The returned tibble data frame can contain some or all of the following columns (the exact columns will depend on the statistical test):
\itemize{
\item \code{statistic}: the numeric value of a statistic
\item \code{df}: the numeric value of a parameter being modeled (often degrees
of freedom for the test)
\item \code{df.error} and \code{df}: relevant only if the statistic in question has
two degrees of freedom (e.g. anova)
\item \code{p.value}: the two-sided \emph{p}-value associated with the observed statistic
\item \code{method}: the name of the inferential statistical test
\item \code{estimate}: estimated value of the effect size
\item \code{conf.low}: lower bound for the effect size estimate
\item \code{conf.high}: upper bound for the effect size estimate
\item \code{conf.level}: width of the confidence interval
\item \code{conf.method}: method used to compute confidence interval
\item \code{conf.distribution}: statistical distribution for the effect
\item \code{effectsize}: the name of the effect size
\item \code{n.obs}: number of observations
\item \code{expression}: pre-formatted expression containing statistical details
}

For examples, see \href{https://www.indrapatil.com/statsExpressions/articles/web_only/dataframe_outputs.html}{data frame output vignette}.
}
\description{
Parametric and Bayesian one-way and two-way contingency table analyses.
}
\section{Contingency table analyses}{


The table below provides summary about:
\itemize{
\item statistical test carried out for inferential statistics
\item type of effect size estimate and a measure of uncertainty for this estimate
\item functions used internally to compute these details
}
\subsection{two-way table}{

\strong{Hypothesis testing}\tabular{llll}{
   Type \tab Design \tab Test \tab Function used \cr
   Parametric/Non-parametric \tab Unpaired \tab Pearson's chi-squared test \tab \code{stats::chisq.test()} \cr
   Bayesian \tab Unpaired \tab Bayesian Pearson's chi-squared test \tab \code{BayesFactor::contingencyTableBF()} \cr
   Parametric/Non-parametric \tab Paired \tab McNemar's chi-squared test \tab \code{stats::mcnemar.test()} \cr
   Bayesian \tab Paired \tab No \tab No \cr
}


\strong{Effect size estimation}\tabular{lllll}{
   Type \tab Design \tab Effect size \tab CI available? \tab Function used \cr
   Parametric/Non-parametric \tab Unpaired \tab Cramer's \emph{V} \tab Yes \tab \code{effectsize::cramers_v()} \cr
   Bayesian \tab Unpaired \tab Cramer's \emph{V} \tab Yes \tab \code{effectsize::cramers_v()} \cr
   Parametric/Non-parametric \tab Paired \tab Cohen's \emph{g} \tab Yes \tab \code{effectsize::cohens_g()} \cr
   Bayesian \tab Paired \tab No \tab No \tab No \cr
}

}

\subsection{one-way table}{

\strong{Hypothesis testing}\tabular{lll}{
   Type \tab Test \tab Function used \cr
   Parametric/Non-parametric \tab Goodness of fit chi-squared test \tab \code{stats::chisq.test()} \cr
   Bayesian \tab Bayesian Goodness of fit chi-squared test \tab (custom) \cr
}


\strong{Effect size estimation}\tabular{llll}{
   Type \tab Effect size \tab CI available? \tab Function used \cr
   Parametric/Non-parametric \tab Pearson's \emph{C} \tab Yes \tab \code{effectsize::pearsons_c()} \cr
   Bayesian \tab No \tab No \tab No \cr
}

}
}

\examples{
\dontshow{if (identical(Sys.getenv("NOT_CRAN"), "true")) withAutoprint(\{ # examplesIf}
#### -------------------- association test ------------------------ ####

# ------------------------ frequentist ---------------------------------

# unpaired

set.seed(123)
contingency_table(
  data = mtcars,
  x = am,
  y = vs,
  paired = FALSE
)

# paired

paired_data <- dplyr::tibble(
  response_before = structure(
    c(1L, 2L, 1L, 2L),
    levels = c("no", "yes"),
    class = "factor"
  ),
  response_after = structure(
    c(1L, 1L, 2L, 2L),
    levels = c("no", "yes"),
    class = "factor"
  ),
  Freq = c(65L, 25L, 5L, 5L)
)

set.seed(123)
contingency_table(
  data = paired_data,
  x = response_before,
  y = response_after,
  paired = TRUE,
  counts = Freq
)

# ------------------------ Bayesian -------------------------------------

# unpaired

set.seed(123)
contingency_table(
  data = mtcars,
  x = am,
  y = vs,
  paired = FALSE,
  type = "bayes"
)

# paired

set.seed(123)
contingency_table(
  data = paired_data,
  x = response_before,
  y = response_after,
  paired = TRUE,
  counts = Freq,
  type = "bayes"
)

#### -------------------- goodness-of-fit test -------------------- ####

# ------------------------ frequentist ---------------------------------

set.seed(123)
contingency_table(
  data = as.data.frame(HairEyeColor),
  x = Eye,
  counts = Freq
)

# ------------------------ Bayesian -------------------------------------

set.seed(123)
contingency_table(
  data = as.data.frame(HairEyeColor),
  x = Eye,
  counts = Freq,
  ratio = c(0.2, 0.2, 0.3, 0.3),
  type = "bayes"
)
\dontshow{\}) # examplesIf}
}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/pairwise-contingency-table.R
\name{pairwise_contingency_table}
\alias{pairwise_contingency_table}
\title{Pairwise contingency table analyses}
\usage{
pairwise_contingency_table(
  data,
  x,
  y,
  counts = NULL,
  p.adjust.method = "holm",
  digits = 2L,
  conf.level = 0.95,
  alternative = "two.sided",
  ...
)
}
\arguments{
\item{data}{A data frame (or a tibble) from which variables specified are to
be taken. Other data types (e.g., matrix,table, array, etc.) will \strong{not}
be accepted. Additionally, grouped data frames from \code{{dplyr}} should be
ungrouped before they are entered as \code{data}.}

\item{x}{The variable to use as the \strong{rows} in the contingency table.}

\item{y}{The variable to use as the \strong{columns} in the contingency table.
Default is \code{NULL}. If \code{NULL}, one-sample proportion test (a goodness of fit
test) will be run for the \code{x} variable.}

\item{counts}{The variable in data containing counts, or \code{NULL} if each row
represents a single observation.}

\item{p.adjust.method}{Adjustment method for \emph{p}-values for multiple
comparisons. Possible methods are: \code{"holm"} (default), \code{"hochberg"},
\code{"hommel"}, \code{"bonferroni"}, \code{"BH"}, \code{"BY"}, \code{"fdr"}, \code{"none"}.}

\item{digits}{Number of digits for rounding or significant figures. May also
be \code{"signif"} to return significant figures or \code{"scientific"}
to return scientific notation. Control the number of digits by adding the
value as suffix, e.g. \code{digits = "scientific4"} to have scientific
notation with 4 decimal places, or \code{digits = "signif5"} for 5
significant figures (see also \code{\link[=signif]{signif()}}).}

\item{conf.level}{Scalar between \code{0} and \code{1} (default: \verb{95\%}
confidence/credible intervals, \code{0.95}). If \code{NULL}, no confidence intervals
will be computed.}

\item{alternative}{A character string specifying the alternative hypothesis;
Controls the type of CI returned: \code{"two.sided"} (default, two-sided CI),
\code{"greater"} or \code{"less"} (one-sided CI). Partial matching is allowed
(e.g., \code{"g"}, \code{"l"}, \code{"two"}...). See section \emph{One-Sided CIs} in
the \href{https://easystats.github.io/effectsize/}{effectsize_CIs vignette}.}

\item{...}{Additional arguments (currently ignored).}
}
\value{
The returned tibble data frame can contain some or all of the following columns (the exact columns will depend on the statistical test):
\itemize{
\item \code{statistic}: the numeric value of a statistic
\item \code{df}: the numeric value of a parameter being modeled (often degrees
of freedom for the test)
\item \code{df.error} and \code{df}: relevant only if the statistic in question has
two degrees of freedom (e.g. anova)
\item \code{p.value}: the two-sided \emph{p}-value associated with the observed statistic
\item \code{method}: the name of the inferential statistical test
\item \code{estimate}: estimated value of the effect size
\item \code{conf.low}: lower bound for the effect size estimate
\item \code{conf.high}: upper bound for the effect size estimate
\item \code{conf.level}: width of the confidence interval
\item \code{conf.method}: method used to compute confidence interval
\item \code{conf.distribution}: statistical distribution for the effect
\item \code{effectsize}: the name of the effect size
\item \code{n.obs}: number of observations
\item \code{expression}: pre-formatted expression containing statistical details
}

For examples, see \href{https://www.indrapatil.com/statsExpressions/articles/web_only/dataframe_outputs.html}{data frame output vignette}.
}
\description{
Pairwise Fisher's exact tests as post hoc tests for contingency table
analyses, with effect sizes (Cramer's \emph{V}) and \emph{p}-value adjustment for
multiple comparisons.
}
\section{Pairwise contingency table tests}{


The table below provides summary about:
\itemize{
\item statistical test carried out for inferential statistics
\item type of effect size estimate and a measure of uncertainty for this estimate
\item functions used internally to compute these details
}

\strong{Hypothesis testing}\tabular{lll}{
   Test \tab \emph{p}-value adjustment? \tab Function used \cr
   Fisher's exact test \tab Yes \tab \code{stats::fisher.test()} \cr
}


\strong{Effect size estimation}\tabular{lll}{
   Effect size \tab CI available? \tab Function used \cr
   Cramer's \emph{V} \tab Yes \tab \code{effectsize::cramers_v()} \cr
}
}

\section{Citation}{
Patil, I., (2021). statsExpressions: R Package for Tidy Dataframes and Expressions with Statistical Details. Journal of Open Source Software, 6(61), 3236, https://doi.org/10.21105/joss.03236
}

\examples{
\dontshow{if (identical(Sys.getenv("NOT_CRAN"), "true")) withAutoprint(\{ # examplesIf}
# for reproducibility
set.seed(123)
library(statsExpressions)

# pairwise Fisher's exact tests with Holm adjustment
pairwise_contingency_table(
  data = mtcars,
  x = cyl,
  y = am,
  p.adjust.method = "holm"
)

# with counts data and Bonferroni adjustment
pairwise_contingency_table(
  data = as.data.frame(Titanic),
  x = Class,
  y = Survived,
  counts = Freq,
  p.adjust.method = "bonferroni"
)

# no p-value adjustment
pairwise_contingency_table(
  data = mtcars,
  x = cyl,
  y = am,
  p.adjust.method = "none"
)
\dontshow{\}) # examplesIf}
}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/oneway-anova.R
\name{oneway_anova}
\alias{oneway_anova}
\title{One-way analysis of variance (ANOVA)}
\usage{
oneway_anova(
  data,
  x,
  y,
  subject.id = NULL,
  type = "parametric",
  paired = FALSE,
  digits = 2L,
  conf.level = 0.95,
  effsize.type = "omega",
  var.equal = FALSE,
  bf.prior = 0.707,
  tr = 0.2,
  nboot = 100L,
  ...
)
}
\arguments{
\item{data}{A data frame (or a tibble) from which variables specified are to
be taken. Other data types (e.g., matrix,table, array, etc.) will \strong{not}
be accepted. Additionally, grouped data frames from \code{{dplyr}} should be
ungrouped before they are entered as \code{data}.}

\item{x}{The grouping (or independent) variable from \code{data}. In case of a
repeated measures or within-subjects design, if \code{subject.id} argument is
not available or not explicitly specified, the function assumes that the
data has already been sorted by such an id by the user and creates an
internal identifier. So if your data is \strong{not} sorted, the results \emph{can}
be inaccurate when there are more than two levels in \code{x} and there are
\code{NA}s present. The data is expected to be sorted by user in
subject-1, subject-2, ..., pattern.}

\item{y}{The response (or outcome or dependent) variable from \code{data}.}

\item{subject.id}{Relevant in case of a repeated measures or within-subjects
design (\code{paired = TRUE}, i.e.), it specifies the subject or repeated
measures identifier. \strong{Important}: Note that if this argument is \code{NULL}
(which is the default), the function assumes that the data has already been
sorted by such an id by the user and creates an internal identifier. So if
your data is \strong{not} sorted and you leave this argument unspecified, the
results \emph{can} be inaccurate when there are more than two levels in \code{x} and
there are \code{NA}s present.}

\item{type}{A character specifying the type of statistical approach:
\itemize{
\item \code{"parametric"}
\item \code{"nonparametric"}
\item \code{"robust"}
\item \code{"bayes"}
}

You can specify just the initial letter.}

\item{paired}{Logical that decides whether the experimental design is
repeated measures/within-subjects or between-subjects. The default is
\code{FALSE}.}

\item{digits}{Number of digits for rounding or significant figures. May also
be \code{"signif"} to return significant figures or \code{"scientific"}
to return scientific notation. Control the number of digits by adding the
value as suffix, e.g. \code{digits = "scientific4"} to have scientific
notation with 4 decimal places, or \code{digits = "signif5"} for 5
significant figures (see also \code{\link[=signif]{signif()}}).}

\item{conf.level}{Scalar between \code{0} and \code{1} (default: \verb{95\%}
confidence/credible intervals, \code{0.95}). If \code{NULL}, no confidence intervals
will be computed.}

\item{effsize.type}{Type of effect size needed for \emph{parametric} tests. The
argument can be \code{"eta"} (partial eta-squared) or \code{"omega"} (partial
omega-squared).}

\item{var.equal}{a logical variable indicating whether to treat the
    two variances as being equal. If \code{TRUE} then the pooled
    variance is used to estimate the variance otherwise the Welch
    (or Satterthwaite) approximation to the degrees of freedom is used.}

\item{bf.prior}{A number between \code{0.5} and \code{2} (default \code{0.707}), the prior
width to use in calculating Bayes factors and posterior estimates. In
addition to numeric arguments, several named values are also recognized:
\code{"medium"}, \code{"wide"}, and \code{"ultrawide"}, corresponding to \emph{r} scale values
of \code{1/2}, \code{sqrt(2)/2}, and \code{1}, respectively. In case of an ANOVA, this
value corresponds to scale for fixed effects.}

\item{tr}{Trim level for the mean when carrying out \code{robust} tests. In case
of an error, try reducing the value of \code{tr}, which is by default set to
\code{0.2}. Lowering the value might help.}

\item{nboot}{Number of bootstrap samples for computing confidence interval
for the effect size (Default: \code{100L}).}

\item{...}{Additional arguments (currently ignored).}
}
\value{
The returned tibble data frame can contain some or all of the following columns (the exact columns will depend on the statistical test):
\itemize{
\item \code{statistic}: the numeric value of a statistic
\item \code{df}: the numeric value of a parameter being modeled (often degrees
of freedom for the test)
\item \code{df.error} and \code{df}: relevant only if the statistic in question has
two degrees of freedom (e.g. anova)
\item \code{p.value}: the two-sided \emph{p}-value associated with the observed statistic
\item \code{method}: the name of the inferential statistical test
\item \code{estimate}: estimated value of the effect size
\item \code{conf.low}: lower bound for the effect size estimate
\item \code{conf.high}: upper bound for the effect size estimate
\item \code{conf.level}: width of the confidence interval
\item \code{conf.method}: method used to compute confidence interval
\item \code{conf.distribution}: statistical distribution for the effect
\item \code{effectsize}: the name of the effect size
\item \code{n.obs}: number of observations
\item \code{expression}: pre-formatted expression containing statistical details
}

For examples, see \href{https://www.indrapatil.com/statsExpressions/articles/web_only/dataframe_outputs.html}{data frame output vignette}.
}
\description{
Parametric, non-parametric, robust, and Bayesian one-way ANOVA.
}
\section{One-way ANOVA}{


The table below provides summary about:
\itemize{
\item statistical test carried out for inferential statistics
\item type of effect size estimate and a measure of uncertainty for this estimate
\item functions used internally to compute these details
}
\subsection{between-subjects}{

\strong{Hypothesis testing}\tabular{llll}{
   Type \tab No. of groups \tab Test \tab Function used \cr
   Parametric \tab > 2 \tab Fisher's or Welch's one-way ANOVA \tab \code{stats::oneway.test()} \cr
   Non-parametric \tab > 2 \tab Kruskal-Wallis one-way ANOVA \tab \code{stats::kruskal.test()} \cr
   Robust \tab > 2 \tab Heteroscedastic one-way ANOVA for trimmed means \tab \code{WRS2::t1way()} \cr
   Bayesian \tab > 2 \tab Fisher's ANOVA \tab \code{BayesFactor::anovaBF()} \cr
}


\strong{Effect size estimation}\tabular{lllll}{
   Type \tab No. of groups \tab Effect size \tab CI available? \tab Function used \cr
   Parametric \tab > 2 \tab partial eta-squared, partial omega-squared \tab Yes \tab \code{effectsize::omega_squared()}, \code{effectsize::eta_squared()} \cr
   Non-parametric \tab > 2 \tab rank epsilon squared \tab Yes \tab \code{effectsize::rank_epsilon_squared()} \cr
   Robust \tab > 2 \tab Explanatory measure of effect size \tab Yes \tab \code{WRS2::t1way()} \cr
   Bayesian \tab > 2 \tab Bayesian R-squared \tab Yes \tab \code{performance::r2_bayes()} \cr
}

}

\subsection{within-subjects}{

\strong{Data requirement}: Repeated measures tests assume a \emph{complete} design with
exactly \strong{one observation per subject per condition}. If your data has multiple
trials per cell, aggregate first (e.g., take the mean). Verify with
\code{table(data$subject, data$condition)} — every cell should equal \code{1}.

\strong{Hypothesis testing}\tabular{llll}{
   Type \tab No. of groups \tab Test \tab Function used \cr
   Parametric \tab > 2 \tab One-way repeated measures ANOVA \tab \code{afex::aov_ez()} \cr
   Non-parametric \tab > 2 \tab Friedman rank sum test \tab \code{stats::friedman.test()} \cr
   Robust \tab > 2 \tab Heteroscedastic one-way repeated measures ANOVA for trimmed means \tab \code{WRS2::rmanova()} \cr
   Bayesian \tab > 2 \tab One-way repeated measures ANOVA \tab \code{BayesFactor::anovaBF()} \cr
}


\strong{Effect size estimation}\tabular{lllll}{
   Type \tab No. of groups \tab Effect size \tab CI available? \tab Function used \cr
   Parametric \tab > 2 \tab partial eta-squared, partial omega-squared \tab Yes \tab \code{effectsize::omega_squared()}, \code{effectsize::eta_squared()} \cr
   Non-parametric \tab > 2 \tab Kendall's coefficient of concordance \tab Yes \tab \code{effectsize::kendalls_w()} \cr
   Robust \tab > 2 \tab Algina-Keselman-Penfield robust standardized difference average \tab Yes \tab \code{WRS2::wmcpAKP()} \cr
   Bayesian \tab > 2 \tab Bayesian R-squared \tab Yes \tab \code{performance::r2_bayes()} \cr
}

}
}

\section{Citation}{
Patil, I., (2021). statsExpressions: R Package for Tidy Dataframes and Expressions with Statistical Details. Journal of Open Source Software, 6(61), 3236, https://doi.org/10.21105/joss.03236
}

\examples{
\dontshow{if (identical(Sys.getenv("NOT_CRAN"), "true")) withAutoprint(\{ # examplesIf}
# for reproducibility
set.seed(123)
library(statsExpressions)

# ----------------------- parametric -------------------------------------

# between-subjects
oneway_anova(
  data = mtcars,
  x    = cyl,
  y    = wt
)

# biased (partial eta-squared) effect size
oneway_anova(
  data         = mtcars,
  x            = cyl,
  y            = wt,
  effsize.type = "eta"
)

# within-subjects design
oneway_anova(
  data       = iris_long,
  x          = condition,
  y          = value,
  subject.id = id,
  paired     = TRUE
)

# ----------------------- non-parametric ----------------------------------

# between-subjects
oneway_anova(
  data = mtcars,
  x    = cyl,
  y    = wt,
  type = "np"
)

# within-subjects design
oneway_anova(
  data       = iris_long,
  x          = condition,
  y          = value,
  subject.id = id,
  paired     = TRUE,
  type       = "np"
)

# ----------------------- robust -------------------------------------

# between-subjects
oneway_anova(
  data = mtcars,
  x    = cyl,
  y    = wt,
  type = "r"
)

# within-subjects design
oneway_anova(
  data       = iris_long,
  x          = condition,
  y          = value,
  subject.id = id,
  paired     = TRUE,
  type       = "r"
)
\dontshow{\}) # examplesIf}
\dontshow{if (identical(Sys.getenv("NOT_CRAN"), "true") && requireNamespace("rstantools")) withAutoprint(\{ # examplesIf}

# ----------------------- Bayesian -------------------------------------

# between-subjects
oneway_anova(
  data = mtcars,
  x    = cyl,
  y    = wt,
  type = "bayes"
)

# within-subjects design
oneway_anova(
  data       = iris_long,
  x          = condition,
  y          = value,
  subject.id = id,
  paired     = TRUE,
  type       = "bayes"
)
\dontshow{\}) # examplesIf}
}
